@@ -86,7 +86,7 @@ int evms_get_node_list(node_search_flags_t flags,
 	}
 
 	node_list = alloc_app_struct(sizeof(node_list_t) + list_to_copy->count * sizeof(node_info_t), free_node_list);
-	
+
 	if (node_list == NULL) {
 		LOG_CRITICAL("Error getting memory for a node_list_t.\n");
 		LOG_PROC_EXIT_INT(ENOMEM);
@@ -502,7 +502,7 @@ int connect_to_ece() {
 	config_node_names->count = num_config_nodes;
 
 	for (i = 0; (i < num_config_nodes) && (rc == 0); i++) {
-		int name_size = 8;     /* Initial allocation size. */
+		uint name_size = 8;     /* Initial allocation size. */
 
 		char * config_node_name = engine_alloc(name_size);
 
