@@ -35,7 +35,7 @@
 #include "memman.h"
 #include "message.h"
 
-					
+
 #define DEFAULT_CONFIG_FILE_NAME	"/etc/evms.conf"
 
 static char * config_file_name = NULL;
@@ -118,7 +118,7 @@ static u_int32_t hash_value(char * string) {
 	u_int32_t h = 0;
 	u_int32_t g;
 	int i;
-	u_char * pByte = string;
+	char * pByte = string;
 
 	LOG_PROC_EXTRA_ENTRY();
 
