@@ -23,4 +23,4 @@
 
 // Global functions exported by crc.c
 
-extern u_int32_t calculate_CRC(u_int32_t CRC, void * Buffer, u_int32_t BufferSize);
+extern u_int32_t evms_calculate_crc(u_int32_t CRC, void * Buffer, u_int32_t BufferSize);
