@@ -191,7 +191,7 @@ int ensure_dev_node(char * name, u_int32_t major, u_int32_t minor) {
 				break;
 
 			case ENOENT:
-				LOG_DEBUG("Device node \"%s\" does not exist.", name);
+				LOG_DEBUG("Device node \"%s\" does not exist.\n", name);
 
 				strcpy(dir_name, name);
 				*(strrchr(dir_name, '/')) = '\0';
