@@ -39,7 +39,6 @@
 #include "cluster.h"
 #include "remote.h"
 #include <ldm_funcs.h>
-#include <csm_funcs.h>
 
 
 static void unload_module(so_record_t * so_record) {
@@ -1180,7 +1179,7 @@ static int setup_plugins() {
 		if (rc == 0) {
 			/* Handle special plug-ins. */
 			switch (plug_rec->id) {
-				case LDM_PLUGIN_ID_2:
+				case EVMS_DISK_PLUGIN_ID:
 					{
 						/* Start up the Local Disk Manager read cache. */
 						plug_rec->functions.plugin->plugin_function(NULL, LDM_Start_Caching, NULL, NULL);
@@ -1193,7 +1192,7 @@ static int setup_plugins() {
 					local_disk_manager = plug_rec;
 					break;
 
-				case REPLACE_PLUGIN_ID:
+				case EVMS_REPLACE_PLUGIN_ID:
 					replace_plugin = plug_rec;
 					break;
 
@@ -1229,7 +1228,7 @@ static int setup_plugins() {
 		if (rc == 0) {
 			/* Handle special plug-ins. */
 			switch (plug_rec->id) {
-				case CSM_PLUGIN_ID:
+				case EVMS_CSM_PLUGIN_ID:
 					cluster_segment_manager = plug_rec;
 					break;
 
