@@ -57,7 +57,7 @@ static void *add_ioctl_target(dm_target_t *target,
 {
 	dm_ioctl_target_t i_target;
 	void *params = begin;
-	unsigned long params_length = strlen(target->params);
+	size_t params_length = strlen(target->params);
 
 	LOG_PROC_ENTRY();
 
@@ -76,7 +76,7 @@ static void *add_ioctl_target(dm_target_t *target,
 		sizeof(i_target.target_type));
 
 	/* Copy the parameter string. */
-	strcpy((char *)params, target->params);
+	strcpy((char *)params, (char *)target->params);
 	params += params_length + 1;
 	params = align(params);
 
@@ -136,7 +136,7 @@ static dm_target_t *build_target_list(dm_ioctl_t *dmi)
 				  "groups from the target type.\n");
 			goto error;
 		}
-		
+
 		/* Allocate a target structure. */
 		target = dm_allocate_target(type, i_target->start,
 					    i_target->length,
@@ -198,9 +198,9 @@ error:
  * packet. The caller is responsible for filling in extra information
  * in the ioctl header (flags and dev) based on the command being sent.
  **/
-static dm_ioctl_t *build_ioctl_packet(unsigned char *name,
+static dm_ioctl_t *build_ioctl_packet(char *name,
 				      dm_target_t *target_list,
-				      unsigned char *new_name)
+				      char *new_name)
 {
 	dm_ioctl_t *dmi;
 	dm_target_t *target;
@@ -219,7 +219,7 @@ static dm_ioctl_t *build_ioctl_packet(unsigned char *name,
 	/* Count the number of targets. */
 	for (target = target_list; target; target = target->next) {
 		packet_length += sizeof(dm_ioctl_target_t);
-		packet_length += strlen(target->params) + 1 + ALIGNMENT;
+		packet_length += strlen((char *)target->params) + 1 + ALIGNMENT;
 		target_count++;
 	}
 
@@ -436,7 +436,7 @@ int dm_activate_v3(char *name,
 		*dev_major = major(dmi->dev);
 		*dev_minor = minor(dmi->dev);
 	}
-	
+
 out:
 	engine_free(dmi);
 	LOG_PROC_EXIT_INT(rc);
