@@ -91,7 +91,7 @@ static void *add_ioctl_target(dm_target_t *target,
 {
 	dm_ioctl_target_t i_target;
 	void *params = begin;
-	unsigned long params_length = strlen(target->params);
+	size_t params_length = strlen(target->params);
 
 	LOG_PROC_ENTRY();
 
@@ -110,7 +110,7 @@ static void *add_ioctl_target(dm_target_t *target,
 		sizeof(i_target.target_type));
 
 	/* Copy the parameter string. */
-	strcpy((char *)params, target->params);
+	strcpy((char *)params, (char *)target->params);
 	params += params_length + 1;
 	params = align(params);
 
@@ -228,7 +228,7 @@ static dm_device_list_t *build_device_list(dm_ioctl_t *dmi)
 	LOG_PROC_ENTRY();
 
 	name = (dm_name_list_t*)data_start;
-	
+
 	if (name->dev == 0) {
 		goto out;
 	}
@@ -276,7 +276,7 @@ static dm_module_list_t *build_module_list(dm_ioctl_t *dmi)
 	LOG_PROC_ENTRY();
 
 	version = (dm_target_versions_t*)data_start;
-	
+
 	if (version->name[0] == '\0') {
 		goto out;
 	}
@@ -403,9 +403,9 @@ static void put_ioctl_packet(dm_ioctl_t *dmi)
  * packet. The caller is responsible for filling in extra information
  * in the ioctl header (flags and dev) based on the command being sent.
  **/
-static dm_ioctl_t *build_ioctl_packet(unsigned char *name,
+static dm_ioctl_t *build_ioctl_packet(char *name,
 				      dm_target_t *target_list,
-				      unsigned char *new_name)
+				      char *new_name)
 {
 	dm_ioctl_t *dmi;
 	dm_target_t *target;
