@@ -185,6 +185,25 @@ void dm_deallocate_device_list(dm_device_list_t *device_list)
 	LOG_PROC_EXIT_VOID();
 }
 
+/**
+ * dm_deallocate_module_list
+ *
+ * Free the memory for a list of dm_module_list's.
+ **/
+void dm_deallocate_module_list(dm_module_list_t *module_list)
+{
+	dm_module_list_t *module;
+
+	LOG_PROC_ENTRY();
+
+	for (module = module_list; module; module = module_list) {
+		module_list = module->next;
+		engine_free(module);
+	}
+
+	LOG_PROC_EXIT_VOID();
+}
+
 /**
  * dm_suspend
  *
@@ -1135,6 +1154,40 @@ out:
 	return rc;
 }
 
+/**
+ * dm_get_modules
+ *
+ * @modules_list: List of modules returned to caller.
+ *
+ * Get a list of all target-modules current loaded in Device-Mapper.
+ *
+ * This API is only available with DM interface version 4.
+ **/
+int dm_get_modules(dm_module_list_t ** module_list)
+{
+	int rc;
+
+	LOG_PROC_ENTRY();
+
+	if (!module_list) {
+		/* Bad parameters. */
+		rc = EINVAL;
+		goto out;
+	}
+
+	switch (dm_version_major) {
+	case 4:
+		rc = dm_get_modules_v4(module_list);
+		break;
+	default:
+		rc = EINVAL;
+	}
+
+out:
+	LOG_PROC_EXIT_INT(rc);
+	return rc;
+}
+
 /**
  * dm_wait
  *
