@@ -156,7 +156,7 @@ char  * log_file_name = DEFAULT_LOG_FILE;
 int     log_file_fd = 0;
 boolean log_usec = FALSE;
 boolean log_pid = FALSE;
-u_char log_buf[LOG_BUF_SIZE];
+char log_buf[LOG_BUF_SIZE];
 pthread_mutex_t log_mutex = PTHREAD_MUTEX_INITIALIZER;
 boolean sync_log = FALSE;
 
