@@ -66,7 +66,7 @@ extern char           * log_file_name;
 extern int              log_file_fd;
 extern boolean          log_usec;
 extern boolean          log_pid;
-extern u_char           log_buf[];
+extern char             log_buf[];
 extern pthread_mutex_t  log_mutex;
 #define LOG_BUF_SIZE    (MAX_USER_MESSAGE_LEN + 1024)
 
