@@ -430,7 +430,8 @@ int engine_get_object_list(object_type_t         object_type,
 					 * If the object does not have changes pending,
 					 * Delete it from the list.
 					 */
-					if (!is_object_change_pending(obj, NULL)) {
+					changes_pending_parms_t parms;
+					if (!is_object_change_pending(obj, &parms)) {
 						remove = TRUE;
 					}
 				}
@@ -1575,61 +1576,189 @@ static int engine_calculate_checksum(unsigned char * buffer,
 }
 
 
-/*
- * Tell the Engine to put some sectors on its kill list.
- */
-static int engine_add_sectors_to_kill_list(storage_object_t * disk, lba_t lba, sector_count_t count) {
-
-	kill_sector_record_t * ksr = engine_alloc(sizeof(kill_sector_record_t));
-	int                    rc = 0;
+static int insert_new_kill_sector_record(storage_object_t * disk,
+					 lba_t              lba,
+					 sector_count_t     count,
+					 insert_flags_t     insert_flags,
+					 element_t        * ref_element) {
+	int rc = 0;
+	kill_sector_record_t * ksr;
+	list_element_t el;
 
 	LOG_PROC_ENTRY();
 
-	if (ksr != NULL) {
-		if (disk != NULL) {
-			if (lba <= disk->size) {
-				if (lba + count <= disk->size) {
-					list_element_t el;
+	ksr = engine_alloc(sizeof(kill_sector_record_t));
+	if (ksr == NULL) {
+		LOG_CRITICAL("Error allocating memory for a kill sector record.\n");
+		LOG_PROC_EXIT_INT(ENOMEM);
+		return ENOMEM;
+	}
 
-					ksr->logical_disk  = disk;
-					ksr->sector_offset = lba;
-					ksr->sector_count  = count;
+	ksr->logical_disk  = disk;
+	ksr->sector_offset = lba;
+	ksr->sector_count  = count;
 
-					el = insert_thing(&kill_sectors_list,
-							  ksr,
-							  INSERT_BEFORE,
-							  NULL);
+	el = insert_thing(&kill_sectors_list,
+			  ksr,
+			  insert_flags,
+			  ref_element);
 
-					if (el != NULL) {
-						LOG_DEBUG("Request queued to kill %"PRIu64" sector%s on disk %s at LBA %"PRIu64".\n", ksr->sector_count, (ksr->sector_count == 1) ? "" : "s", ksr->logical_disk->name, ksr->sector_offset);
+	if (el != NULL) {
+		LOG_DEBUG("Request queued to kill %"PRIu64" sector%s on disk %s at LBA %"PRIu64".\n", count, (count == 1) ? "" : "s", disk->name, lba);
+	} else {
+		LOG_CRITICAL("Error inserting a kill sector record into the kill sectors list.\n");
+		rc = ENOMEM;
 
-					} else {
-						LOG_CRITICAL("Error inserting a kill sector record into the kill sectos list.\n");
-						rc = ENOMEM;
-					}
+		engine_free(ksr);
+	}
 
-				} else {
-					LOG_ERROR("The count of sectors (%"PRIu64" at LBA %"PRIu64") goes past the end of the disk (disk size is %"PRIu64").\n", ksr->sector_count, ksr->sector_offset, disk->size);
-					rc = EINVAL;
-				}
+	LOG_PROC_EXIT_INT(rc);
+	return rc;
+}
+
+
+/*
+ * Tell the Engine to put some sectors on its kill list.
+ */
+static int engine_add_sectors_to_kill_list(storage_object_t * disk,
+					   lba_t              lba,
+					   sector_count_t     count) {
+
+	int rc = 0;
+	list_element_t el;
+	list_element_t el_next;
+	kill_sector_record_t * ksr;
+	kill_sector_record_t * ksr_next;
+	sector_count_t ksr_end;
+	sector_count_t new_end = lba + count;
+	int disk_comp;
+
+	LOG_PROC_ENTRY();
+
+	LOG_DEBUG("Request to kill %"PRIu64" sector%s at offset %"PRIu64" on disk %s.\n",
+		  count, (count == 1) ? "" : "s", lba, disk->name);
+
+	if (disk == NULL) {
+		LOG_ERROR("The pointer for the disk is NULL.\n");
+		LOG_PROC_EXIT_INT(EINVAL);
+		return EINVAL;
+	}
+
+	if (lba > disk->size) {
+		LOG_ERROR("The starting LBA of the kill sectors (%"PRIu64") is past the end of the disk (disk size is %"PRIu64").\n", lba, disk->size);
+		LOG_PROC_EXIT_INT(EINVAL);
+		return EINVAL;
+	}
+
+	if (lba + count > disk->size) {
+		LOG_ERROR("The count of sectors (%"PRIu64" at LBA %"PRIu64") goes past the end of the disk (disk size is %"PRIu64").\n", count, lba, disk->size);
+		LOG_PROC_EXIT_INT(EINVAL);
+		return EINVAL;
+	}
+
+	ksr = first_thing(&kill_sectors_list, &el);
+
+	if (ksr == NULL) {
+		rc = insert_new_kill_sector_record(disk, lba, count, INSERT_BEFORE, NULL);
+		LOG_PROC_EXIT_INT(rc);
+		return rc;
+	}
+
+	while (ksr != NULL) {
+		ksr_end = ksr->sector_offset + ksr->sector_count;
+
+		disk_comp = strcmp(disk->name, ksr->logical_disk->name);
+
+		/* Check if the new record belongs before of this one. */
+		if ((disk_comp < 0) ||
+		    ((disk_comp == 0) && (new_end < ksr->sector_offset))) {
+			rc = insert_new_kill_sector_record(disk, lba, count, INSERT_BEFORE, el);
+
+			break;
+		}
+
+		/* Check if the new record belongs after this one. */
+		if ((disk_comp > 0) ||
+		    ((disk_comp == 0) && (lba > ksr_end))) {
+			
+			ksr = next_thing(&el);
+
+			if (ksr == NULL) {
+				/* At end of list. */
+				rc = insert_new_kill_sector_record(disk, lba, count, INSERT_AFTER, NULL);
+				break;
 
 			} else {
-				LOG_ERROR("The starting LBA of the kill sectors (%"PRIu64") is past the end of the disk (disk size is %"PRIu64").\n", ksr->sector_offset, disk->size);
-				rc = EINVAL;
+				continue;
 			}
-
-		} else {
-			LOG_ERROR("The pointer for the disk is NULL.\n");
-			rc = EINVAL;
 		}
 
-		if (rc != 0) {
-			engine_free(ksr);
+		/* The new record can be merged with this one. */
+		LOG_DEBUG("The new request can be merged with an existing\n");
+		LOG_DEBUG("request to kill %"PRIu64" sector%s at offset %"PRIu64" on disk %s.\n",
+			  ksr->sector_count, (ksr->sector_count == 1) ? "" : "s",
+			  ksr->sector_offset, ksr->logical_disk->name);
+
+		if ((lba < ksr->sector_offset) &&
+		    (new_end >= ksr->sector_offset)) {
+			LOG_DEBUG("Adjust existing request.\n");
+			LOG_DEBUG("Before: Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+				  ksr->logical_disk->name, ksr->sector_offset, ksr->sector_count);
+
+			ksr->sector_count += ksr->sector_offset - lba;
+			ksr->sector_offset = lba;
+
+			LOG_DEBUG("After:  Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+				  ksr->logical_disk->name, ksr->sector_offset, ksr->sector_count);
+		}
+		
+		if ((new_end > ksr_end) &&
+		    (lba <= ksr_end)) {
+			LOG_DEBUG("Adjust existing request.\n");
+			LOG_DEBUG("Before: Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+				  ksr->logical_disk->name, ksr->sector_offset, ksr->sector_count);
+
+			ksr->sector_count += new_end - ksr_end;
+
+			LOG_DEBUG("After:  Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+				  ksr->logical_disk->name, ksr->sector_offset, ksr->sector_count);
+
+			/*
+			 * This record may have grown enough to merge into the
+			 * next request in the list.
+			 */
+			el_next = el;
+			ksr_next = next_thing(&el_next);
+
+			while (ksr_next != NULL) {
+				if ((disk != ksr_next->logical_disk) ||
+				    (ksr->sector_offset + ksr->sector_count < ksr_next->sector_offset)) {
+					break;
+				}
+
+				/* The records can be merged. */
+				LOG_DEBUG("Merge requests.\n");
+				LOG_DEBUG("Before: Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+					  ksr->logical_disk->name, ksr->sector_offset, ksr->sector_count);
+				LOG_DEBUG("        Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+					  ksr_next->logical_disk->name, ksr_next->sector_offset, ksr_next->sector_count);
+
+				ksr_end = max(ksr->sector_offset + ksr->sector_count,
+					      ksr_next->sector_offset + ksr_next->sector_count);
+				ksr->sector_count = ksr_end - ksr->sector_offset;
+
+				LOG_DEBUG("After:  Disk: %s  Offset: %"PRIu64" Count: %"PRIu64"\n",
+					  ksr->logical_disk->name, ksr->sector_offset, ksr->sector_count);
+
+				delete_element(el_next);
+				engine_free(ksr_next);
+
+				el_next = el;
+				ksr_next = next_thing(&el_next);
+			}
 		}
 
-	} else {
-		LOG_CRITICAL("Error allocating memory for a kill sector record.\n");
-		rc = ENOMEM;
+		break;
 	}
 
 	LOG_PROC_EXIT_INT(rc);
