@@ -76,7 +76,7 @@ static boolean isa_valid_anchor(anchor_t * anchor) {
 	LOG_PROC_EXTRA_ENTRY();
 
 	if (anchor == NULL) {
-		LOG_ERROR("List is NULL.\n");
+		LOG_DEBUG("List is NULL.\n");
 		LOG_PROC_EXTRA_EXIT_BOOLEAN(FALSE);
 		return FALSE;
 	}
