@@ -239,10 +239,44 @@ int evms_create(plugin_handle_t    plugin_handle,
 						child_obj->flags &= ~SOFLAG_HAS_STOP_DATA;
 					}
 
-					/* Mark the new objects' feature
+					/*
+					 * Mark the new objects' feature
 					 * headers dirty.
 					 */
 					set_feature_header_dirty(new_obj);
+
+					/*
+					 * Set the object's SOFLAG_NEEDS_ACTIVATE
+					 * flag if all of its children are
+					 * active or are scheduled to be
+					 * activated..
+					 */
+					if (new_obj->data_type == DATA_TYPE) {
+						new_obj->flags |= SOFLAG_NEEDS_ACTIVATE;
+						if (new_obj->producing_container != NULL) {
+							LIST_FOR_EACH(new_obj->producing_container->objects_consumed, tmp_iter, child_obj) {
+								if (!(child_obj->flags & (SOFLAG_ACTIVE | SOFLAG_NEEDS_ACTIVATE))) {
+									new_obj->flags &= ~SOFLAG_NEEDS_ACTIVATE;
+									break;
+								}
+							}
+						} else {
+							LIST_FOR_EACH(new_obj->child_objects, tmp_iter, child_obj) {
+								if (!(child_obj->flags & (SOFLAG_ACTIVE | SOFLAG_NEEDS_ACTIVATE))) {
+									new_obj->flags &= ~SOFLAG_NEEDS_ACTIVATE;
+									break;
+								}
+							}
+						}
+						if (new_obj->flags & SOFLAG_NEEDS_ACTIVATE) {
+							LIST_FOR_EACH(new_obj->associated_children, tmp_iter, child_obj) {
+								if (!(child_obj->flags & (SOFLAG_ACTIVE | SOFLAG_NEEDS_ACTIVATE))) {
+									new_obj->flags &= ~SOFLAG_NEEDS_ACTIVATE;
+									break;
+								}
+							}
+						}
+					}
 				}
 
 				propigate_cluster_info(&new_objects);
@@ -256,17 +290,17 @@ int evms_create(plugin_handle_t    plugin_handle,
 				/* Sort the list that was affected. */
 				switch (GetPluginType(pPlugRec->id)) {
 					case EVMS_DEVICE_MANAGER:
-						sort_list(&disks_list, compare_objects);
+						sort_list(&disks_list, compare_objects, NULL);
 						break;
 					case EVMS_SEGMENT_MANAGER:
-						sort_list(&segments_list, compare_objects);
+						sort_list(&segments_list, compare_objects, NULL);
 						break;
 					case EVMS_REGION_MANAGER:
-						sort_list(&regions_list, compare_objects);
+						sort_list(&regions_list, compare_objects, NULL);
 						break;
 					case EVMS_FEATURE:
 					case EVMS_ASSOCIATIVE_FEATURE:
-						sort_list(&EVMS_objects_list, compare_objects);
+						sort_list(&EVMS_objects_list, compare_objects, NULL);
 						break;
 					default:
 						break;
@@ -287,10 +321,9 @@ int evms_create(plugin_handle_t    plugin_handle,
 					rc = make_user_handle_array(&new_objects, output_objects);
 				}
 
-				} else {
-					LOG_CRITICAL("Error getting memory for resulting object list.\n");
-					rc = ENOMEM;
-				}
+			} else {
+				LOG_CRITICAL("Error returned from plugin's create routine.\n");
+			}
 
 			destroy_list(input_objects);
 
@@ -307,246 +340,6 @@ int evms_create(plugin_handle_t    plugin_handle,
 }
 
 
-/*
- * validate_transfer_parameters is a support function for evms_transfer()
- * below.  It does the parameter validation so that evms_transfer() can
- * do the real work of transferring the object.
- */
-static int validate_transfer_parameters(object_handle_t         object_handle,
-					plugin_handle_t         plugin_handle,
-					object_handle_t         container_handle,
-					storage_object_t    * * p_object,
-					plugin_record_t     * * p_plugin,
-					storage_container_t * * p_container) {
-	int rc = 0;
-	object_type_t         type;
-	storage_object_t    * object = NULL;
-	plugin_record_t     * plugin = NULL;
-	storage_container_t * container = NULL;
-
-	LOG_PROC_ENTRY();
-
-	rc = translate_handle(object_handle, (void *) &object, &type);
-
-	if (rc == HANDLE_MANAGER_NO_ERROR) {
-
-		/* Containers can only contain storage objects. */
-		if ((type == DISK) ||
-		    (type == SEGMENT) ||
-		    (type == REGION) ||
-		    (type == EVMS_OBJECT)) {
-
-			/* The object must not be part of a volume. */
-			if (object->volume != NULL) {
-				LOG_ERROR("The object cannot be transferred since it is part of a volume.\n");
-				rc = EINVAL;
-			}
-
-		} else {
-			LOG_ERROR("The object handle is not for a storage object.\n");
-			rc = EINVAL;
-		}
-
-	} else {
-		LOG_ERROR("The object handle parameter is not valid.  translate_handle() returned error %d.\n", rc);
-	}
-
-	if (rc == 0) {
-		/* If a plugin_handle was given, get the plug-in record. */
-		if (plugin_handle != 0) {
-			rc = translate_handle(plugin_handle, (void *) &plugin, &type);
-
-			if (rc == 0) {
-				if (type == PLUGIN) {
-					/*
-					 * Check to make sure the plug-in supports containers, i.e.,
-					 * it has a function table for container functions.
-					 */
-					if (plugin->container_functions == NULL) {
-						LOG_ERROR("The target plug-in does not support container functions.\n");
-						rc = EINVAL;
-					}
-
-				} else {
-					LOG_ERROR("The plug-in handle parameter is not a handle for a plug-in.\n");
-					rc = EINVAL;
-				}
-
-			} else {
-				LOG_ERROR("The plug-in handle parameter is not valid.  translate_handle() returned error %d.\n", rc);
-			}
-		}
-	}
-
-	if (rc == 0) {
-		/* If a container_handle was given, get the container. */
-		if (container_handle != 0) {
-			rc = translate_handle(container_handle, (void *) &container, &type);
-
-			if (rc == 0) {
-				if (type != CONTAINER) {
-					LOG_ERROR("The container handle parameter is not a handle for a container.\n");
-					rc = EINVAL;
-				}
-
-			} else {
-				LOG_ERROR("The container handle parameter is not valid.  translate_handle() returned error %d.\n", rc);
-			}
-		}
-	}
-
-	if (rc == 0) {
-		/*
-		 * If both a plug-in and a container were given, make sure the plug-in
-		 * is the one that manages the container.
-		 */
-		if ((plugin != NULL) && (container != NULL)) {
-		    if (container->plugin != plugin) {
-			LOG_ERROR("Parameter conflict.  The specified container is not managed by the specified plug-in.\n");
-			rc = EINVAL;
-		    }
-		}
-	}
-
-	if (rc == 0) {
-		/*
-		 * If a container was given, make sure the object and the
-		 * container are in the same disk group.
-		 */
-		if (container != NULL) {
-			/*
-			 * The Cluster Segment Manger is allowed to transfer
-			 * disks between groups.
-			 */
-			if (container->plugin != cluster_segment_manager) {
-				if (object->disk_group != container->disk_group) {
-					LOG_ERROR("Object %s and container %s are not in the same disk group.\n", object->name, container->name);
-					rc = EINVAL;
-				}
-			}
-		}
-	}
-
-	/* If all went well, return the pointers. */
-	if (rc == 0) {
-		*p_object    = object;
-		*p_plugin    = plugin;
-		*p_container = container;
-	}
-
-	LOG_PROC_EXIT_INT(rc);
-	return rc;
-}
-
-
-/*
- * evms_transfer will transfer an object to a particular plug-in and/or
- * container.  If container is 0, the plug-in will assign the object to its
- * default container.
- */
-int evms_transfer(object_handle_t  object_handle,
-		  plugin_handle_t  plugin_handle,
-		  object_handle_t  container_handle,
-		  option_array_t * options) {
-
-	int rc = 0;
-	storage_object_t    * object = NULL;
-	plugin_record_t     * plugin = NULL;
-	storage_container_t * container = NULL;
-
-	LOG_PROC_ENTRY();
-
-	rc = check_engine_write_access();
-        if (rc != 0) {
-		LOG_PROC_EXIT_INT(rc);
-		return rc;
-	}
-
-	if (!local_focus) {
-		rc = remote_transfer(object_handle, plugin_handle, container_handle, options);
-		LOG_PROC_EXIT_INT(rc);
-		return rc;
-	}
-	rc = validate_transfer_parameters(object_handle, plugin_handle, container_handle,
-					  &object, &plugin, &container);
-	if (rc == 0) {
-		/*
-		 * If a target plug-in was not specified, then the target plug-in is
-		 * the one that manages the target container, if a container was
-		 * specified.
-		 */
-		if (plugin == NULL) {
-			if (container != NULL) {
-				plugin = container->plugin;
-			}
-		}
-
-		/* Check if the object is currently in a container. */
-		if (object->consuming_container != NULL) {
-
-			if (object->consuming_container->plugin == plugin) {
-
-				/* This is an intra-plugin transfer. */
-				rc = plugin->container_functions->transfer_object(object, container, options);
-
-				LOG_DEBUG("transfer_object() returned error code %d.\n", rc);
-
-			} else {
-				/*
-				 * This is an inter-plugin transfer.  Tell the plug-in that
-				 * currently owns the container to which the object belongs
-				 * to remove it from its current container.
-				 */
-				rc = object->consuming_container->plugin->container_functions->remove_object(object);
-
-				LOG_DEBUG("remove_object() returned error code %d.\n", rc);
-
-				if (rc == 0) {
-					/*
-					 * If a target plug-in/container was specified, add the
-					 * object to the target plug-in/container.
-					 */
-					if (plugin != NULL) {
-						rc = plugin->container_functions->add_object(object, container, options);
-
-						LOG_DEBUG("add_object() returned error code %d.\n", rc);
-					}
-
-				} else {
-					LOG_WARNING("The %s plug-in failed to remove the object with handle %d from its current container.  The error code was %d.\n", object->consuming_container->plugin->short_name,object_handle, rc);
-				}
-			}
-
-		} else {
-			if (plugin != NULL) {
-				/*
-				 * The object does not belong to a container.
-				 * Just add it to the new container.
-				 */
-				rc = plugin->container_functions->add_object(object, container, options);
-				LOG_DEBUG("add_object() returned error code %d.\n", rc);
-
-				if (rc == 0) {
-					/*
-					 * Now that the object is consumed,
-					 * any stop data on it can be
-					 * overwritten.  Forget that it is
-					 * there.
-					 */
-					object->flags &= ~SOFLAG_HAS_STOP_DATA;
-				}
-			} else {
-				LOG_WARNING("The object does not belong to a container and no target container or plug-in was specified.  There is nothing for evms_transfer() to do.\n");
-				rc = EINVAL;
-			}
-		}
-	}
-
-	LOG_PROC_EXIT_INT(rc);
-	return rc;
-}
-
-
 /*
  * evms_get_object_list returns a pointer to a handle_array_t with handles for
  * storage objects, optionally filtering on the object type, the data type of
@@ -733,7 +526,7 @@ int evms_assign(object_handle_t  object_handle,
 		}
 
 	} else {
-		LOG_ERROR("An plug-in handle must be given.\n");
+		LOG_ERROR("A plug-in handle must be given.\n");
 		rc = EINVAL;
 	}
 
@@ -750,6 +543,22 @@ int evms_assign(object_handle_t  object_handle,
 			obj->flags &= ~SOFLAG_HAS_STOP_DATA;
 
 			propigate_cluster_info(obj->parent_objects);
+
+			/*
+			 * If the target object of the assign is active or
+			 * scheduled to be activated, mark its new parent
+			 * objects for activation.
+			 */
+			if (obj->flags & (SOFLAG_ACTIVE | SOFLAG_NEEDS_ACTIVATE)) {
+				list_element_t iter;
+				storage_object_t * parent;
+
+				LIST_FOR_EACH(obj->parent_objects, iter, parent) {
+					if (parent->data_type == DATA_TYPE) {
+						parent->flags |= SOFLAG_NEEDS_ACTIVATE;
+					}
+				}
+			}
 		}
 	}
 
@@ -1017,8 +826,8 @@ int evms_unassign(object_handle_t object_handle) {
 					int answer = 0;	    /* Default is "Continue" */
 
 					rc = engine_user_message(&answer, choices,
-								 "WARNING:  Plug-in %s is producing data objects from object %s.  "
-								 "Unassigning plug-in %s from object %s will destroy the data objects.\n",
+								 _("WARNING:  Plug-in %s is producing data objects from object %s.  "
+								   "Unassigning plug-in %s from object %s will destroy the data objects.\n"),
 								 parent_plugin->short_name, obj->name,
 								 parent_plugin->short_name, obj->name);
 
@@ -1178,10 +987,7 @@ int evms_get_plugin_functions(engine_handle_t           thing_handle,
 		 * Allocate a user memory block and copy the action info
 		 * to the user memory.
 		 */
-		uint size = sizeof(function_info_array_t);
-		if (function_array->count > 1) {
-			size += (function_array->count - 1) * sizeof(function_info_t);
-		}
+		uint size = sizeof(function_info_array_t) + function_array->count * sizeof(function_info_t);
 
 		*actions = alloc_app_struct(size, free_function_info_array_contents);
 
