@@ -919,7 +919,7 @@ int evms_get_option_descriptor_by_name(task_handle_t           handle,
 
 		if (descriptor != NULL) {
 			if (name != NULL) {
-				u_int32_t index;
+				u_int32_t index = -1;
 
 				rc = OptionNameToIndex(task, name, &index);
 
@@ -1022,8 +1022,7 @@ int evms_set_option_value_by_name(task_handle_t   handle,
 
 		if (value != NULL) {
 			if (name != NULL) {
-				u_int32_t index;
-
+				u_int32_t index = -1;
 				rc = OptionNameToIndex(task, name, &index);
 
 				if (rc == 0) {
