@@ -49,7 +49,7 @@
 #include "option.h"
 
 
-static unsigned char msg_buf[2048];
+static char msg_buf[2048];
 
 static inline void log_buffer(void * in_buff, uint len) {
 
@@ -57,11 +57,11 @@ static inline void log_buffer(void * in_buff, uint len) {
 	int byte_count = 0;
 
 	unsigned char * byte = (unsigned char *) in_buff;
-	unsigned char * p = msg_buf;
+	char * p = msg_buf;
 
 	for (i = 0; i < len; i++) {
 		sprintf(p, "%02x", *byte);
-		p += strlen(p);	
+		p += strlen(p);
 		byte++;
 		byte_count++;
 		if (byte_count % 16 == 0) {
@@ -187,7 +187,7 @@ static void handle_response(const ece_msg_t * msg) {
 	list_element_t iter;
 
 	LOG_PROC_ENTRY();
-	
+
 	pthread_mutex_lock(&talk_list_mutex);
 	LIST_FOR_EACH(&talk_list, iter, talk) {
 		if ((talk->say.corrolator == msg->corrolator)  &&
@@ -307,7 +307,7 @@ static int wait_for_response(talk_t * talk) {
 #define SEPARATOR_LEN	(sizeof(FROM_PREFIX) - 1)
 
 static int msg_user_msg(talk_t * talk) {
-	
+
 	int rc;
 	const char * node_name = nodeid_to_string(&talk->hear.node);
 	char * message_text;
@@ -317,7 +317,7 @@ static int msg_user_msg(talk_t * talk) {
 	u_int32_t response[2];
 
 	LOG_PROC_ENTRY();
-	
+
 	talk->say.node       = talk->hear.node;
 	talk->say.corrolator = talk->hear.corrolator;
         talk->say.cmd        = talk->hear.cmd | COMMAND_RESPONSE;
@@ -405,7 +405,7 @@ static int msg_progress(talk_t * talk) {
 	u_int32_t response[3];
 
 	LOG_PROC_ENTRY();
-	
+
 	talk->say.node       = talk->hear.node;
 	talk->say.corrolator = talk->hear.corrolator;
         talk->say.cmd        = talk->hear.cmd | COMMAND_RESPONSE;
@@ -661,7 +661,7 @@ int remote_verify_version(void) {
 	int i;
 	get_version_thread_args_t * gvta;
 	STATIC_LIST_DECL(version_list);
-	int response_count;
+	uint response_count;
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
 	list_element_t iter;
@@ -970,7 +970,7 @@ int remote_open_engine(char           * node_name,
 	void * net_args;
 	STATIC_LIST_DECL(open_engine_list);
 	open_engine_thread_args_t * oeta;
-        int response_count = 0;
+        uint response_count = 0;
 	STATIC_LIST_DECL(callback_list);
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
@@ -988,7 +988,7 @@ int remote_open_engine(char           * node_name,
 
 	status_message("Starting EVMS on the other nodes in the cluster...\n");
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_open_engine_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_open_engine_args_f,
 				     node_name,
 				     mode,
 				     ui_callbacks,
@@ -1324,7 +1324,7 @@ int remote_set_debug_level(debug_level_t level) {
 	set_debug_level_thread_args_t * sdlta;
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
-	int response_count = 0;
+	uint response_count = 0;
 	list_element_t iter;
 	list_element_t iter1;
 	list_element_t iter2;
@@ -1537,7 +1537,7 @@ int remote_close_engine() {
 	int i;
 	STATIC_LIST_DECL(close_engine_list);
 	close_engine_thread_args_t * ceta;
-	int response_count = 0;
+	uint response_count = 0;
 	STATIC_LIST_DECL(callback_list);
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
@@ -1686,7 +1686,7 @@ int remote_can_delete(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_DELETE, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1699,7 +1699,7 @@ int remote_can_destroy(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_DESTROY, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1712,7 +1712,7 @@ int remote_can_expand(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_EXPAND, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1725,7 +1725,7 @@ int remote_can_shrink(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_SHRINK, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1751,7 +1751,7 @@ int remote_can_set_info(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_SET_INFO, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1764,7 +1764,7 @@ int remote_delete(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_DELETE, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1777,7 +1777,7 @@ int remote_destroy(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_DESTROY, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -1820,7 +1820,7 @@ int remote_expand(object_handle_t  thing,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_expand_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_expand_args_f,
 				     thing,
 				     objects,
 				     options);
@@ -1895,7 +1895,7 @@ int remote_shrink(object_handle_t  thing,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_shrink_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_shrink_args_f,
 				     thing,
 				     objects,
 				     options);
@@ -2006,7 +2006,7 @@ int remote_get_extended_info(object_handle_t           thing,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_get_extended_info_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_get_extended_info_args_f,
 				     thing,
 				     descriptor_name);
 
@@ -2055,7 +2055,7 @@ int remote_set_info(object_handle_t  object,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_set_info_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_set_info_args_f,
 				     object,
 				     options);
 
@@ -2099,7 +2099,7 @@ int remote_get_object_handle_for_name(object_type_t     type,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_get_object_handle_for_name_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_get_object_handle_for_name_args_f,
 				     type,
 				     name);
 
@@ -2225,7 +2225,7 @@ int remote_create(plugin_handle_t    plugin,
 int remote_assign(object_handle_t  object,
 		  plugin_handle_t  plugin,
 		  option_array_t * options) {
-	
+
 	int rc = 0;
 	size_t arg_size;
 	void * net_args;
@@ -2233,7 +2233,7 @@ int remote_assign(object_handle_t  object,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_assign_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_assign_args_f,
 				     object,
 				     plugin,
 				     options);
@@ -2277,7 +2277,7 @@ int remote_can_unassign(object_handle_t object) {
 	rc = one_handle_arg(EVMS_CAN_UNASSIGN, object);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2290,7 +2290,7 @@ int remote_unassign(object_handle_t object) {
 	rc = one_handle_arg(EVMS_UNASSIGN, object);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2390,7 +2390,7 @@ int remote_do_plugin_function(engine_handle_t  thing,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_do_plugin_function_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_do_plugin_function_args_f,
 				     thing,
 				     action,
 				     objects,
@@ -2440,7 +2440,7 @@ int remote_can_create_volume(object_handle_t object) {
 	rc = one_handle_arg(EVMS_CAN_CREATE_VOLUME, object);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2453,7 +2453,7 @@ int remote_can_create_compatibility_volume(object_handle_t object) {
 	rc = one_handle_arg(EVMS_CAN_CREATE_COMPATIBILITY_VOLUME, object);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2466,7 +2466,7 @@ int remote_can_set_volume_name(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_SET_VOLUME_NAME, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2479,7 +2479,7 @@ int remote_can_convert_to_evms_volume(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_CONVERT_TO_EVMS_VOLUME, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2492,7 +2492,7 @@ int remote_can_convert_to_compatibility_volume(object_handle_t volume){
 	rc = one_handle_arg(EVMS_CAN_CONVERT_TO_COMPATIBILITY_VOLUME, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2506,7 +2506,7 @@ int remote_can_add_feature_to_volume(object_handle_t volume,
 	rc = two_handle_arg(EVMS_CAN_ADD_FEATURE_TO_VOLUME, volume, feature);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2519,7 +2519,7 @@ int remote_create_volume(object_handle_t object,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_create_volume_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_create_volume_args_f,
 				     object,
 				     name);
 
@@ -2562,7 +2562,7 @@ int remote_set_volume_name(object_handle_t volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_set_volume_name_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_set_volume_name_args_f,
 				     volume,
 				     name);
 
@@ -2596,7 +2596,7 @@ int remote_set_volume_name(object_handle_t volume,
 
 
 int remote_create_compatibility_volume(object_handle_t object) {
-	
+
 	int rc;
 
 	LOG_PROC_ENTRY();
@@ -2604,7 +2604,7 @@ int remote_create_compatibility_volume(object_handle_t object) {
 	rc = one_handle_arg(EVMS_CREATE_COMPATIBILITY_VOLUME, object);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2618,7 +2618,7 @@ int remote_convert_to_evms_volume(object_handle_t volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_convert_to_evms_volume_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_convert_to_evms_volume_args_f,
 				     volume,
 				     name);
 
@@ -2652,7 +2652,7 @@ int remote_convert_to_evms_volume(object_handle_t volume,
 
 
 int remote_convert_to_compatibility_volume(object_handle_t volume) {
-	
+
 	int rc;
 
 	LOG_PROC_ENTRY();
@@ -2660,7 +2660,7 @@ int remote_convert_to_compatibility_volume(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CONVERT_TO_COMPATIBILITY_VOLUME, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2674,7 +2674,7 @@ int remote_add_feature_to_volume(object_handle_t  volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_add_feature_to_volume_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_add_feature_to_volume_args_f,
 				     volume,
 				     feature,
 				     options);
@@ -2719,7 +2719,7 @@ int remote_can_mkfs(object_handle_t volume,
 	rc = two_handle_arg(EVMS_CAN_MKFS, volume, fsim);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 int remote_can_unmkfs(object_handle_t volume) {
@@ -2731,7 +2731,7 @@ int remote_can_unmkfs(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_UNMKFS, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2745,7 +2745,7 @@ int remote_can_fsck(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_FSCK, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2760,7 +2760,7 @@ int remote_mkfs(object_handle_t  volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_mkfs_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_mkfs_args_f,
 				     volume,
 				     fsim,
 				     options);
@@ -2804,7 +2804,7 @@ int remote_unmkfs(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_UNMKFS, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2818,7 +2818,7 @@ int remote_fsck(object_handle_t  volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_fsck_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_fsck_args_f,
 				     volume,
 				     options);
 
@@ -2913,7 +2913,7 @@ int remote_can_mount(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_MOUNT, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2928,7 +2928,7 @@ int remote_mount(object_handle_t volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_mount_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_mount_args_f,
 				     volume,
 				     mount_point,
 				     options);
@@ -2972,7 +2972,7 @@ int remote_can_unmount(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_UNMOUNT, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2985,7 +2985,7 @@ int remote_unmount(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_UNMOUNT, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -2998,7 +2998,7 @@ int remote_can_remount(object_handle_t volume) {
 	rc = one_handle_arg(EVMS_CAN_REMOUNT, volume);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -3012,7 +3012,7 @@ int remote_remount(object_handle_t volume,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_remount_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_remount_args_f,
 				     volume,
 				     options);
 
@@ -3060,7 +3060,7 @@ int remote_create_container(plugin_handle_t   plugin,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_create_container_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_create_container_args_f,
 				     plugin,
 				     input_objects,
 				     options);
@@ -3168,7 +3168,7 @@ int remote_create_task(engine_handle_t thing,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_create_task_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_create_task_args_f,
 				     thing,
 				     action);
 
@@ -3235,7 +3235,7 @@ int remote_invoke_task(task_handle_t      task,
 
 
 int remote_destroy_task(task_handle_t task) {
-	
+
 	int rc;
 
 	LOG_PROC_ENTRY();
@@ -3372,7 +3372,7 @@ int remote_set_selected_objects(task_handle_t               task,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_set_selected_objects_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_set_selected_objects_args_f,
 				     task,
 				     selected_object_list);
 
@@ -3468,7 +3468,7 @@ int remote_get_option_descriptor(task_handle_t           task,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_get_option_descriptor_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_get_option_descriptor_args_f,
 				     task,
 				     option);
 
@@ -3535,7 +3535,7 @@ int remote_set_option_value(task_handle_t   task,
 	value_is_list = od->flags & EVMS_OPTION_FLAGS_VALUE_IS_LIST;
 	evms_free(od);
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_set_option_value_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_set_option_value_args_f,
 				     task,
 				     option,
 				     value_type,
@@ -3597,7 +3597,7 @@ int remote_get_option_descriptor_by_name(task_handle_t           task,
 
 	LOG_PROC_ENTRY();
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_get_option_descriptor_by_name_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_get_option_descriptor_by_name_args_f,
 				     task,
 				     option);
 
@@ -3664,7 +3664,7 @@ int remote_set_option_value_by_name(task_handle_t   task,
 	value_is_list = od->flags & EVMS_OPTION_FLAGS_VALUE_IS_LIST;
 	evms_free(od);
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_set_option_value_by_name_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_set_option_value_by_name_args_f,
 				     task,
 				     option_name,
 				     value_type,
@@ -3768,7 +3768,7 @@ int remote_mark_for_rediscover(char * name) {
 	void * net_args;
 	STATIC_LIST_DECL(mark_for_rediscover_list);
 	mark_for_rediscover_thread_args_t * mfrta;
-	int response_count = 0;
+	uint response_count = 0;
 	STATIC_LIST_DECL(callback_list);
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
@@ -3784,7 +3784,7 @@ int remote_mark_for_rediscover(char * name) {
 		return 0;
 	}
 
-	rc = evms_sizeof_host_to_net(&arg_size, evms_mark_for_rediscover_args_f,	
+	rc = evms_sizeof_host_to_net(&arg_size, evms_mark_for_rediscover_args_f,
 				     name);
 
 	if (rc != 0) {
@@ -3989,7 +3989,7 @@ int remote_rediscover(void) {
 	int i;
 	STATIC_LIST_DECL(rediscover_list);
 	rediscover_thread_args_t * rta;
-	int response_count = 0;
+	uint response_count = 0;
 	STATIC_LIST_DECL(callback_list);
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
@@ -4009,7 +4009,7 @@ int remote_rediscover(void) {
 
 	for (i = 0; (i < membership->num_entries) && (rc == 0); i++) {
 
-		/* Don't send a set debug level message to myself. */
+		/* Don't send a rediscover message to myself. */
 		if (memcmp(&membership->node[i], my_nodeid, sizeof(ece_nodeid_t)) != 0) {
 
 			rta = engine_alloc(sizeof(*rta));
@@ -4215,7 +4215,7 @@ int remote_shutdown() {
 	int i;
 	STATIC_LIST_DECL(shutdown_list);
 	shutdown_thread_args_t * sta;
-	int response_count = 0;
+	uint response_count = 0;
 	STATIC_LIST_DECL(callback_list);
 	pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 	pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
@@ -4354,7 +4354,7 @@ int remote_can_activate(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_ACTIVATE, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -4367,7 +4367,7 @@ int remote_activate(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_ACTIVATE, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -4380,7 +4380,7 @@ int remote_can_deactivate(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_CAN_DEACTIVATE, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
@@ -4393,7 +4393,7 @@ int remote_deactivate(object_handle_t thing) {
 	rc = one_handle_arg(EVMS_DEACTIVATE, thing);
 
 	LOG_PROC_EXIT_INT(rc);
-	return rc;			
+	return rc;
 }
 
 
