@@ -25,7 +25,6 @@
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
-#include <csm_funcs.h>
 
 #include "fullengine.h"
 #include "shrink.h"
@@ -696,7 +695,7 @@ static int do_container_shrink(storage_container_t * con,
 		 * must obey the rule of having everything in the same
 		 * disk group.
 		 */
-		if (con->plugin->id == CSM_PLUGIN_ID) {
+		if (con->plugin->id == EVMS_CSM_PLUGIN_ID) {
 			disk_group = NULL;
 		} else {
 			disk_group = con->disk_group;
