@@ -48,7 +48,6 @@ static task_name_t task_names[] = {
 	{EVMS_Task_Create,             "EVMS_Task_Create"},
 	{EVMS_Task_Create_Container,   "EVMS_Task_Create_Container"},
 	{EVMS_Task_Assign_Plugin,      "EVMS_Task_Assign_Plugin"},
-	{EVMS_Task_Expand_Container,   "EVMS_Task_Expand_Container"},
 	{EVMS_Task_Set_Info,           "EVMS_Task_Set_Info"},
 	{EVMS_Task_Expand,             "EVMS_Task_Expand"},
 	{EVMS_Task_Shrink,             "EVMS_Task_Shrink"},
@@ -56,10 +55,8 @@ static task_name_t task_names[] = {
 	{EVMS_Task_Move,               "EVMS_Task_Move"},
 	{EVMS_Task_mkfs,               "EVMS_Task_mkfs"},
 	{EVMS_Task_fsck,               "EVMS_Task_fsck"},
-	{EVMS_Task_defrag,             "EVMS_Task_defrag"},
 	{EVMS_Task_Message,            "EVMS_Task_Message"},
 	{EVMS_Task_Add_Feature,        "EVMS_Task_Add_Feature"},
-	{EVMS_Task_Shrink_Container,   "EVMS_Task_Shrink_Container"},
 	{EVMS_Task_Set_Container_Info, "EVMS_Task_Set_Container_Info"}
 };
 
@@ -111,11 +108,17 @@ static inline void FreeTaskMemory(task_context_t * task) {
 		/*
 		 * Avoiding memory leaks is of great importance here.
 		 */
+		if (task->acceptable_objects != NULL) {
+			/*
+			 * Don't free the objects in the list as they are on
+			 * someone else's list.
+			 */
+			destroy_list(task->acceptable_objects);
+		}
 		if (task->selected_objects != NULL) {
 			/*
-			 * Destroy the parameter list. Don't free the
-			 * objects in the list as they are on someone
-			 * else's list.
+			 * Don't free the objects in the list as they are on
+			 * someone else's list.
 			 */
 			destroy_list(task->selected_objects);
 		}
@@ -251,7 +254,7 @@ static int is_valid_expand_object(storage_object_t * obj) {
 
 		parent_count = list_count(top_object->parent_objects);
 
-		while (parent_count > 0) {
+		while ((parent_count) > 0 && (top_object->consuming_container == NULL)) {
 			top_object = first_thing(top_object->parent_objects, NULL);
 
 			if (top_object != NULL) {
@@ -259,15 +262,18 @@ static int is_valid_expand_object(storage_object_t * obj) {
 			}
 		}
 
-		if (parent_count <= 1) {
-			sector_count_t max_delta_size = -1;
-
-			rc = get_object_expand_points(top_object, &max_delta_size, &expand_points);
+		if (top_object->consuming_container != NULL) {
+			rc = get_container_expand_points(top_object->consuming_container, &expand_points);
 
 		} else {
-			if (parent_count > 1) {
-				LOG_ERROR("Object %s cannot be expanded because it has multiple parents.\n", obj->name);
-				rc = EINVAL;
+			if (parent_count <= 1) {
+				rc = get_object_expand_points(top_object, -1, &expand_points);
+
+			} else {
+				if (parent_count > 1) {
+					LOG_ERROR("Object %s cannot be expanded because it has multiple parents.\n", obj->name);
+					rc = EINVAL;
+				}
 			}
 		}
 	}
@@ -316,7 +322,7 @@ static int is_valid_shrink_object(storage_object_t * obj) {
 
 		parent_count = list_count(top_object->parent_objects);
 
-		while (parent_count > 0) {
+		while ((parent_count > 0) && (top_object->consuming_container == NULL)) {
 			top_object = first_thing(top_object->parent_objects, NULL);
 
 			if (top_object != NULL) {
@@ -324,15 +330,18 @@ static int is_valid_shrink_object(storage_object_t * obj) {
 			}
 		}
 
-		if (parent_count <= 1) {
-			sector_count_t max_delta_size = -1;
-
-			rc = get_object_shrink_points(top_object, &max_delta_size, &shrink_points);
+		if (top_object->consuming_container != NULL) {
+			rc = get_container_shrink_points(top_object->consuming_container, &shrink_points);
 
 		} else {
-			if (parent_count > 1) {
-				LOG_ERROR("Object %s cannot be shrunk because it has multiple parents.\n", obj->name);
-				rc = EINVAL;
+			if (parent_count <= 1) {
+				rc = get_object_shrink_points(top_object, -1, &shrink_points);
+
+			} else {
+				if (parent_count > 1) {
+					LOG_ERROR("Object %s cannot be shrunk because it has multiple parents.\n", obj->name);
+					rc = EINVAL;
+				}
 			}
 		}
 	}
@@ -418,8 +427,8 @@ static int isa_valid_task(task_action_t           action,
 			break;
 
 		case CONTAINER:
-			if ((action == EVMS_Task_Expand_Container) ||
-			    (action == EVMS_Task_Shrink_Container) ||
+			if ((action == EVMS_Task_Expand) ||
+			    (action == EVMS_Task_Shrink) ||
 			    (action == EVMS_Task_Set_Container_Info) ||
 			    (action >= EVMS_Task_Plugin_Function)) {
 
@@ -435,7 +444,6 @@ static int isa_valid_task(task_action_t           action,
 		case VOLUME:
 			if ((action == EVMS_Task_Expand) ||
 			    (action == EVMS_Task_fsck) ||
-			    (action == EVMS_Task_defrag) ||
 			    (action == EVMS_Task_Set_Info) ||
 			    (action >= EVMS_Task_Plugin_Function)) {
 
@@ -475,8 +483,6 @@ static int isa_valid_task(task_action_t           action,
 				break;
 
 			case EVMS_Task_Set_Container_Info:
-			case EVMS_Task_Expand_Container:
-			case EVMS_Task_Shrink_Container:
 				break;
 
 			case EVMS_Task_Set_Info:
@@ -489,7 +495,9 @@ static int isa_valid_task(task_action_t           action,
 				break;
 
 			case EVMS_Task_Shrink:
-				rc = is_valid_shrink_object(obj);
+				if (obj != NULL) {
+					rc = is_valid_shrink_object(obj);
+				}
 				break;
 
 			case EVMS_Task_Slide:
@@ -504,9 +512,6 @@ static int isa_valid_task(task_action_t           action,
 			case EVMS_Task_fsck:
 				break;
 
-			case EVMS_Task_defrag:
-				break;
-
 			case EVMS_Task_Message:
 				break;
 
@@ -615,13 +620,13 @@ int evms_create_task(engine_handle_t thing,
 
 					count = GetTaskOptionsCount(task);
 
-					if (count > 1) {
-						size = sizeof(option_desc_array_t) +
-						       (sizeof(option_descriptor_t) * (count - 1));
-					} else {
-						size = sizeof(option_desc_array_t);
+					if (count < 0) {
+						count = 0;
 					}
 
+					size = sizeof(option_desc_array_t) +
+					       (sizeof(option_descriptor_t) * count);
+
 					task->option_descriptors = engine_alloc(size);
 
 					if (task->option_descriptors != NULL) {
@@ -675,7 +680,7 @@ int evms_create_task(engine_handle_t thing,
 						}
 
 					} else {
-						LOG_WARNING("Allocation of option descriptor array failed.\n");
+						LOG_CRITICAL("Allocation of option descriptor array failed.\n");
 						FreeTaskMemory(task);
 						rc = ENOMEM;
 					}
@@ -697,90 +702,6 @@ int evms_create_task(engine_handle_t thing,
 }
 
 
-/*
- * This function does the work for the EVMS_Task_Expand_Container task.
- * The code is broken out into a separate function to keep the switch
- * statement in evms_ivoke_task() tidy.
- */
-static int do_expand_container_task(handle_array_t * selected_ha,
-				    task_context_t * task,
-				    option_array_t * option_array) {
-	int rc = 0;
-	int i;
-	int final_rc = 0;
-
-	LOG_PROC_ENTRY();
-
-
-	/*
-	 * evms_transfer() can only handle transferring one object at a time.
-	 * Issue an evms_transfer() for each object.
-	 */
-
-	for (i = 0; i < selected_ha->count; i++) {
-		rc = evms_transfer(selected_ha->handle[i],
-				   task->plugin->app_handle,
-				   task->container->app_handle,
-				   option_array);
-
-		if (rc != 0) {
-
-			/* Save the first non-zero error code. */
-			if (final_rc == 0) {
-				final_rc = rc;
-			}
-		}
-	}
-
-	rc = final_rc;
-
-	LOG_PROC_EXIT_INT(rc);
-	return rc;
-}
-
-
-/*
- * This function does the work for the EVMS_Task_Shrink_Container task.
- * The code is broken out into a separate function to keep the switch
- * statement in evms_invoke_task() tidy.
- */
-static int do_shrink_container_task(handle_array_t * selected_ha,
-				    task_context_t * task,
-				    option_array_t * option_array) {
-	int rc = 0;
-	int i;
-	int final_rc = 0;
-
-	LOG_PROC_ENTRY();
-
-
-	/*
-	 * evms_transfer() can only handle transferring one object at a time.
-	 * Issue an evms_transfer() for each object.
-	 */
-
-	for (i = 0; i < selected_ha->count; i++) {
-		rc = evms_transfer(selected_ha->handle[i],
-				   0,
-				   0,
-				   option_array);
-
-		if (rc != 0) {
-
-			/* Save the first non-zero error code. */
-			if (final_rc == 0) {
-				final_rc = rc;
-			}
-		}
-	}
-
-	rc = final_rc;
-
-	LOG_PROC_EXIT_INT(rc);
-	return rc;
-}
-
-
 /*
  *
  *   int evms_invoke_task(task_handle_t handle, handle_array_t * * resulting_objects)
@@ -871,7 +792,8 @@ int evms_invoke_task(task_handle_t      handle,
 
 							if (rc == 0) {
 								if (resulting_objects != NULL) {
-									*resulting_objects = alloc_app_struct(sizeof(handle_array_t), NULL);
+									*resulting_objects = alloc_app_struct(sizeof(handle_array_t) + sizeof(object_handle_t),
+													      NULL);
 
 									if (*resulting_objects != NULL) {
 										(*resulting_objects)->count = 1;
@@ -904,20 +826,6 @@ int evms_invoke_task(task_handle_t      handle,
 						}
 						break;
 
-					case EVMS_Task_Expand_Container:
-
-						rc = do_expand_container_task(selected_ha,
-									      task,
-									      option_array);
-						break;
-
-					case EVMS_Task_Shrink_Container:
-
-						rc = do_shrink_container_task(selected_ha,
-									      task,
-									      option_array);
-						break;
-
 					case EVMS_Task_Set_Info:
 
 						if (task->object != NULL) {
@@ -944,16 +852,31 @@ int evms_invoke_task(task_handle_t      handle,
 									 selected_ha,
 									 option_array);
 						
-						} else {
+						} else if (task->container!= NULL) {
+							rc = evms_expand(task->container->app_handle,
+									 selected_ha,
+									 option_array);
+						
+						} else{
 							rc = EINVAL;
 						}
 						break;
 
 					case EVMS_Task_Shrink:
 
-						rc = evms_shrink(task->object->app_handle,
-								 selected_ha,
-								 option_array);
+						if (task->object != NULL) {
+							rc = evms_shrink(task->object->app_handle,
+									 selected_ha,
+									 option_array);
+
+						} else if (task->container!= NULL) {
+							rc = evms_shrink(task->container->app_handle,
+									 selected_ha,
+									 option_array);
+						
+						} else{
+							rc = EINVAL;
+						}
 						break;
 
 					case EVMS_Task_mkfs:
@@ -981,12 +904,6 @@ int evms_invoke_task(task_handle_t      handle,
 							       option_array);
 						break;
 
-					case EVMS_Task_defrag:
-
-						rc = evms_defrag(task->volume->app_handle,
-								 option_array);
-						break;
-
 					case EVMS_Task_Slide:
 					case EVMS_Task_Move:
 						LOG_WARNING("Task action %d is not supported yet.\n", task->action);
@@ -1033,7 +950,8 @@ int evms_invoke_task(task_handle_t      handle,
 				}
 			}
 
-			free_option_array(option_array);
+			free_option_array_contents(option_array);
+			engine_free(option_array);
 
 		} else {
 			LOG_CRITICAL("Error allocating memory for building the option array.\n");
@@ -1227,11 +1145,7 @@ static int make_user_declined_handle_array(list_anchor_t               declined_
 	count = list_count(declined_objects_list);
 
 	LOG_DEBUG("Number of objects in the list:  %d\n", count);
-	if (count > 1) {
-		size = sizeof(declined_handle_array_t) + ((count -1) * sizeof(declined_handle_t));
-	} else {
-		size = sizeof(declined_handle_array_t);
-	}
+	size = sizeof(declined_handle_array_t) + (count * sizeof(declined_handle_t));
 
 	*dha = alloc_app_struct(size, NULL);
 	if (*dha != NULL) {
@@ -1711,7 +1625,7 @@ static boolean is_acceptable_object(common_header_t * thing,
 	LOG_PROC_ENTRY();
 
 	/* Check if the object is in the acceptable_objects list. */
-	el = find_in_list(acceptable_objects, thing, NULL);
+	el = find_in_list(acceptable_objects, thing, NULL, NULL);
 
 	/*
 	 * If the object is not found in the acceptable_object list, build a
