@@ -3153,6 +3153,12 @@ static int can_unmount(object_handle_t volume_handle,
 		return EINVAL;
 	}
 
+	if (is_mounted_as_swap(vol->name)) {
+		LOG(log_level, "Volume \"%s\" is mounted as swap.\n", vol->name);
+		LOG_PROC_EXIT_INT(EINVAL);
+		return EINVAL;
+	}
+
 	LOG_PROC_EXIT_INT(rc);
 	return rc;
 }
