@@ -61,7 +61,7 @@ static evms_version_t prog_version = {major:      MAJOR_VERSION,
 				      minor:      MINOR_VERSION,
 				      patchlevel: PATCH_LEVEL};
 
-static unsigned char msg_buf[2048];
+static char msg_buf[2048];
 
 static inline void log_buffer(void * in_buff, uint len) {
 
@@ -69,11 +69,11 @@ static inline void log_buffer(void * in_buff, uint len) {
 	int byte_count = 0;
 
 	unsigned char * byte = (unsigned char *) in_buff;
-	unsigned char * p = msg_buf;
+	char * p = msg_buf;
 
 	for (i = 0; i < len; i++) {
 		sprintf(p, "%02x", *byte);
-		p += strlen(p);	
+		p += strlen(p);
 		byte++;
 		byte_count++;
 		if (byte_count % 16 == 0) {
@@ -104,7 +104,7 @@ static void * get_msg(uint * cmd, size_t * size, void * buffer) {
 	size_t bytes_read;
 
 	LOG_PROC_ENTRY();
-			
+
 	do {
 		LOG_DEBUG("Request to read %d bytes from stdin.\n", sizeof(msg_hdr));
 		bytes_read = read(0, &msg_hdr, sizeof(msg_hdr));
@@ -168,7 +168,7 @@ static void put_msg(uint cmd, size_t size, void * message) {
 	size_t bytes_written;
 
 	LOG_PROC_ENTRY();
-			
+
 	LOG_DEBUG("Command: %#x (%s %s)  Size: %u  Message: %p\n",
 		  cmd, msg_cmd_name(cmd), (cmd & COMMAND_RESPONSE) ? "response" : "request", size, message);
 
@@ -207,7 +207,7 @@ static void worker_get_engine_api_version(void) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_sizeof_host_to_net(&size, evms_version_f, engine_version.major, engine_version.minor, engine_version.patchlevel);
 
 	return_buf = calloc(1, size);
@@ -221,7 +221,7 @@ static void worker_get_engine_api_version(void) {
 
 		free(return_buf);
 	}
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -238,7 +238,7 @@ static int message_callback(char   * message_text,
 	int dummy;
 
 	LOG_PROC_ENTRY();
-			
+
 	rc = evms_sizeof_host_to_net(&size, user_message_args_f, message_text, answer, choices);
 	LOG_DEBUG("Flat user message is of size %u.\n", size);
 	send_buf = calloc(1, size);
@@ -297,7 +297,7 @@ static int progress_callback(progress_t * progress) {
 	void * reply;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_sizeof_host_to_net(&size, user_progress_args_f, progress);
 
 	send_buf = calloc(1, size);
@@ -318,7 +318,7 @@ static int progress_callback(progress_t * progress) {
 			}
 
 		} while (cmd != (PROGRESS | COMMAND_RESPONSE));
-				
+
 		if (reply != NULL) {
 			evms_net_to_host(reply, user_progress_rets_f,
 					 &rc,
@@ -347,7 +347,7 @@ static void status_callback(char * message) {
 	LOG_PROC_ENTRY();
 
 	LOG_DEBUG("Status is: %s\n", message);
-			
+
 	/*
 	 * Status is a character string.  It goes out on the wire without any
 	 * conversion to network byte order.
@@ -369,7 +369,7 @@ static void status_callback(char * message) {
 	if (reply != NULL) {
 		free(reply);
 	}
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -392,7 +392,7 @@ static void worker_open_engine(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
      	evms_net_to_host(msg, evms_open_engine_args_f,
 			 &node_name,
 			 &mode,
@@ -422,7 +422,7 @@ static void worker_open_engine(void * msg) {
 	evms_host_to_net(&net_rc, evms_open_engine_rets_f, rc);
 
 	put_msg(EVMS_OPEN_ENGINE | COMMAND_RESPONSE, sizeof(net_rc), &net_rc);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -437,7 +437,7 @@ static void worker_get_plugin_list(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_plugin_list_args_f,
 			 &type,
 			 &flags);
@@ -477,7 +477,7 @@ static void worker_get_plugin_list(void * msg) {
 	}
 
 	evms_free(ha);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -491,7 +491,7 @@ static void worker_get_plugin_by_ID(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_plugin_by_ID_args_f,
 			 &plugin_ID);
 
@@ -540,7 +540,7 @@ static void worker_get_plugin_by_name(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	/*
 	 * Strings get passed as-is on the wire.  No need to extract
 	 * the plugin_name from the msg.  the msg is the name.
@@ -591,7 +591,7 @@ static void worker_changes_pending() {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
         rc = evms_changes_pending(&result, &changes);
 
 	if (rc == 0) {
@@ -629,7 +629,7 @@ static void worker_changes_pending() {
 	}
 
 	evms_free(changes);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -641,7 +641,7 @@ static void worker_set_debug_level(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_set_debug_level_args_f,
 			 &level);
 
@@ -662,7 +662,7 @@ static void worker_commit_changes() {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
         rc = evms_commit_changes();
 
 	evms_host_to_net(&net_rc, evms_commit_changes_rets_f,
@@ -678,19 +678,19 @@ static void worker_close_engine(void) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	rc = evms_close_engine();
 
 	evms_host_to_net(&net_rc, evms_close_engine_rets_f, rc);
 
 	put_msg(EVMS_CLOSE_ENGINE | COMMAND_RESPONSE, sizeof(net_rc), &net_rc);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
 
 static void worker_get_expand_points(void * msg) {
-	
+
 	int rc;
 	object_handle_t thing;
 	expand_handle_array_t * expand_points = NULL;
@@ -698,7 +698,7 @@ static void worker_get_expand_points(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_expand_points_args_f,
 			 &thing);
 
@@ -743,7 +743,7 @@ static void worker_get_expand_points(void * msg) {
 
 
 static void worker_expand(void * msg) {
-	
+
 	object_handle_t thing;
 	handle_array_t * objects = NULL;
 	option_array_t * options = NULL;
@@ -751,7 +751,7 @@ static void worker_expand(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_expand_args_f,
 			 &thing,
 			 &objects,
@@ -760,7 +760,7 @@ static void worker_expand(void * msg) {
 	rc = evms_expand(thing, objects, options);
 
 	evms_host_to_net(&net_rc, evms_expand_rets_f, rc);
-		
+
 	put_msg(EVMS_EXPAND | COMMAND_RESPONSE, sizeof(net_rc), &net_rc);
 
 	evms_free(objects);
@@ -771,7 +771,7 @@ static void worker_expand(void * msg) {
 
 
 static void worker_get_shrink_points(void * msg) {
-	
+
 	int rc;
 	object_handle_t thing;
 	shrink_handle_array_t * shrink_points = NULL;
@@ -779,7 +779,7 @@ static void worker_get_shrink_points(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_shrink_points_args_f,
 			 &thing);
 
@@ -824,7 +824,7 @@ static void worker_get_shrink_points(void * msg) {
 
 
 static void worker_shrink(void * msg) {
-	
+
 	object_handle_t thing;
 	handle_array_t * objects = NULL;
 	option_array_t * options = NULL;
@@ -832,7 +832,7 @@ static void worker_shrink(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_shrink_args_f,
 			 &thing,
 			 &objects,
@@ -841,7 +841,7 @@ static void worker_shrink(void * msg) {
 	rc = evms_shrink(thing, objects, options);
 
 	evms_host_to_net(&net_rc, evms_shrink_rets_f, rc);
-		
+
 	put_msg(EVMS_SHRINK | COMMAND_RESPONSE, sizeof(net_rc), &net_rc);
 
 	evms_free(objects);
@@ -860,7 +860,7 @@ static void worker_get_handle_object_type(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_handle_object_type_args_f,
 			 &thing);
 
@@ -911,7 +911,7 @@ static void worker_get_info(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_info_args_f,
 			 &thing);
 
@@ -965,7 +965,7 @@ static void worker_get_extended_info(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_extended_info_args_f,
 			 &thing,
 			 &name);
@@ -1005,7 +1005,7 @@ static void worker_get_extended_info(void * msg) {
 	}
 
 	evms_free(eia);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -1018,7 +1018,7 @@ static void worker_set_info(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_set_info_args_f,
 			 &thing,
 			 &options);
@@ -1068,7 +1068,7 @@ static void worker_get_feature_list(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_feature_list_args_f,
 			 &thing);
 
@@ -1106,7 +1106,7 @@ static void worker_get_feature_list(void * msg) {
 	}
 
 	evms_free(ha);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -1122,7 +1122,7 @@ static void worker_create(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_create_args_f,
 			 &plugin,
 			 &input_objects,
@@ -1164,13 +1164,13 @@ static void worker_create(void * msg) {
 	evms_free(input_objects);
 	evms_free(options);
 	evms_free(output_objects);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
 
 static void worker_assign(void * msg) {
-	
+
 	object_handle_t  object;
 	plugin_handle_t  plugin;
 	option_array_t * options = NULL;
@@ -1178,7 +1178,7 @@ static void worker_assign(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_assign_args_f,
 			 &object,
 			 &plugin,
@@ -1210,7 +1210,7 @@ static void worker_get_object_list(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_object_list_args_f,
 			 &object_type,
 			 &data_type,
@@ -1253,7 +1253,7 @@ static void worker_get_object_list(void * msg) {
 	}
 
 	evms_free(ha);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -1267,7 +1267,7 @@ static void worker_get_plugin_functions(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_plugin_functions_args_f,
 			 &thing);
 
@@ -1306,7 +1306,7 @@ static void worker_get_plugin_functions(void * msg) {
 	}
 
 	evms_free(actions);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -1321,7 +1321,7 @@ static void worker_do_plugin_function(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_do_plugin_function_args_f,
 			 &thing,
 			 &action,
@@ -1350,7 +1350,7 @@ static void worker_create_volume(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_create_volume_args_f,
 			 &object,
 			 &name);
@@ -1374,7 +1374,7 @@ static void worker_set_volume_name(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_set_volume_name_args_f,
 			 &object,
 			 &name);
@@ -1398,7 +1398,7 @@ static void worker_convert_to_evms_volume(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_convert_to_evms_volume_args_f,
 			 &object,
 			 &name);
@@ -1423,7 +1423,7 @@ static void worker_add_feature_to_volume(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_add_feature_to_volume_args_f,
 			 &volume,
 			 &feature,
@@ -1451,7 +1451,7 @@ static void worker_mkfs(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_mkfs_args_f,
 			 &volume,
 			 &feature,
@@ -1478,7 +1478,7 @@ static void worker_fsck(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_fsck_args_f,
 			 &volume,
 			 &options);
@@ -1507,7 +1507,7 @@ static void worker_get_volume_list(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_volume_list_args_f,
 			 &fsim_handle,
 			 &disk_group,
@@ -1547,7 +1547,7 @@ static void worker_get_volume_list(void * msg) {
 	}
 
 	evms_free(ha);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -1561,7 +1561,7 @@ static void worker_mount(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_mount_args_f,
 			 &volume,
 			 &mount_point,
@@ -1588,7 +1588,7 @@ static void worker_remount(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_remount_args_f,
 			 &volume,
 			 &options);
@@ -1616,7 +1616,7 @@ static void worker_create_container(void * msg) {
 	u_int32_t response_buf[2];
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_create_container_args_f,
 			 &plugin,
 			 &input_objects,
@@ -1638,7 +1638,7 @@ static void worker_create_container(void * msg) {
 
 
 static void worker_get_container_list(void * msg) {
-	
+
 	object_handle_t          plugin_handle;
 	object_handle_t          disk_group;
 	container_search_flags_t flags;
@@ -1648,7 +1648,7 @@ static void worker_get_container_list(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_container_list_args_f,
 			 &plugin_handle,
 			 &disk_group,
@@ -1689,7 +1689,7 @@ static void worker_get_container_list(void * msg) {
 	}
 
 	evms_free(ha);
-	
+
 	LOG_PROC_EXIT_VOID();
 }
 
@@ -1703,7 +1703,7 @@ static void worker_create_task(void * msg) {
 	u_int32_t response_buf[2];
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_create_task_args_f,
 			 &thing,
 			 &action);
@@ -1729,7 +1729,7 @@ static void worker_invoke_task(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_invoke_task_args_f,
 			 &task);
 
@@ -1783,7 +1783,7 @@ static void worker_get_task_action(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_task_action_args_f,
 			 &handle);
 
@@ -1834,7 +1834,7 @@ static void worker_get_acceptable_objects(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_acceptable_objects_args_f,
 			 &task);
 
@@ -1887,7 +1887,7 @@ static void worker_get_selected_objects(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_selected_objects_args_f,
 			 &task);
 
@@ -1941,7 +1941,7 @@ static void worker_get_selected_object_limits(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_selected_object_limits_args_f,
 			 &task);
 
@@ -1996,7 +1996,7 @@ static void worker_set_selected_objects(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_set_selected_objects_args_f,
 			 &task,
 			 &selected_object_list);
@@ -2053,7 +2053,7 @@ static void worker_get_option_count(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_option_count_args_f,
 			 &task);
 
@@ -2105,7 +2105,7 @@ static void worker_get_option_descriptor(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_option_descriptor_args_f,
 			 &task,
 			 &option);
@@ -2164,7 +2164,7 @@ static void worker_set_option_value(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	memset(&value, 0, sizeof(value_t));
 
 	evms_net_to_host(msg, evms_set_option_value_args_f,
@@ -2241,7 +2241,7 @@ static void worker_get_option_descriptor_by_name(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_get_option_descriptor_by_name_args_f,
 			 &task,
 			 &option);
@@ -2300,7 +2300,7 @@ static void worker_set_option_value_by_name(void * msg) {
 	void * return_buf = NULL;
 
 	LOG_PROC_ENTRY();
-			
+
 	memset(&value, 0, sizeof(value_t));
 
 	evms_net_to_host(msg, evms_set_option_value_by_name_args_f,
@@ -2374,7 +2374,7 @@ static void worker_mark_for_rediscover(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_mark_for_rediscover_args_f,
 			 &name);
 
@@ -2395,7 +2395,7 @@ static void worker_rediscover(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	/*
 	 * Don't send back status.  Mutiple nodes may be rediscovering at the
 	 * same time.  Mixed status messages from all the nodes would be
@@ -2424,7 +2424,7 @@ static void worker_one_handle_arg(uint cmd, void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, object_handle_f,
 			 &thing);
 
@@ -2560,7 +2560,7 @@ static void worker_two_handle_arg(uint cmd, void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, object_handle_f object_handle_f,
 			 &thing1,
 			 &thing2);
@@ -2604,7 +2604,7 @@ static void worker_metadata_backup(void * msg) {
 	u_int32_t net_rc;
 
 	LOG_PROC_ENTRY();
-			
+
 	evms_net_to_host(msg, evms_metadata_backup_args_f,
 			 &dir);
 
@@ -2665,7 +2665,7 @@ static int worker_engine_read(void * msg) {
 			}
 		}
 	}
-	
+
 	if (rc == 0) {
 		evms_host_to_net(return_buf, rets_format,
 				 rc,
@@ -2747,7 +2747,7 @@ static void dispatch_commands(void) {
 	void * msg;
 
 	LOG_PROC_ENTRY();
-			
+
 	while (TRUE) {
 
 		msg = get_msg(&cmd, &size, NULL);
