@@ -113,7 +113,7 @@ typedef struct ui_callbacks_s {
 typedef struct handle_array_s {
 	uint            count;
 	object_handle_t handle[0];
-} handle_array_t;
+} __attribute__ ((packed)) handle_array_t;
 #define handle_array_struct_f "c[" object_handle_f "]"
 #define handle_array_c 'H'
 #define handle_array_f "H"
@@ -137,7 +137,7 @@ typedef struct plugin_info_s {
 	char          * long_name;
 	char          * oem_name;
 	boolean         supports_containers;
-} plugin_info_t;
+} __attribute__ ((packed)) plugin_info_t;
 #define plugin_info_f   \
 	object_handle_f \
 	plugin_id_f     \
@@ -170,7 +170,7 @@ typedef struct storage_object_info_s {
 	sector_count_t          size;			/* Size of the storage object in sectors */
 	geometry_t              geometry;		/* Optional object geometry */
 	object_handle_t         volume;			/* Volume to which this object belongs */
-} storage_object_info_t;
+} __attribute__ ((packed)) storage_object_info_t;
 #define storage_object_info_f   \
 	object_handle_f         \
 	object_type_f           \
@@ -203,7 +203,7 @@ typedef struct storage_container_info_s {
 	handle_array_t        * objects_produced;	/* Handles of objects produced */
 							/* by this container */
 	sector_count_t          size;			/* Size of the container */
-} storage_container_info_t;
+} __attribute__ ((packed)) storage_container_info_t;
 #define storage_container_info_f \
 	object_handle_f          \
 	object_handle_f          \
@@ -234,7 +234,7 @@ typedef struct logical_volume_info_s {
 	u_int32_t               flags;			/* Defined by VOLFLAG_???? defines */
 	char                    name[EVMS_VOLUME_NAME_SIZE+1];
 	char                    dev_node[EVMS_VOLUME_NAME_SIZE+1];
-} logical_volume_info_t;
+} __attribute__ ((packed)) logical_volume_info_t;
 #define logical_volume_info_f \
 	object_handle_f       \
 	u_int32_f             \
@@ -271,7 +271,7 @@ typedef union {
 typedef struct handle_object_info_s {
 	object_type_t   type;
 	object_info_t   info;
-} handle_object_info_t;
+} __attribute__ ((packed)) handle_object_info_t;
 #define handle_object_info_c 'I'
 #define handle_object_info_f "I"
 
@@ -282,7 +282,7 @@ typedef struct handle_object_info_s {
 typedef struct expand_handle_s {
 	object_handle_t     object;
 	sector_count_t      max_expand_size;
-} expand_handle_t;
+} __attribute__ ((packed)) expand_handle_t;
 #define expand_handle_f \
 	object_handle_f \
 	sector_count_f
@@ -293,7 +293,7 @@ typedef struct expand_handle_s {
 typedef struct expand_handle_array_s {
 	uint                count;
 	expand_handle_t     expand_point[0];
-} expand_handle_array_t;
+} __attribute__ ((packed)) expand_handle_array_t;
 #define expand_handle_array_struct_f "c[" expand_handle_f "]"
 #define expand_handle_array_c 'E'
 #define expand_handle_array_f "E"
@@ -305,7 +305,7 @@ typedef struct expand_handle_array_s {
 typedef struct shrink_handle_s {
 	object_handle_t     object;
 	sector_count_t      max_shrink_size;
-} shrink_handle_t;
+} __attribute__ ((packed)) shrink_handle_t;
 #define shrink_handle_f \
 	object_handle_f \
 	sector_count_f
@@ -316,7 +316,7 @@ typedef struct shrink_handle_s {
 typedef struct shrink_handle_array_s {
 	uint                count;
 	shrink_handle_t     shrink_point[0];
-} shrink_handle_array_t;
+} __attribute__ ((packed)) shrink_handle_array_t;
 #define shrink_handle_array_struct_f "c[" shrink_handle_f "]"
 #define shrink_handle_array_c 'S'
 #define shrink_handle_array_f "S"
@@ -329,7 +329,7 @@ typedef struct change_record_s {
 	char          * name;
 	object_type_t   type;
 	u_int32_t       changes;
-} change_record_t;
+} __attribute__ ((packed)) change_record_t;
 #define change_record_f \
 	string_f	\
 	object_type_f   \
@@ -338,7 +338,7 @@ typedef struct change_record_s {
 typedef struct change_record_array_s {
 	uint            count;
 	change_record_t changes_pending[0];
-} change_record_array_t;
+} __attribute__ ((packed)) change_record_array_t;
 #define change_record_array_struct_f "c[" change_record_f "]"
 #define change_record_array_c 'R'
 #define change_record_array_f "R"
