@@ -36,10 +36,6 @@
 #define EVMS_VOLUME_NAME_SIZE           127
 #define evms_name_f			"x128"
 
-#define EVMS_IBM_OEM_ID                 8112    // could be anything, but used
-						// I=8, B=1, M=12
-#define EVMS_IBM_OEM_NAME		"IBM"
-
 #define EVMS_INITIAL_CRC                0xFFFFFFFF
 #define EVMS_MAGIC_CRC                  0x31415926
 
@@ -721,7 +717,7 @@ typedef struct node_list_s {
 	node_info_t     node_info[0];
 } __attribute__ ((packed)) node_list_t;
 #define node_list_f "C[" node_info_f "]"
-	
+
 
 /*
  * Handy macros for finding the min and max of two numbers.
