@@ -88,7 +88,7 @@ typedef struct function_info_s {
 	char          * help;		/* Full help text */
 					/* e.g. "Use this function to add a spare blah blah blah..." */
 	u_int32_t	flags;
-} function_info_t;
+} __attribute__ ((packed)) function_info_t;
 #define function_info_f \
 	task_action_f   \
 	string_f	\
@@ -103,7 +103,7 @@ typedef struct function_info_s {
 typedef struct function_info_array_s {
 	uint            count;
 	function_info_t info[0];
-} function_info_array_t;
+} __attribute__ ((packed)) function_info_array_t;
 #define function_info_array_struct_f "c[" function_info_f "]"
 #define function_info_array_c 'F'
 #define function_info_array_f "F"
@@ -116,7 +116,7 @@ typedef struct function_info_array_s {
 typedef struct declined_handle_s {
 	object_handle_t	handle;		/* Handle of object declined */
 	u_int32_t	reason;		/* Reason for being declined */
-} declined_handle_t;
+} __attribute__ ((packed)) declined_handle_t;
 #define declined_handle_f \
 	object_handle_f   \
 	u_int32_f
@@ -124,7 +124,7 @@ typedef struct declined_handle_s {
 typedef struct declined_handle_array_s {
 	u_int32_t		count;
 	declined_handle_t	declined[0];
-} declined_handle_array_t;
+} __attribute__ ((packed)) declined_handle_array_t;
 #define declined_handle_array_struct_f "C[" declined_handle_f "]"
 #define declined_handle_array_c 'N'
 #define declined_handle_array_f "N"
@@ -222,7 +222,7 @@ typedef struct key_value_pair_s {
 	value_type_t    type;		/* Value type */
 	u_int16_t	flags;		/* Flags (see below) */
 	value_t         value;		/* Union of basic data types */
-} key_value_pair_t;
+} __attribute__ ((packed)) key_value_pair_t;
 #define key_value_pair_f \
 	string_f         \
 	u_int16_f        \
@@ -245,7 +245,7 @@ typedef struct key_value_pair_s {
 typedef struct option_array_s {
 	u_int			count;
 	key_value_pair_t	option[0];
-} option_array_t;
+} __attribute__ ((packed)) option_array_t;
 #define option_array_struct_f "c[" key_value_pair_f "]"
 #define option_array_c 'O'
 #define option_array_f "O"
@@ -253,24 +253,24 @@ typedef struct option_array_s {
 typedef struct value_list_s {
 	u_int	count;
 	value_t	value[0];
-} value_list_t;
+} __attribute__ ((packed)) value_list_t;
 
 typedef struct value_range_s {
 	value_t	min;			/* Minimum value */
 	value_t	max;			/* Maximum value */
 	value_t	increment;		/* Step or increment for changes in-between */
-} value_range_t;
+} __attribute__ ((packed)) value_range_t;
 
 typedef union {
 	value_list_t	*list;		/* Array of values of the same type */
 	value_range_t	*range;		/* Range of values for numeric types */
-} value_collection_t;
+} __attribute__ ((packed)) value_collection_t;
 
 typedef struct group_info_s {
 	u_int32_t	group_number;	/* group number, 0 if not grouped */
 	u_int32_t	group_level;	/* possibly used for indenting, or sub fields */
 	char		*group_name;	/* name of group                              */
-} group_info_t;
+} __attribute__ ((packed)) group_info_t;
 #define group_info_f \
 	u_int32_f    \
 	u_int32_f    \
@@ -291,7 +291,7 @@ typedef struct option_descriptor_s {
 	value_collection_t        constraint;		/* Either a list or range of valid input values */
 	value_t                   value;		/* Initial/current value */
 	group_info_t              group;		/* Group information for display purposes */
-} option_descriptor_t;
+} __attribute__ ((packed)) option_descriptor_t;
 #define option_descriptor_c 'D'
 #define option_descriptor_f "D"
 
@@ -347,7 +347,7 @@ typedef struct extended_info_s {
 	value_collection_t      collection;	/* Either a list or range of values of value_type_t */
 	group_info_t            group;		/* Group information for display purposes */
 	u_int16_t               flags;		/* Extended info flags (defined below) */
-} extended_info_t;
+} __attribute__ ((packed)) extended_info_t;
 
 
 #define EVMS_EINFO_FLAGS_NO_UNIT_CONVERSION (1 << 0)	/* Don't convert unit measurements, e.g. I really */
@@ -358,7 +358,7 @@ typedef struct extended_info_s {
 typedef struct extended_info_array_s {
 	u_int32_t	count;		/* Count of extended_info_t structs in array */
 	extended_info_t	info[0];	/* Info descriptors */
-} extended_info_array_t;
+} __attribute__ ((packed)) extended_info_array_t;
 #define extended_info_array_c 'X'
 #define extended_info_array_f "X"
 
