@@ -89,9 +89,9 @@ static int allocate_shrink_option_descriptors( task_context_t * context )
 
         context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].flags = 0;
         context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].help = NULL;
-        SET_STRING( context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].name, BBR_SHRINK_BLOCKCOUNT_NAME );
-        SET_STRING( context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].tip,"The number of replacement blocks you wish to use for the expanded object." );
-        SET_STRING( context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].title, "Count" );
+        context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].name = EngFncs->engine_strdup( BBR_SHRINK_BLOCKCOUNT_NAME );
+        context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].tip = EngFncs->engine_strdup( _("The number of replacement blocks you wish to use for the expanded object.") );
+        context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].title = EngFncs->engine_strdup( _("Count") );
         context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].type = EVMS_Type_Unsigned_Int64;
         context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].unit = EVMS_Unit_None;
         context->option_descriptors->option[BBR_SHRINK_BLOCKCOUNT_INDEX].value.ui64 = 0;
@@ -331,7 +331,7 @@ static int get_acceptable_shrink_objects( task_context_t * context  )
                 LIST_FOR_EACH_SAFE(context->acceptable_objects, itr1, itr2, object) {
                     child = GET_BBR_CHILD( object );
                     if (child) {
-                        rc = child->plugin->functions.plugin->can_shrink(child, NULL,
+                        rc = child->plugin->functions.plugin->can_shrink(child, child->size,
                                                                          shrink_points);
                         if (rc) {
                             EngFncs->delete_element(itr1);
@@ -433,18 +433,18 @@ int BBR_GetInfo( storage_object_t  * object, char *name,  extended_info_array_t
 
             Info->count = BBR_INFO_COUNT;
 
-            SET_STRING( Info->info[BBR_INFO_NAME_INDEX].name, "Name" );
-            SET_STRING( Info->info[BBR_INFO_NAME_INDEX].title, "Name" );
-            SET_STRING( Info->info[BBR_INFO_NAME_INDEX].desc, "This is the name given to the storage object. It must be unique on the system.");
+            Info->info[BBR_INFO_NAME_INDEX].name = EngFncs->engine_strdup( "Name" );
+            Info->info[BBR_INFO_NAME_INDEX].title = EngFncs->engine_strdup( _("Name") );
+            Info->info[BBR_INFO_NAME_INDEX].desc = EngFncs->engine_strdup( _("This is the name given to the storage object. It must be unique on the system.") );
             Info->info[BBR_INFO_NAME_INDEX].type               = EVMS_Type_String;
             Info->info[BBR_INFO_NAME_INDEX].unit               = EVMS_Unit_None;
-            SET_STRING( Info->info[BBR_INFO_NAME_INDEX].value.s, object->name );
+            Info->info[BBR_INFO_NAME_INDEX].value.s = EngFncs->engine_strdup( object->name );
             Info->info[BBR_INFO_NAME_INDEX].collection_type    = EVMS_Collection_None;
             memset( &Info->info[BBR_INFO_NAME_INDEX].group, 0, sizeof(group_info_t));
 
-            SET_STRING( Info->info[BBR_INFO_SIZE_INDEX].name, "Size" );
-            SET_STRING( Info->info[BBR_INFO_SIZE_INDEX].title, "Size" );
-            SET_STRING( Info->info[BBR_INFO_SIZE_INDEX].desc, "This is the size in sectors of the storage object after reserving space for metadata.");
+            Info->info[BBR_INFO_SIZE_INDEX].name = EngFncs->engine_strdup( "Size" );
+            Info->info[BBR_INFO_SIZE_INDEX].title = EngFncs->engine_strdup( _("Size") );
+            Info->info[BBR_INFO_SIZE_INDEX].desc = EngFncs->engine_strdup( _("This is the size in sectors of the storage object after reserving space for metadata.") );
             Info->info[BBR_INFO_SIZE_INDEX].type               = EVMS_Type_Unsigned_Int64;
             Info->info[BBR_INFO_SIZE_INDEX].unit               = EVMS_Unit_Sectors;
             Info->info[BBR_INFO_SIZE_INDEX].value.ui64         = object->size;
@@ -452,27 +452,27 @@ int BBR_GetInfo( storage_object_t  * object, char *name,  extended_info_array_t
             memset( &Info->info[BBR_INFO_SIZE_INDEX].group, 0, sizeof(group_info_t));
             Info->info[BBR_INFO_SIZE_INDEX].flags |= EVMS_EINFO_FLAGS_NO_UNIT_CONVERSION;
 
-            SET_STRING( Info->info[BBR_INFO_BLKS_INDEX].name, "Reserve Blocks" );
-            SET_STRING( Info->info[BBR_INFO_BLKS_INDEX].title, "Blocks" );
-            SET_STRING( Info->info[BBR_INFO_BLKS_INDEX].desc, "This is the number of replacement blocks BBR is reserving for this storage object.");
+            Info->info[BBR_INFO_BLKS_INDEX].name = EngFncs->engine_strdup( "Reserve Blocks" );
+            Info->info[BBR_INFO_BLKS_INDEX].title = EngFncs->engine_strdup( _("Blocks") );
+            Info->info[BBR_INFO_BLKS_INDEX].desc = EngFncs->engine_strdup( _("This is the number of replacement blocks BBR is reserving for this storage object.") );
             Info->info[BBR_INFO_BLKS_INDEX].type               = EVMS_Type_Unsigned_Int64;
             Info->info[BBR_INFO_BLKS_INDEX].unit               = EVMS_Unit_None;
             Info->info[BBR_INFO_BLKS_INDEX].value.ui64         = pdata->replacement_blocks_needed;
             Info->info[BBR_INFO_BLKS_INDEX].collection_type    = EVMS_Collection_None;
             memset( &Info->info[BBR_INFO_BLKS_INDEX].group, 0, sizeof(group_info_t));
 
-            SET_STRING( Info->info[BBR_INFO_BLKSZ_INDEX].name, "Block Size" );
-            SET_STRING( Info->info[BBR_INFO_BLKSZ_INDEX].title, "Block Size" );
-            SET_STRING( Info->info[BBR_INFO_BLKSZ_INDEX].desc, "This value tells you the size of a replacement block.");
+            Info->info[BBR_INFO_BLKSZ_INDEX].name = EngFncs->engine_strdup( "Block Size" );
+            Info->info[BBR_INFO_BLKSZ_INDEX].title = EngFncs->engine_strdup( _("Block Size") );
+            Info->info[BBR_INFO_BLKSZ_INDEX].desc = EngFncs->engine_strdup( _("This value tells you the size of a replacement block.") );
             Info->info[BBR_INFO_BLKSZ_INDEX].type               = EVMS_Type_Unsigned_Int64;
             Info->info[BBR_INFO_BLKSZ_INDEX].unit               = EVMS_Unit_None;
             Info->info[BBR_INFO_BLKSZ_INDEX].value.ui64         = pdata->block_size;
             Info->info[BBR_INFO_BLKSZ_INDEX].collection_type    = EVMS_Collection_None;
             memset( &Info->info[BBR_INFO_BLKSZ_INDEX].group, 0, sizeof(group_info_t));
 
-            SET_STRING( Info->info[BBR_INFO_TBLSZ_INDEX].name, "Table Size" );
-            SET_STRING( Info->info[BBR_INFO_TBLSZ_INDEX].title, "Size of BBR table" );
-            SET_STRING( Info->info[BBR_INFO_TBLSZ_INDEX].desc, "This is the number of sectors being used by the BBR remapping table.");
+            Info->info[BBR_INFO_TBLSZ_INDEX].name = EngFncs->engine_strdup( "Table Size" );
+            Info->info[BBR_INFO_TBLSZ_INDEX].title = EngFncs->engine_strdup( _("Size of BBR table") );
+            Info->info[BBR_INFO_TBLSZ_INDEX].desc = EngFncs->engine_strdup( _("This is the number of sectors being used by the BBR remapping table.") );
             Info->info[BBR_INFO_TBLSZ_INDEX].type               = EVMS_Type_Unsigned_Int64;
             Info->info[BBR_INFO_TBLSZ_INDEX].unit               = EVMS_Unit_Sectors;
             Info->info[BBR_INFO_TBLSZ_INDEX].value.ui64         = pdata->bbr_table_size_in_sectors;
@@ -537,57 +537,59 @@ int BBR_GetPluginInfo( char * descriptor_name, extended_info_array_t * * info )
                 my_plugin_record->required_plugin_api_version.plugin.minor,
                 my_plugin_record->required_plugin_api_version.plugin.patchlevel );
 
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].name, "Short Name" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].title, "Short Name" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].desc, "A short name given to this plugin.");
+        Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].name = EngFncs->engine_strdup( "Short Name" );
+        Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].title = EngFncs->engine_strdup( _("Short Name") );
+        Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].desc = EngFncs->engine_strdup( _("A short name given to this plug-in") );
         Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].type               = EVMS_Type_String;
         Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].unit               = EVMS_Unit_None;
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].value.s, my_plugin_record->short_name );
+        Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].value.s = EngFncs->engine_strdup( my_plugin_record->short_name );
         Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].collection_type    = EVMS_Collection_None;
         memset( &Info->info[BBR_PLUGIN_INFO_SNAME_INDEX].group, 0, sizeof(group_info_t));
 
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].name, "Long Name" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].title, "Long Name" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].desc, "A long name given to this plugin.");
+        Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].name = EngFncs->engine_strdup( "Long Name" );
+        Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].title = EngFncs->engine_strdup( _("Long Name") );
+        Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].desc = EngFncs->engine_strdup( _("A longer, more descriptive name for this plug-in") );
         Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].type               = EVMS_Type_String;
         Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].unit               = EVMS_Unit_None;
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].value.s, my_plugin_record->long_name );
+        Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].value.s = EngFncs->engine_strdup( my_plugin_record->long_name );
         Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].collection_type    = EVMS_Collection_None;
         memset( &Info->info[BBR_PLUGIN_INFO_LNAME_INDEX].group, 0, sizeof(group_info_t));
 
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].name, "Type" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].title, "Plugin Type" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].desc, "There are various types of plugins; each responsible for some kind of storage object.");
+        Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].name = EngFncs->engine_strdup( "Type" );
+        Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].title = EngFncs->engine_strdup( _("Plug-in Type") );
+        Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].desc = EngFncs->engine_strdup( _("There are various types of plug-ins, each responsible for some kind of storage object or logical volume.") );
         Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].type               = EVMS_Type_String;
         Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].unit               = EVMS_Unit_None;
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].value.s, "EVMS Feature" );
+        Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].value.s = EngFncs->engine_strdup( _("EVMS Feature") );
         Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].collection_type    = EVMS_Collection_None;
         memset( &Info->info[BBR_PLUGIN_INFO_TYPE_INDEX].group, 0, sizeof(group_info_t));
 
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].name, "Version" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].title, "Plugin Version" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].desc, "This is the version number of the plugin.");
+        Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].name = EngFncs->engine_strdup( "Version" );
+        Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].title = EngFncs->engine_strdup( _("Plug-in Version") );
+        Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version number of the plug-in.") );
         Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].type               = EVMS_Type_String;
         Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].unit               = EVMS_Unit_None;
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].value.s, version_string );
+        Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].value.s = EngFncs->engine_strdup( version_string );
         Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].collection_type    = EVMS_Collection_None;
         memset( &Info->info[BBR_PLUGIN_INFO_VERSION_INDEX].group, 0, sizeof(group_info_t));
 
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].name, "Required Engine Services Version" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].title, "Required Engine Services Version" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].desc, "This is the version of the Engine services that this plug-in requires. It will not run on older versions of the Engine services.");
+        Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].name = EngFncs->engine_strdup( "Required Engine Services Version" );
+        Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].title = EngFncs->engine_strdup( _("Required Engine Services Version") );
+        Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version of the Engine services that this plug-in requires.  "
+											    "It will not run on older versions of the Engine services.") );
         Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].type               = EVMS_Type_String;
         Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].unit               = EVMS_Unit_None;
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].value.s, required_engine_api_version_string );
+        Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].value.s = EngFncs->engine_strdup( required_engine_api_version_string );
         Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].collection_type    = EVMS_Collection_None;
         memset( &Info->info[BBR_PLUGIN_INFO_REQENGSVCVERSION_INDEX].group, 0, sizeof(group_info_t));
 
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].name, "Required Engine Plug-in API Version" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].title, "Required Engine Plug-in API Version" );
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].desc, "This is the version of the Engine plug-in API that this plug-in requires. It will not run on older versions of the Engine plug-in API.");
+        Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].name = EngFncs->engine_strdup( "Required Engine Plug-in API Version" );
+        Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].title = EngFncs->engine_strdup( _("Required Engine Plug-in API Version") );
+        Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version of the Engine plug-in API that this plug-in requires.  "
+											     "It will not run on older versions of the Engine plug-in API.") );
         Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].type               = EVMS_Type_String;
         Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].unit               = EVMS_Unit_None;
-        SET_STRING( Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].value.s, required_plugin_api_version_string );
+        Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].value.s = EngFncs->engine_strdup( required_plugin_api_version_string );
         Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].collection_type    = EVMS_Collection_None;
         memset( &Info->info[BBR_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].group, 0, sizeof(group_info_t));
 
