@@ -23,8 +23,12 @@
 #ifndef _DOS_DEV_MAPPER_HEADER_
 #define _DOS_DEV_MAPPER_HEADER_ 1
 
+int  BBR_can_activate( storage_object_t *object );
+
 int  BBR_activate( storage_object_t *object );
 
+int  BBR_can_deactivate( storage_object_t *object );
+
 int  BBR_deactivate( storage_object_t *object );
 
 #endif
