@@ -1095,7 +1095,7 @@ static int write_metadata(storage_object_t *segment,
 	buffer = EngFncs->engine_alloc(EVMS_VSECTOR_SIZE);
 	if (!buffer) {
 		LOG_EXIT_INT(ENOMEM);
-		return ENOMEM;	
+		return ENOMEM;
 	}
 
 	if (commit_phase == FIRST_METADATA_WRITE) {
@@ -1620,7 +1620,7 @@ static int make_bbr(storage_object_t *child)
 
 	/* Create a name and UUID for the new segment. */
 	snprintf(parent->name, EVMS_NAME_SIZE, "%s_bbr", child->name);
-	uuid_generate_random((char*)&id);
+	uuid_generate_random((unsigned char*)&id);
 	sprintf(parent->uuid,
 		"%08X-%04X-%04X-%02X%02X-%02X%02X%02X%02X%02X%02X",
 		id.time_low, id.time_mid, id.time_high, id.clock_seq_high,
@@ -2306,7 +2306,7 @@ static int bbr_commit_changes(storage_object_t *segment,
 	 * Phase 2: Commit 2nd copy of metadata & 2nd bbr table
 	 */
 	switch (commit_phase) {
-			
+
 	case FIRST_METADATA_WRITE:
 	case SECOND_METADATA_WRITE:
 		rc = commit_bbr_segment(segment, commit_phase);
@@ -2558,7 +2558,7 @@ static int bbr_get_option_count(task_context_t *task)
 	LOG_ENTRY();
 
 	switch (task->action) {
-	
+
 	case EVMS_Task_Assign_Plugin:
 	case EVMS_Task_Create:
 	case EVMS_Task_Expand:
@@ -2650,7 +2650,7 @@ static int bbr_init_task(task_context_t *context)
 		context->max_selected_objects = 0;
 		rc = 0;
 		break;
-	
+
 	default:
 		LOG_ERROR("Action %d is unsupported.\n", context->action);
 		rc = EINVAL;
