@@ -23,8 +23,12 @@
 #ifndef _BSD_DEV_MAPPER_HEADER_
 #define _BSD_DEV_MAPPER_HEADER_ 1
 
+int    bsd_can_activate( storage_object_t *object );
+
 int    bsd_activate( storage_object_t *object );
 
+int    bsd_can_deactivate( storage_object_t *object );
+
 int    bsd_deactivate( storage_object_t *object );
 
 #endif
