@@ -68,7 +68,7 @@ int bsd_can_delete( DISKSEG * seg )
  */
 int bsd_discover( list_anchor_t input_objects, list_anchor_t output_objects, boolean final_call)
 {
-        int  count = 0;
+        uint  count = 0;
         list_element_t iter;
         storage_object_t *object;
 
@@ -77,7 +77,7 @@ int bsd_discover( list_anchor_t input_objects, list_anchor_t output_objects, boo
         if ( (input_objects != NULL) &&
              (output_objects != NULL) &&
              (EngFncs->list_count(input_objects) > 0)) {
- 
+
                 LIST_FOR_EACH( input_objects, iter, object ){
                         discover_bsd_segments( object, output_objects, &count);
                 }
@@ -93,7 +93,7 @@ int bsd_discover( list_anchor_t input_objects, list_anchor_t output_objects, boo
  *  Function:  bsd_unassign
  *
  *  We can unassign from any logical disk storage object that
- *  has a BSD disk label on it as long as the data segments are 
+ *  has a BSD disk label on it as long as the data segments are
  *  top-most storage objects.
  *
  */
@@ -133,14 +133,14 @@ int bsd_unassign( LOGICALDISK *ld )
         LOG_ENTRY();
 
         REQUIRE( isa_bsd_logical_disk(ld) == TRUE );
-  
+
         // toss segment storage objects
         prune_bsd_seg_objects_from_list( ld->parent_objects );
 
         // toss our logical disk private data area
         delete_bsd_disk_private_data( ld );
 
-        // blast bsd disk label 
+        // blast bsd disk label
         KILL_SECTORS(ld, 0, 1);
 
         LOG_EXIT_INT(0);
@@ -167,7 +167,7 @@ int bsd_destroy( DISKSEG * seg, list_anchor_t child_objects )
         REQUIRE( seg->data_type   == DATA_TYPE );
         REQUIRE( disk_move_pending(seg) == FALSE);
         REQUIRE( isa_bsd_segment( seg ) == TRUE );
- 
+
         ld = get_logical_disk(seg);
         REQUIRE( ld != NULL);
 
@@ -182,7 +182,7 @@ int bsd_destroy( DISKSEG * seg, list_anchor_t child_objects )
         }
 
         if (metadata) {
-                
+
                 rc = remove_bsd_segment_from_list( ld->parent_objects, seg );
                 if (rc == 0) {
 
@@ -194,7 +194,7 @@ int bsd_destroy( DISKSEG * seg, list_anchor_t child_objects )
                         metadata->flags   |= SOFLAG_DIRTY;
                 }
                 else {
-                        rc = ENODEV; 
+                        rc = ENODEV;
                 }
 
         }
@@ -227,11 +227,11 @@ int bsd_discard(list_anchor_t objects)
 				remove_bsd_segment_from_list( ld->parent_objects, seg );
 				if (EngFncs->list_empty(ld->parent_objects) == TRUE)
 			        // toss our logical disk private data area
-			        delete_bsd_disk_private_data( ld );	
+			        delete_bsd_disk_private_data( ld );
 			}
-			
-			free_bsd_segment(seg);				
-			
+
+			free_bsd_segment(seg);
+
 		}
 	}
 	LOG_EXIT_INT(rc);
@@ -276,31 +276,31 @@ int bsd_add_sectors_to_kill_list( DISKSEG       *seg,
  *  commit phases.
  */
 int bsd_commit_changes( DISKSEG *seg, uint commit_phase )
-{        
+{
         int rc;
         LOGICALDISK *ld;
         disk_private_data_t *disk_pdata;
 
 
         LOG_ENTRY();
-        
+
         REQUIRE( isa_bsd_segment(seg) == TRUE );
 
-        ld = get_logical_disk(seg);     
+        ld = get_logical_disk(seg);
         REQUIRE( ld != NULL );
 
         disk_pdata = get_bsd_disk_private_data(ld);
         REQUIRE( disk_pdata != NULL);
-             
+
         if (commit_phase == MOVE) {
-                if ( disk_pdata->flags & DISK_HAS_MOVE_PENDING ) {                              
+                if ( disk_pdata->flags & DISK_HAS_MOVE_PENDING ) {
                         /*
                         rc = bsd_move_segment_commit( disk_pdata->copy_job );
                         */
                         rc = ENOSYS;
                         if (disk_pdata->copy_job) free(disk_pdata->copy_job );
                         disk_pdata->copy_job = NULL;
-                        disk_pdata->flags   &= ~DISK_HAS_MOVE_PENDING; 
+                        disk_pdata->flags   &= ~DISK_HAS_MOVE_PENDING;
                         seg->flags          &= ~SOFLAG_DIRTY;
                 }
                 else {
@@ -319,10 +319,10 @@ int bsd_commit_changes( DISKSEG *seg, uint commit_phase )
         else {
                 rc=0;
         }
-        
+
 
         LOG_EXIT_INT(0);
-        return 0;   
+        return 0;
 }
 
 
