@@ -28,7 +28,6 @@
 #include <uuid/uuid.h>
 
 #include <plugin.h>
-#include <csm_funcs.h>
 
 #include "csm_plugin.h"
 
@@ -174,7 +173,7 @@ static container_functions_t csm_container_functions = {
 
 static plugin_record_t csm_plugin_record = {
 
-	id:                                 CSM_PLUGIN_ID,
+	id:                                 EVMS_CSM_PLUGIN_ID,
 
 	version:                            {MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL},
 
@@ -182,9 +181,9 @@ static plugin_record_t csm_plugin_record = {
 	required_plugin_api_version:        {plugin: {13,1,0}},
 	required_container_api_version:     {10,1,0},
 
-	short_name:                         "CSM",
-	long_name:                          "Cluster Segment Manager",
-	oem_name:                           "IBM",
+	short_name:                         EVMS_CSM_PLUGIN_SHORT_NAME,
+	long_name:                          EVMS_CSM_PLUGIN_LONG_NAME,
+	oem_name:                           EVMS_IBM_OEM_NAME,
 
 	functions:                          {plugin: &csm_plugin_functions},
 
