@@ -118,7 +118,7 @@ static csm_header_t *  read_csm_header_sector( storage_object_t *object,
 static csm_header_t * get_csm_header( LOGICALDISK  *ld )
 {
         csm_header_t  *hdr  = NULL;
-        char * choices[] = {"Yes", "No", NULL};
+        char * choices[] = {_("Yes"), _("No"), NULL};
         int answer = 0;     // Initialize to Revert
 
         LOG_ENTRY();
@@ -325,7 +325,7 @@ int get_segments( storage_object_t     *object,
 
         // if primary header is missing then mark it dirty so engine will commit it.
         if (md1_dirty == TRUE) {
-                MESSAGE("\nPrimary CSM Header is missing or corrupt. Marking %s dirty to correct the problem\n",
+                MESSAGE(_("Primary CSM Header is missing or corrupt.  Marking %s dirty to correct the problem.\n"),
                         metadata1->name );
                 metadata1->flags |= SOFLAG_DIRTY;
         }
@@ -357,7 +357,7 @@ int get_segments( storage_object_t     *object,
 
         // if secondary header is missing then mark it dirty so engine will commit it.
         if (md2_dirty == TRUE) {
-                MESSAGE("\nAlternate CSM Header is missing or corrupt. Marking %s dirty to correct the problem\n",
+                MESSAGE(_("Alternate CSM Header is missing or corrupt.  Marking %s dirty to correct the problem.\n"),
                         metadata2->name );
                 metadata2->flags |= SOFLAG_DIRTY;
         }
@@ -367,8 +367,7 @@ int get_segments( storage_object_t     *object,
                 dataseg = create_csm_data_segment( object,
                                                    container,
                                                    hdr->start_useable,
-                                                   hdr->end_useable - hdr->start_useable + 1,
-                                                   0 );
+                                                   hdr->end_useable - hdr->start_useable + 1 );
 
                 if (dataseg == NULL) {
                         if (hdr1) free(hdr1);
@@ -470,17 +469,6 @@ void get_csm_segment_devmap_info( storage_object_t *seg, storage_container_t *co
                                 }
 
                         }
-                        else {
-                                // SEGMENT IS NOT ACTIVE ...
-
-                                if ( ok_to_activate == TRUE ) {
-                                        seg->flags |= SOFLAG_NEEDS_ACTIVATE;
-                                }
-                                else {
-                                        LOG_DEBUG("seg is not active but not this nodeid so not activating\n");
-                                }
-
-                        }
 
                 }
 
