@@ -102,7 +102,7 @@ int csm_can_shrink_by( DISKSEG * seg, sector_count_t * size )
 int csm_discover( list_anchor_t input_objects, list_anchor_t output_objects, boolean final_call)
 {
         int  rc=0;
-        int  count = 0;
+        uint  count = 0;
         list_element_t iter;
         storage_object_t *object;
 
@@ -252,7 +252,7 @@ int assign_cluster_segment_manager_to_disk( LOGICALDISK         *ld,
         --end_useable;
 
         // generate a unique disk id
-        uuid_generate_random( (char *) &disk_id );
+        uuid_generate_random( (unsigned char *) &disk_id );
 
         // REGISTER DISK - convert DISK uuid to ascii string and register it.
         disk_guid_name = guid_to_string( &disk_id );
