@@ -77,6 +77,12 @@ u_int32_t num_file_handles = 0;
 #define DEFAULT_FILE_HANDLES 64
 #define MAX_FILE_HANDLES 1024
 
+static int LD_read(storage_object_t * disk,
+		   lsn_t offset,
+		   sector_count_t count,
+		   void * buffer);
+
+
 static void close_dev(storage_object_t * disk);
 
 /**
@@ -568,7 +574,7 @@ static void filter_out_excludes(char * pattern, int path_len, int new_globs_inde
 	LOG_ENTRY();
 
 	for (i = 0; i < exclude_count; i++) {
-			
+
 		strcpy(pattern + path_len, excludes[i]);
 
 		rc = glob(pattern, glob_flags, NULL, &exclude_glob);
@@ -624,7 +630,7 @@ static void filter_out_non_block_devices(int new_globs_index)
 
 	i = new_globs_index;
 	while (i < dev_names_glob.gl_pathc) {
-			
+
 		status = stat(dev_names_glob.gl_pathv[i], &statbuf);
 
 		if (status == 0) {
@@ -678,7 +684,7 @@ static void get_dev_names(const char * dir)
 	new_globs_index = dev_names_glob.gl_pathc;
 
 	for (i = 0; i < include_count; i++) {
-			
+
 		strcpy(pattern + path_len, includes[i]);
 
 		rc = glob(pattern, glob_flags, NULL, &dev_names_glob);
@@ -1396,96 +1402,172 @@ static void remove_multipath_children(list_anchor_t multipath_children,
 }
 
 /**
- * get_geometry
+ * valid_part_table_flag
+ *
+ * Does this sector contain a partition table with a DOS MBR signature?
+ **/
+inline boolean valid_part_table_flag(unsigned char *b)
+{
+	return (b[510] == 0x55 && b[511] == 0xaa);
+}
+
+static unsigned char MBR_buff[EVMS_VSECTOR_SIZE];
+
+#define pt_offset(b, n) ((struct partition *)((b) + 0x1be + \
+					      (n) * sizeof(struct partition)))
+
+/**
+ * get_partition_table_geometry
+ *
+ * See if the disk has a DOS partition table in the first sector. If so, see
+ * if a valid geometry is recorded there that we can use for the disk.
+ **/
+static int get_partition_table_geometry(storage_object_t * disk)
+{
+	int rc;
+	struct partition * p;
+	int i;
+	int heads = 0;
+	int sectors = 0;
+	boolean first = TRUE;
+	boolean bad = FALSE;
+
+	/* Use LD_read() because the disk was opened with O_DIRECT. LD_read()
+	 * knows how to handle setting up buffer alignment for O_DIRECT.
+	 */
+	rc = LD_read(disk, 0, 1, MBR_buff);
+	if (rc) {
+		LOG_DETAILS("Unable to read MBR sector from disk %s. "
+			    "Error code is %d:%s\n",
+			    disk->name, rc, EngFncs->strerror(rc));
+		LOG_EXIT_INT(rc);
+		return rc;
+	}
+
+	if (!(valid_part_table_flag(MBR_buff))) {
+		LOG_DETAILS("Disk %s does not have a valid partition table "
+			    "flag.\n", disk->name);
+		LOG_EXIT_INT(ENODATA);
+		return ENODATA;
+	}
+
+	for (i = 0; (i < 4) && !bad; i++) {
+		p = pt_offset(MBR_buff, i);
+		if (p->sys_ind != 0) {
+			int h, s;
+
+			h = p->end_head + 1;
+			s = (p->end_sector & 077);
+			if (first) {
+				heads = h;
+				sectors = s;
+				first = FALSE;
+			} else if (heads != h || sectors != s)
+				bad = TRUE;
+		}
+	}
+
+	if (first || bad) {
+		LOG_DETAILS("Could not determine geometry from the partition "
+			    "records on disk %s.\n", disk->name);
+		LOG_EXIT_INT(ENODATA);
+		return ENODATA;
+	}
+
+	if (!first && !bad) {
+		disk->geometry.heads = heads;
+		disk->geometry.sectors_per_track = sectors;
+	}
+
+	LOG_EXIT_INT(0);
+	return 0;
+}
+
+/**
+ * get_kernel_geometry
  *
  * Use the HDIO_GETGEO_BIG or HDIO_GETGEO ioctl to get the disk's geometry.
  * Check that the geometry is valid for a disk.
  **/
-static int get_geometry(storage_object_t * disk)
+static int get_kernel_geometry(storage_object_t * disk)
 {
+	int rc;
 	struct hd_big_geometry big_geometry;
 	struct hd_geometry geometry;
 	local_disk_t * ld = disk->private_data;
-	int rc;
 
 	LOG_ENTRY();
 
 	rc = ioctl(ld->fd, HDIO_GETGEO, &geometry);
-	if (rc) {
+	if (rc == -1) {
 		rc = ioctl(ld->fd, HDIO_GETGEO_BIG, &big_geometry);
-		if (rc) {
+		if (rc == -1) {
 			rc = errno;
 			LOG_DEBUG("Error getting geometry for disk %s: %d: "
-				  "%s.\n", disk->name, rc, strerror(rc));
+				  "%s.\n", disk->name, rc, EngFncs->strerror(rc));
 		} else if (big_geometry.start != 0) {
 			/* A disk's geometry must start at offset 0. */
-			LOG_DEBUG("Geometry for disk %s reports a non-zero starting "
-				  "offset. Not a valid disk.\n", disk->name);
+			LOG_DEBUG("Geometry for disk %s reports a non-zero "
+				  "starting offset. Not a valid disk.\n",
+				  disk->name);
 			rc = EINVAL;
 		} else {
-			disk->geometry.cylinders = big_geometry.cylinders;
+			/* Ala fdisk: Never use geometry.cylinders -
+			 * it's truncated.
+			 */
+			// disk->geometry.cylinders = big_geometry.cylinders;
 			disk->geometry.heads = big_geometry.heads;
 			disk->geometry.sectors_per_track = big_geometry.sectors;
 		}
 	} else {
 		if (geometry.start != 0) {
 			/* A disk's geometry must start at offset 0. */
-			LOG_DEBUG("Geometry for disk %s reports a non-zero starting "
-				  "offset. Not a valid disk.\n", disk->name);
+			LOG_DEBUG("Geometry for disk %s reports a non-zero "
+				  "starting offset. Not a valid disk.\n",
+				  disk->name);
 			rc = EINVAL;
 		} else {
-			/* ala fdisk: never use geometry.cylinders - it is truncated */
+			/* Ala fdisk: Never use geometry.cylinders -
+			 * it's truncated.
+			 */
 			// disk->geometry.cylinders = geometry.cylinders;
 			disk->geometry.heads = geometry.heads;
 			disk->geometry.sectors_per_track = geometry.sectors;
 		}
 	}
 
-	/*
-	 * If the driver answered the ioctl but didn't supply a geometry,
-	 * fill in a default geometry.  This is what fdisk does.
-	 */
-	if (rc == 0) {
-		if (disk->geometry.heads == 0) {
-			disk->geometry.heads = 255;
-		}
-		if (disk->geometry.sectors_per_track == 0) {
-			disk->geometry.sectors_per_track = 63;
-		}
-		if (disk->geometry.cylinders == 0) {
-			disk->geometry.cylinders = disk->size / (255 * 63 *
-								 (disk->geometry.bytes_per_sector / 512));
-		}
-	}
-
 	LOG_EXIT_INT(rc);
 	return rc;
 }
 
 /**
- * get_fake_geometry
+ * get_geometry
  *
- * Some drivers (notably loop, nbd, and drbd) don't
- * support geometry, so we need to fake it.
+ * First try to get the geometry from the partition table (if it exists).
+ * Otherwise ask the kernel what the geometry is.
  **/
-static int get_fake_geometry(storage_object_t * disk)
+static int get_geometry(storage_object_t * disk)
 {
-	local_disk_t * ld = disk->private_data;
-	int rc = EINVAL;
+	int rc;
 
 	LOG_ENTRY();
 
-	if (disk->dev_major == LOOP_MAJOR ||
-	    disk->dev_major == NBD_MAJOR ||
-	    disk->dev_major == DRBD_MAJOR ||
-	    ld->flags & LD_FLAG_MULTIPATH) {
-		LOG_DEBUG("Creating fake geometry for disk %s.\n", disk->name);
-		disk->geometry.heads = 255;
-		disk->geometry.sectors_per_track = 63;
-		disk->geometry.cylinders = disk->size / (255 * 63);
-		rc = 0;
+	/* Set defaults */
+	disk->geometry.heads = 255;
+	disk->geometry.sectors_per_track = 63;
+
+	rc = get_partition_table_geometry(disk);
+
+	if (rc != 0) {
+		get_kernel_geometry(disk);
 	}
 
+	disk->geometry.cylinders = disk->size /
+				   (disk->geometry.heads *
+				    disk->geometry.sectors_per_track *
+				    (disk->geometry.bytes_per_sector /
+				     EVMS_VSECTOR_SIZE));
+
 	LOG_EXIT_INT(rc);
 	return rc;
 }
@@ -1742,19 +1824,6 @@ static int LD_discover(list_anchor_t input_list,
 			continue;
 		}
 
-		/* Get the disk's hard-sector-size. */
-		get_hardsector_size(&working_disk);
-
-		/* Get the disk's geometry. */
-		rc = get_geometry(&working_disk);
-		if (rc) {
-			rc = get_fake_geometry(&working_disk);
-			if (rc) {
-				close_dev(&working_disk);
-				continue;
-			}
-		}
-
 		/* Get the disk's block-size. */
 		rc = get_block_size(&working_disk);
 		if (rc) {
@@ -1762,6 +1831,12 @@ static int LD_discover(list_anchor_t input_list,
 			continue;
 		}
 
+		/* Get the disk's hard-sector-size. */
+		get_hardsector_size(&working_disk);
+
+		/* Get the disk's geometry. */
+		get_geometry(&working_disk);
+
 		/* Passed all checks. Create a new disk. */
 		disk = create_logical_disk(&working_disk);
 		if (!disk) {
@@ -2055,14 +2130,14 @@ static int LD_write(storage_object_t * disk,
 			goto out;
 		}
 	}
-	
+
 	/* Put user data at the right place in the buffer */
 	if (!aligned) {
 		memcpy(local_buffer +
 		       ((offset - local_offset) << EVMS_VSECTOR_SIZE_SHIFT),
 		       buffer, count << EVMS_VSECTOR_SIZE_SHIFT);
 	}
-	
+
 	/* Send the write to the engine. */
 	rc = EngFncs->write_object(disk, ld->fd, local_buffer,
 				   local_count << EVMS_VSECTOR_SIZE_SHIFT,
@@ -2149,7 +2224,7 @@ static int LD_get_info(storage_object_t * disk,
 	LOG_ENTRY();
 
 	*info = NULL;
-	
+
 	if (!name) {
 		rc = get_basic_info(disk, info);
 	} else if (!strncasecmp(name, "Type", 4)) {
