@@ -24,6 +24,6 @@
 #ifndef COMMIT_HEADER
 #define COMMIT_HEADER 1
 
-int  Commit_Disk_Partition_Tables(LOGICALDISK *ld);
+int  Commit_Disk_Partition_Tables(LOGICALDISK *ld, DISKSEG *parent, boolean backup);
 
 #endif
