@@ -253,8 +253,7 @@ static int SEG_can_set_volume(storage_object_t * seg, boolean flag )
 
 	if ( ( seg ) &&
 	     ( seg->object_type == SEGMENT ) &&
-	     ( seg->data_type   == DATA_TYPE ) &&
-	     ( i_can_modify_seg( seg ) == TRUE ) ) {
+	     ( seg->data_type   == DATA_TYPE ) ) {
 
 		ld = get_logical_disk(seg);
 
