@@ -99,21 +99,25 @@ static boolean isa_disk_with_msdos_partitions( LOGICALDISK *ld, Master_Boot_Reco
 
                         rc = seg_geometry_guess(ld, &guess );
                         if (rc == 0) {
+				char number_buffer1[64];
+				char number_buffer2[64];
 
                                 // success, so switch to new geometry
                                 disk_pdata->geometry.cylinders         = guess.cylinders;
                                 disk_pdata->geometry.sectors_per_track = guess.sectors_per_track;
                                 disk_pdata->geometry.heads             = guess.heads;
 
-                                MESSAGE( "\nWarning, using an alternate geometry (Cylinders, Heads, Sectors) for drive %s.\n"
-                                         "\nThe kernel reported drive geometry is: C= %"PRIu64" H= %d S= %d\n"
-                                         "\nThe partition records report a geometry of: C= %"PRIu64" H= %d S= %d\n"
-                                         "\nUsing the alternate geometry reported by the partition records.\n",
+				sprintf(number_buffer1, "%"PRIu64, ld->geometry.cylinders);
+				sprintf(number_buffer2, "%"PRIu64, disk_pdata->geometry.cylinders);
+                                MESSAGE( _("Warning:  Using an alternate geometry (Cylinders, Heads, Sectors) for drive %s.\n"
+					   "The kernel reported drive geometry is: C= %s H= %d S= %d\n"
+					   "The partition records report a geometry of: C= %s H= %d S= %d\n"
+					   "Using the alternate geometry reported by the partition records.\n"),
                                          ld->name,
-                                         ld->geometry.cylinders,
+                                         number_buffer1,
                                          ld->geometry.heads,
                                          ld->geometry.sectors_per_track,
-                                         disk_pdata->geometry.cylinders,
+                                         number_buffer2,
                                          disk_pdata->geometry.heads,
                                          disk_pdata->geometry.sectors_per_track );
 
@@ -140,7 +144,7 @@ static boolean isa_disk_with_msdos_partitions( LOGICALDISK *ld, Master_Boot_Reco
 
                                         disk_pdata->flags |= DISK_HAS_FORCED_LBA_ADDRESSING;
 
-                                        MESSAGE("\nWarning, forced to use LBA addressing on drive %s due to inconsistant geometry.\nChanges will not be committed on this drive.\n",
+                                        MESSAGE(_("Warning:  Forced to use LBA addressing on drive %s due to inconsistant geometry.\nChanges will not be committed on this drive.\n"),
                                                 ld->name);
 
                                 }
@@ -521,7 +525,7 @@ static int get_disk_segments(  LOGICALDISK         *ld,                  // driv
                 part = &boot_sector->Partition_Table[i];
 
                 switch ( SYS_IND(part) ) {
-                
+
                 case BSD_PARTITION:
                 case NETBSD_PARTITION:
                 case OPENBSD_PARTITION:
@@ -546,8 +550,8 @@ static int get_disk_segments(  LOGICALDISK         *ld,                  // driv
         // look for guid partitioned disk and warn user
         if ( has_guid_partition_table( boot_sector )==TRUE) {
 
-                MESSAGE("Warning, disk %s seems to have a GUID Partition Table. Making "
-                        "any changes to this disk may damage the GPT partitions.",
+                MESSAGE(_("Warning: Disk %s seems to have a GUID Partition Table.  "
+			  "Making any changes to this disk may damage the GPT partitions."),
                         ld->name );
         }
 
@@ -634,25 +638,26 @@ int dos_segment_discovery( storage_object_t  *object,
         // get disk manager function table
         dft = (struct plugin_functions_s *)ld->plugin->functions.plugin;
         if (dft==NULL) {
-                MESSAGE("error ... no device manager function table for drive %s\n", ld->name);
+                MESSAGE(_("Error:  No device manager function table for drive %s\n"), ld->name);
                 rc = EINVAL;
         }
 
-        // read MBR off drive 
+        // read MBR off drive
         if (!rc) {
                 mbr = (Master_Boot_Record *) malloc(ld->geometry.bytes_per_sector);
                 if (mbr) {
                         rc = dft->read( ld, 0, 1, (void *) mbr );
                 }
                 else {
-                        rc = ENOMEM;       
+                        rc = ENOMEM;
                 }
         }
 
         // create disk private data area for this drive
         if (!rc) {
                 if ( create_disk_private_data(ld) ) {
-                        MESSAGE("error, unable to malloc a sector sized buffer for reading sectors off drive %s\n", ld->name );
+                        MESSAGE(_("Error:  Unable to malloc a sector sized buffer for reading sectors off drive %s\n"),
+				ld->name );
                         rc = ENOMEM;
                 }
                 else {
@@ -708,7 +713,7 @@ int dos_segment_discovery( storage_object_t  *object,
                                 // of sync with the DM kernel objects. So, we need to resolve
                                 // these differences and obtain status on the segment storage
                                 // objects ...
-                                resolve_partitions_with_device_mapper(ld);              
+                                resolve_partitions_with_device_mapper(ld);
 
                                 // copy storage objects to the output list
                                 rc = EngFncs->concatenate_lists( output_objects, ld->parent_objects );
@@ -732,7 +737,7 @@ int dos_segment_discovery( storage_object_t  *object,
 
                 DISKSEG *freespace=NULL;
                 DISKSEG *mbrseg=NULL;
-                char * choices[] = {"Yes", "No", NULL};        
+                char * choices[] = {_("Yes"), _("No"), NULL};
                 int answer = 1;     // Initialize to Revert
 
                 if ( has_msdos_signature(mbr) == TRUE ) {
