@@ -23,8 +23,12 @@
 #ifndef _DOS_DEV_MAPPER_HEADER_
 #define _DOS_DEV_MAPPER_HEADER_ 1
 
+int  SEG_can_activate( storage_object_t *object );
+
 int  SEG_activate( storage_object_t *object );
 
+int  SEG_can_deactivate( storage_object_t *object );
+
 int  SEG_deactivate( storage_object_t *object );
 
 #endif
