@@ -43,12 +43,12 @@
  */
 static inline boolean safe_to_move(DISKSEG *seg)
 {
-	LOGICALDISK        *ld=get_logical_disk(seg);   
+	LOGICALDISK        *ld=get_logical_disk(seg);
 	DISK_PRIVATE_DATA  *disk_pdata=NULL;
 
 	if ( ld ) {
 
-		disk_pdata = get_disk_private_data(ld); 
+		disk_pdata = get_disk_private_data(ld);
 		if (disk_pdata) {
 
 			if ( i_can_modify_seg(seg)  ==  TRUE &&
@@ -114,7 +114,7 @@ static int create_copy_job( DISKSEG      *seg,	     // data segment to be moved
 	LOG_ENTRY();
 
 	ld          = get_logical_disk(seg);
-	disk_pdata  = get_disk_private_data(ld);        
+	disk_pdata  = get_disk_private_data(ld);
 	job         = alloc_copy_job_t();
 	title       = malloc(EVMS_NAME_SIZE*2+2);
 
@@ -185,7 +185,7 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 		LOG_ERROR("error, get_logical_disk() failed\n");
 		rc = ENODEV;
 		LOG_EXIT_INT(rc);
-		return rc;              
+		return rc;
 	}
 
 	if (freespace) {
@@ -195,7 +195,7 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 			LOG_ERROR("error, freespace too small for move\n");
 			rc = EFBIG;
 			LOG_EXIT_INT(rc);
-			return rc;              
+			return rc;
 		}
 	}
 	else {
@@ -268,18 +268,18 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 
 			// ebr will be in very 1st sector and occupy 1 track
 			ebr->start = start;
-			ebr->size  = ld->geometry.sectors_per_track * disk_pdata->vsectors_per_block; 
+			ebr->size  = ld->geometry.sectors_per_track * disk_pdata->vsectors_per_block;
 
 			LOG_DEBUG("ebr start = %"PRIu64"\n", ebr->start);
 			LOG_DEBUG("ebr  size = %"PRIu64"\n", ebr->size);
 
 			// determine the offset of the logical from the start of the cylinder
-			// that it starts within ... not from the start of the ebr ... which 
+			// that it starts within ... not from the start of the ebr ... which
 			// may or may not be in the very 1st sector of the cylinder.
 			cyl_start  = rounddown_to_cylinder_boundary(ld,seg->start);
-			cyl_offset = seg->start - cyl_start;        
+			cyl_offset = seg->start - cyl_start;
 
-			LOG_DEBUG("src seg cyl start  = %"PRIu64"\n",cyl_start); 
+			LOG_DEBUG("src seg cyl start  = %"PRIu64"\n",cyl_start);
 			LOG_DEBUG("src seg cyl offset = %"PRIu64"\n", cyl_offset);
 
 			if (cyl_offset == 0) { // partition is cyl alligned
@@ -303,7 +303,7 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 			// (2) a source segment might be track alligned because it has been moved before and was
 			//     track alligned because it use to follow the MBR track on the disk.
 			// (3) the target freespace may be track alligned because it follows the MBR
-			//     track on the disk.               
+			//     track on the disk.
 
 			if (starts_on_cylinder_boundary(ld,seg->start)==FALSE) {
 				sector_count_t sector_offset;
@@ -314,7 +314,7 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 				cylinder_start = rounddown_to_cylinder_boundary(ld,seg->start);
 				sector_offset  = seg->start - cylinder_start;
 
-				LOG_DEBUG("cyl start= %"PRId64"  sector offset= %"PRId64"\n", cylinder_start, sector_offset);           
+				LOG_DEBUG("cyl start= %"PRId64"  sector offset= %"PRId64"\n", cylinder_start, sector_offset);
 
 				if (starts_on_cylinder_boundary(ld,freespace->start)==TRUE) {
 					LOG_DEBUG("freespace starts on cyl bdy so simply offsetting into freespace by same amount\n");
@@ -366,7 +366,7 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 			rc = EINVAL;
 		}
 		else if (start > freespace->start+freespace->size-1 ) {
-			LOG_DEBUG("error ... would start past end of freespace segment\n");             
+			LOG_DEBUG("error ... would start past end of freespace segment\n");
 		}
 		else if (end > freespace->start+freespace->size-1 ) {
 			LOG_DEBUG("error ... would end past end of freespace segment\n");
@@ -375,7 +375,7 @@ static int create_move_target( DISKSEG  *seg,	     // source data segment
 		else {
 			trg->size = end - trg->start + 1;
 			*target=trg;
-			rc = 0;                 
+			rc = 0;
 		}
 
 	}
@@ -448,7 +448,7 @@ int dos_validate_move_target( DISKSEG *src, DISKSEG *trg )
 		}
 
 		if (rc==0) {
-			rc = create_move_target( src, trg, &tseg, TRUE);                                        
+			rc = create_move_target( src, trg, &tseg, TRUE);
 		}
 
 	}
@@ -468,8 +468,8 @@ int dos_validate_move_target( DISKSEG *src, DISKSEG *trg )
  */
 int dos_can_move_segment( DISKSEG *seg )
 {
-	DISKSEG       *freespace=NULL;  
-	LOGICALDISK   *ld=NULL; 
+	DISKSEG       *freespace=NULL;
+	LOGICALDISK   *ld=NULL;
 	int rc=EINVAL;
 	list_element_t iter;
 
@@ -526,8 +526,8 @@ static int dos_update_segment_info( DISKSEG *src, DISKSEG *trg )
 	if (src && trg) {
 
 		ld         = get_logical_disk(src);
-		disk_pdata = get_disk_private_data(ld); 
-		src_pdata  = (SEG_PRIVATE_DATA *) src->private_data;            
+		disk_pdata = get_disk_private_data(ld);
+		src_pdata  = (SEG_PRIVATE_DATA *) src->private_data;
 		trg_pdata  = (SEG_PRIVATE_DATA *) trg->private_data;
 
 		logical_partition = (src_pdata->flags & SEG_IS_LOGICAL_PARTITION) ? TRUE : FALSE;
@@ -575,7 +575,7 @@ static int dos_update_segment_info( DISKSEG *src, DISKSEG *trg )
 			fixup_disk_extd_partition_anchor(ld);
 
 			// calc sizes of each std ebr partition
-			fixup_EBR_Sizes(ld);                    
+			fixup_EBR_Sizes(ld);
 		}
 
 		rc = 0;
@@ -607,7 +607,7 @@ int dos_move_segment( DISKSEG *src, DISKSEG *freespace )
 
 		ld         = get_logical_disk(src);
 		disk_pdata = get_disk_private_data(ld);
-		src_pdata  = (SEG_PRIVATE_DATA *) src->private_data;                            
+		src_pdata  = (SEG_PRIVATE_DATA *) src->private_data;
 
 		// create a move target segment
 		rc = create_move_target(src, freespace, &trg, FALSE);
@@ -615,7 +615,7 @@ int dos_move_segment( DISKSEG *src, DISKSEG *freespace )
 
 		// create the engine copy job
 		if (rc==0) {
-			rc = create_copy_job( src, trg, &job );                                         
+			rc = create_copy_job( src, trg, &job );
 			if (rc) {
 				if (trg_pdata->flags & SEG_IS_LOGICAL_PARTITION) {
 					free_disk_segment(trg_pdata->ebr);
@@ -637,7 +637,7 @@ int dos_move_segment( DISKSEG *src, DISKSEG *freespace )
 			}
 			insert_diskseg_into_ordered_list( ld->parent_objects, trg );
 
-			disk_pdata->flags     |= DISK_HAS_MOVE_PENDING;         
+			disk_pdata->flags     |= DISK_HAS_MOVE_PENDING;
 			disk_pdata->copy_job   = job;
 			src_pdata->move_target = trg;
 			src->flags |= SOFLAG_DIRTY;
@@ -655,12 +655,12 @@ int dos_move_segment( DISKSEG *src, DISKSEG *freespace )
  *
  *  Called after a move to update partition tables.
  */
-static int do_move_segment_finish( DISKSEG      *src, 
-				   DISKSEG      *trg, 
+static int do_move_segment_finish( DISKSEG      *src,
+				   DISKSEG      *trg,
 				   int   copy_rc,
 				   boolean       offline )
 {
-	int rc=EINVAL;  
+	int rc=EINVAL;
 	LOGICALDISK        *ld=NULL;
 	SEG_PRIVATE_DATA   *src_pdata=NULL;
 	SEG_PRIVATE_DATA   *trg_pdata=NULL;
@@ -675,23 +675,23 @@ static int do_move_segment_finish( DISKSEG      *src,
 	if (src && trg) {
 
 		ld         = get_logical_disk(src);
-		disk_pdata = get_disk_private_data(ld); 
+		disk_pdata = get_disk_private_data(ld);
 		src_pdata  = (SEG_PRIVATE_DATA *)src->private_data;
-		trg_pdata  = (SEG_PRIVATE_DATA *)trg->private_data;                             
+		trg_pdata  = (SEG_PRIVATE_DATA *)trg->private_data;
 		logical_partition = (src_pdata->flags & SEG_IS_LOGICAL_PARTITION) ? TRUE : FALSE;
 
 		// if sectors were copied Ok ... then try to update partition tables to
 		// complete the move ... restore the source segment if any errors occur.
 		if (copy_rc==0) {
 			memcpy(&saved_seg, src, sizeof(DISKSEG));
-			memcpy(&saved_pdata, src_pdata, sizeof(SEG_PRIVATE_DATA));      
+			memcpy(&saved_pdata, src_pdata, sizeof(SEG_PRIVATE_DATA));
 			if (logical_partition==TRUE) {
 				memcpy(&saved_ebr, src_pdata->ebr, sizeof(DISKSEG));
 			}
 
 			rc = dos_update_segment_info(src,trg);
 			if (rc==0) {
-				rc = Commit_Disk_Partition_Tables(ld);
+				rc = Commit_Disk_Partition_Tables(ld, trg, FALSE);
 			}
 
 			if (rc) {
@@ -700,7 +700,7 @@ static int do_move_segment_finish( DISKSEG      *src,
 				if (logical_partition==TRUE) {
 					memcpy(src_pdata->ebr, &saved_ebr, sizeof(DISKSEG));
 				}
-				Commit_Disk_Partition_Tables(ld);
+				Commit_Disk_Partition_Tables(ld, src, FALSE);
 			}
 		}
 		else {
@@ -767,7 +767,7 @@ static int do_online_copy(storage_object_t *src, storage_object_t *tgt, copy_job
 				EngFncs->dm_suspend(src, FALSE);
 			}
 			else {
-				LOG_SERIOUS("Error code %d when resuming object %s: %s\n", 
+				LOG_SERIOUS("Error code %d when resuming object %s: %s\n",
 					    rc, src->name, EngFncs->strerror(rc));
 			}
 
@@ -775,13 +775,13 @@ static int do_online_copy(storage_object_t *src, storage_object_t *tgt, copy_job
 
 		}
 		else {
-			LOG_SERIOUS("Error code %d when loading the new mirror target for the object %s: %s\n", 
+			LOG_SERIOUS("Error code %d when loading the new mirror target for the object %s: %s\n",
 				    rc, src->name, EngFncs->strerror(rc));
 		}
 
 	}
 	else {
-		LOG_SERIOUS("Error code %d when getting the target for the object %s: %s\n", 
+		LOG_SERIOUS("Error code %d when getting the target for the object %s: %s\n",
 			    rc, src->name, EngFncs->strerror(rc));
 	}
 
@@ -824,9 +824,9 @@ static int do_offline_copy( storage_object_t *src, storage_object_t *tgt, copy_j
  */
 int dos_move_segment_commit( DISKSEG *src, DISKSEG *tgt, copy_job_t *job )
 {
-	int rc=0;       
-	char * choices[] = {"Yes", "No", NULL};        
-	int answer = 0;    
+	int rc=0;
+	char * choices[] = {_("Yes"), _("No"), NULL};
+	int answer = 0;
 	logical_volume_t *vol=NULL;
 
 	LOG_ENTRY();
