@@ -320,7 +320,22 @@ static inline DISKSEG * dos_malloc_segment(LOGICALDISK *ld, int minor, storage_c
                 else {
                         if (name[strlen(name)-1] == '/') {
                                 strcat(name, "part");
-                        }
+			} else {
+				// Special case for HP/Compaq disk arrays.
+				// These disks have names like "cciss/c0d0",
+				// and the segments need to be named like
+				// "cciss/c0d0p1". Search for the pattern
+				// "name/c<digits>d<digits>".
+				char junk1[64];
+				unsigned int junk2, junk3;
+				int rc = 0;
+				rc = sscanf(name, "%63[^/]/c%ud%u",
+					    junk1, &junk2, &junk3);
+				if (rc == 3) {
+					strcat(name, "p");
+				}
+				rc = 0;
+			}
                 }
 		sprintf(seg->name, "%s%d", name, minor);
 
