@@ -71,8 +71,8 @@ int dl_get_drivelink_list( list_anchor_t *list )
         LOG_EXIT_INT(rc);
         return rc;
 }
- 
- 
+
+
 /*
  *  Function: dl_isa_parent
  *
@@ -80,7 +80,7 @@ int dl_get_drivelink_list( list_anchor_t *list )
  *  a top level parent object.  Meaning that it is found at
  *  a higher level in the feature stack.
  */
-boolean dl_isa_parent( storage_object_t *parent, 
+boolean dl_isa_parent( storage_object_t *parent,
                        storage_object_t *object )
 {
         boolean rc = FALSE;
@@ -99,12 +99,12 @@ boolean dl_isa_parent( storage_object_t *parent,
                         break;
                 }
         }
-  
+
         LOG_EXIT_BOOL(rc);
         return rc;
 }
-         
-         
+
+
 /*
  *  Function: dl_setup_geometry
  *
@@ -138,7 +138,7 @@ int dl_setup_geometry( storage_object_t  *drivelink )
 
         // walk child objects
         LIST_FOR_EACH(drivelink->child_objects, iter, child) {
- 
+
                 if ( !dl_isa_missing_child(child) ) {
 
                         if ( got_initial_CHS_values == FALSE ) {
@@ -195,7 +195,7 @@ int dl_setup_geometry( storage_object_t  *drivelink )
         }
 
         // finally, calculate a cylinder count for this aggregate
-        drivelink->geometry.cylinders = drivelink->size / 
+        drivelink->geometry.cylinders = drivelink->size /
                                         (drivelink->geometry.heads*drivelink->geometry.sectors_per_track);
 
         LOG_DEBUG(" Drivelink Geometry ...\n");
@@ -251,7 +251,7 @@ storage_object_t *  dl_get_last_child( storage_object_t *object )
 
         if ( dl_isa_drivelink(object) == TRUE ) {
                 pdata =  (drivelink_private_data_t *) object->private_data;
-                last_child = pdata->drive_link[pdata->drive_link_count-1].object;                
+                last_child = pdata->drive_link[pdata->drive_link_count-1].object;
         }
 
         LOG_EXIT_PTR(last_child);
@@ -279,7 +279,7 @@ boolean dl_isa_complete_aggregate( storage_object_t *drivelink )
         int     i;
         drivelink_private_data_t *pdata;
 
-        if (dl_isa_drivelink(drivelink)==TRUE) {        
+        if (dl_isa_drivelink(drivelink)==TRUE) {
                 pdata = (drivelink_private_data_t *)drivelink->private_data;
                 for (i=0; i<pdata->drive_link_count; i++) {
                         if ( pdata->drive_link[i].object == NULL ||
@@ -312,9 +312,9 @@ boolean dl_isa_complete_aggregate( storage_object_t *drivelink )
  *  Returns: feature header in the supplied buffer if RC=0
  *
  */
-int dl_build_feature_header( storage_object_t      *drivelink,         
-                             drive_link_t          *child,           
-                             evms_feature_header_t *fh    ) 
+int dl_build_feature_header( storage_object_t      *drivelink,
+                             drive_link_t          *child,
+                             evms_feature_header_t *fh    )
 {
         int rc=0;
         drivelink_private_data_t *pdata;
@@ -338,8 +338,8 @@ int dl_build_feature_header( storage_object_t      *drivelink,
         feature_header_sequence_number   = pdata->sequence_number;
 
         // 1st copy of metadata is found immediately before feature header sectors
-        feature_header_data1_start_lsn =  child->object->size - 
-                                          (FEATURE_HEADER_SECTOR_COUNT*2) - 
+        feature_header_data1_start_lsn =  child->object->size -
+                                          (FEATURE_HEADER_SECTOR_COUNT*2) -
                                           DRIVELINK_METADATA_SECTOR_COUNT;
 
         feature_header_data1_size      =  DRIVELINK_METADATA_SECTOR_COUNT;
@@ -349,7 +349,7 @@ int dl_build_feature_header( storage_object_t      *drivelink,
         feature_header_data2_size      = DRIVELINK_METADATA_SECTOR_COUNT;
 
         fh->signature                  = EVMS_FEATURE_HEADER_SIGNATURE;
-        fh->feature_id                 = SetPluginID(EVMS_OEM_IBM, EVMS_FEATURE, EVMS_DRIVELINK_FEATURE_ID );
+        fh->feature_id                 = EVMS_DRIVE_LINK_PLUGIN_ID;
         fh->sequence_number            = feature_header_sequence_number;
         fh->feature_data1_size         = feature_header_data1_size;
         fh->feature_data2_size         = feature_header_data2_size;
@@ -378,7 +378,7 @@ void dl_free_drivelink_object( storage_object_t  *object )
 {
         if (object) {
                 drivelink_private_data_t * pdata = (drivelink_private_data_t *)object->private_data;
-                if (pdata) {            
+                if (pdata) {
                         EngFncs->unregister_name( object->name);
                         dl_unregister_serial_number(pdata->parent_serial_number);
                         free(object->private_data);
@@ -500,7 +500,7 @@ int dl_table_fixup(storage_object_t * drivelink)
 /*
  *  Function: dl_build_linear_mapping
  *
- *  Called to walk a drivelink and create a mapping between the 
+ *  Called to walk a drivelink and create a mapping between the
  *  logical sector numbers of the drivelink and the useable areas
  *  of the child objects.
  */
@@ -541,7 +541,7 @@ int dl_build_linear_mapping( storage_object_t *drivelink )
                            pdata->drive_link[i].end_lsn,
                            pdata->drive_link[i].sector_count );
         }
-        
+
         LOG_EXIT_INT(rc);
         return rc;
 }
