@@ -78,7 +78,7 @@ static int dl_build_missing_feature_header( storage_object_t  *child,
         if (fh ){
                 child->feature_header = fh;
                 fh->signature   = EVMS_FEATURE_HEADER_SIGNATURE;
-                fh->feature_id  = SetPluginID(EVMS_OEM_IBM, EVMS_FEATURE, EVMS_DRIVELINK_FEATURE_ID );
+                fh->feature_id  = EVMS_DRIVE_LINK_PLUGIN_ID;
                 strncpy( fh->object_name, drivelink_name, EVMS_VOLUME_NAME_SIZE );
         }
         else {
