@@ -57,7 +57,7 @@ static int dl_build_reverse_ordered_child_object_list( storage_object_t *driveli
         REQUIRE(drivelink != NULL);
         REQUIRE(drivelink->private_data != NULL);
         REQUIRE(list != NULL);
-        
+
         pdata = (drivelink_private_data_t  *) drivelink->private_data;
 
         starting_count = EngFncs->list_count(list);
@@ -71,7 +71,7 @@ static int dl_build_reverse_ordered_child_object_list( storage_object_t *driveli
                 if ( pdata->drive_link[i].object != NULL ) {
 
                         LIST_FOR_EACH(list, iter, obj) {
-                
+
                                 if (obj == pdata->drive_link[i].object) {
 
                                         iter2 = EngFncs->insert_thing(reverse_ordered_list, obj,
@@ -82,12 +82,12 @@ static int dl_build_reverse_ordered_child_object_list( storage_object_t *driveli
 
                                         break;
                                 }
-                            
+
                         }
                 }
 
         }
- 
+
         // if I finished with a reversed ordered list that contains
         // the same number of objects that I started with ... then
         // it means that the drive link ordering table matches the
@@ -101,7 +101,7 @@ static int dl_build_reverse_ordered_child_object_list( storage_object_t *driveli
                 EngFncs->delete_all_elements(list);
 
                 // then copy reordered objects to callers list
-                rc = EngFncs->merge_lists(list, reverse_ordered_list, NULL);
+                rc = EngFncs->merge_lists(list, reverse_ordered_list, NULL, NULL);
         }
         else {
                 EngFncs->destroy_list(reverse_ordered_list);
@@ -160,7 +160,7 @@ int dl_get_option_count(task_context_t * task)
  */
 static int allocate_replace_option_descriptors( task_context_t * context )
 {
-        int rc; 
+        int rc;
 
         LOG_ENTRY();
         rc=0;
@@ -172,7 +172,7 @@ static int allocate_replace_option_descriptors( task_context_t * context )
 /*
  *  Called to initialize the REPLACE options in the task context.
  */
-static int initialize_replace_option_descriptors( storage_object_t  * missing_child, 
+static int initialize_replace_option_descriptors( storage_object_t  * missing_child,
                                                   task_context_t    * context )
 {
         int rc;
@@ -187,7 +187,7 @@ static int initialize_replace_option_descriptors( storage_object_t  * missing_ch
 /*
  *  Function: set replace object
  *
- *  Called by set_object() to validate the task selected 
+ *  Called by set_object() to validate the task selected
  *  object.
  */
 static int set_replace_object( task_context_t * context,
@@ -215,12 +215,12 @@ static int set_replace_object( task_context_t * context,
  *  Function: get acceptable replace objects
  *
  *  Called when setting up a replace task to go out and find all the
- *  objects that we could replace a missing child with. 
+ *  objects that we could replace a missing child with.
  */
 static int get_acceptable_replace_objects( task_context_t * context )
 {
         int  rc = EINVAL;
-        int  count=0;   
+        int  count=0;
         list_element_t iter1, iter2;
         storage_object_t * parent;
         storage_object_t * new_child;
@@ -255,7 +255,7 @@ static int get_acceptable_replace_objects( task_context_t * context )
                                                 EngFncs->delete_element(iter1);
                                         }
                                 }
-                        }                       
+                        }
                 }
                 else {
                         LOG_ERROR("error, context already has acceptable objects\n");
@@ -278,24 +278,24 @@ static int dl_allocate_create_option_descriptors( task_context_t * context )
         LOG_ENTRY();
 
         REQUIRE(context != NULL);
-   
-        context->option_descriptors->count = DL_CREATE_OPTION_COUNT ;     
+
+        context->option_descriptors->count = DL_CREATE_OPTION_COUNT ;
 
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].flags = EVMS_OPTION_FLAGS_INACTIVE ;
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].constraint.list = NULL;
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].constraint_type = EVMS_Collection_None;
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].help = NULL;
-        SET_STRING( context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].name, DL_CREATE_LINKNAME_NAME );
+        context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].name = EngFncs->engine_strdup( DL_CREATE_LINKNAME_NAME );
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].min_len = 1;
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].max_len = EVMS_VOLUME_NAME_SIZE;
-        SET_STRING( context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].tip, "The name to be given to the drivelink object.");
-        SET_STRING( context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].title, "Name" );
+        context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].tip = EngFncs->engine_strdup( _("The name to be given to the drivelink object.") );
+        context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].title = EngFncs->engine_strdup( _("Name") );
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].type = EVMS_Type_String;
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].unit = EVMS_Unit_None;
         context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].value.s = EngFncs->engine_alloc(EVMS_VOLUME_NAME_SIZE+1);
         if (context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].value.s) {
                 memset( context->option_descriptors->option[DL_CREATE_LINKNAME_INDEX].value.s,
-                        0, 
+                        0,
                         EVMS_VOLUME_NAME_SIZE);
         }
         else {
@@ -325,7 +325,7 @@ static int dl_initialize_create_option_descriptors(  task_context_t * context )
                 LOG_ERROR("error, wrong number of option descriptors ... count= %d\n", context->option_descriptors->count);
                 rc = EINVAL;
         }
-   
+
         LOG_EXIT_INT(rc);
         return rc;
 }
@@ -340,7 +340,7 @@ static int dl_allocate_expand_option_descriptors( task_context_t * context )
         REQUIRE(context != NULL);
 
         context->option_descriptors->count = 0;  // no options
-        
+
         LOG_EXIT_INT(rc);
         return rc;
 }
@@ -381,7 +381,7 @@ static int dl_set_create_object( task_context_t * context,
         REQUIRE(effect != NULL);
 
         linkcount = EngFncs->list_count(context->selected_objects);
-    
+
         REQUIRE(linkcount > 0 && linkcount <= EVMS_DRIVELINK_MAX_ENTRIES);
 
         rc = dl_initialize_create_option_descriptors( context );
@@ -421,7 +421,7 @@ static int dl_set_expand_object( task_context_t * context,
 
 
         LOG_ENTRY();
-        
+
         REQUIRE(context != NULL);
         REQUIRE(declined_objects != NULL);
         REQUIRE(effect != NULL);
@@ -434,10 +434,10 @@ static int dl_set_expand_object( task_context_t * context,
         REQUIRE(max_objects_allowed > 0);
 
         LIST_FOR_EACH(context->selected_objects, iter, obj) {
-        
+
                 if ( max_objects_allowed > selected_objects_count ) {
                         ++selected_objects_count;
-                        *effect |=  EVMS_Effect_Reload_Options;                 
+                        *effect |=  EVMS_Effect_Reload_Options;
                 }
                 else {
 
@@ -605,9 +605,9 @@ static int dl_set_shrink_object( task_context_t * context,
                         }
 
                 }
-                
+
         }
-           
+
         if (declined_object_count == 0) {
 
                 sector_count_t   shrink_sectors=0;
@@ -718,7 +718,7 @@ int dl_set_objects( task_context_t * context,
         int rc=0;
 
         LOG_ENTRY();
-        
+
         REQUIRE(context != NULL);
         REQUIRE(declined_objects != NULL);
         REQUIRE(effect != NULL);
@@ -736,7 +736,7 @@ int dl_set_objects( task_context_t * context,
                 case EVMS_Task_Shrink:
                         rc = dl_set_shrink_object( context, declined_objects, effect );
                         break;
-                
+
                 case EVMS_Replace_Missing_DL_Child:
                         rc = set_replace_object( context, declined_objects, effect );
                         break;
@@ -769,7 +769,7 @@ static int dl_set_create_option( task_context_t * context,
                 strlen(value->s) <= EVMS_VOLUME_NAME_SIZE );
 
         rc = EngFncs->validate_name( value->s );
-        
+
         if (rc == 0) {
                 strcpy( context->option_descriptors->option[index].value.s, value->s);
         }
@@ -787,7 +787,7 @@ int dl_set_option( task_context_t * context,
         int rc=EINVAL;
 
         LOG_ENTRY();
-        
+
         REQUIRE(context != NULL);
         REQUIRE(index == DL_CREATE_LINKNAME_INDEX);
         REQUIRE(value != NULL);
@@ -946,7 +946,7 @@ int dl_init_task( task_context_t * context )
         LOG_ENTRY();
 
         REQUIRE(context != NULL);
-       
+
         switch (context->action) {
 
                 case EVMS_Task_Create:
@@ -961,9 +961,9 @@ int dl_init_task( task_context_t * context )
                         break;
 
                 case EVMS_Task_Expand:
-                        
+
                         REQUIRE(dl_isa_drivelink(context->object) == TRUE);
-                        
+
                         pdata = (drivelink_private_data_t *) context->object->private_data;
 
                         context->min_selected_objects = 1;
@@ -1030,7 +1030,7 @@ int dl_get_info( storage_object_t  * object, char *name,  extended_info_array_t
 
         REQUIRE(dl_isa_drivelink(object) == TRUE);
         REQUIRE(info != NULL);
-        
+
         pdata = (drivelink_private_data_t *) object->private_data;
 
         Info = EngFncs->engine_alloc( sizeof(extended_info_array_t) + ( DL_INFO_COUNT * sizeof(extended_info_t) ) );
@@ -1039,20 +1039,20 @@ int dl_get_info( storage_object_t  * object, char *name,  extended_info_array_t
                 // the following info isnt available for missing child objects
                 if (pdata->signature & MISSING_CHILD_SIGNATURE) {
 
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].name, "Name" );
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].title, "Name" );
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].desc, "A temporary name given to the missing drivelink object that is used to assist with recovery.");
+                        Info->info[DL_INFO_NAME_INDEX].name = EngFncs->engine_strdup( "Name" );
+                        Info->info[DL_INFO_NAME_INDEX].title = EngFncs->engine_strdup( _("Name") );
+                        Info->info[DL_INFO_NAME_INDEX].desc = EngFncs->engine_strdup( _("A temporary name given to the missing drivelink object that is used to assist with recovery.") );
                         Info->info[DL_INFO_NAME_INDEX].type               = EVMS_Type_String;
                         Info->info[DL_INFO_NAME_INDEX].unit               = EVMS_Unit_None;
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].value.s, object->name );
+                        Info->info[DL_INFO_NAME_INDEX].value.s = EngFncs->engine_strdup( object->name );
                         Info->info[DL_INFO_NAME_INDEX].collection_type    = EVMS_Collection_None;
                         memset( &Info->info[DL_INFO_NAME_INDEX].group, 0, sizeof(group_info_t));
 
                         Info->count += 1;
 
-                        SET_STRING( Info->info[DL_INFO_SIZE_INDEX].name, "Size" );
-                        SET_STRING( Info->info[DL_INFO_SIZE_INDEX].title, "Size" );
-                        SET_STRING( Info->info[DL_INFO_SIZE_INDEX].desc, "The size of the object that is missing, i.e., the useable size after subtracting metadata.");
+                        Info->info[DL_INFO_SIZE_INDEX].name = EngFncs->engine_strdup( "Size" );
+                        Info->info[DL_INFO_SIZE_INDEX].title = EngFncs->engine_strdup( _("Size") );
+                        Info->info[DL_INFO_SIZE_INDEX].desc = EngFncs->engine_strdup( _("The size of the object that is missing, i.e., the useable size after subtracting metadata.") );
                         Info->info[DL_INFO_SIZE_INDEX].type               = EVMS_Type_Unsigned_Int64;
                         Info->info[DL_INFO_SIZE_INDEX].unit               = EVMS_Unit_Sectors;
                         Info->info[DL_INFO_SIZE_INDEX].value.ui64         = object->size;
@@ -1065,20 +1065,20 @@ int dl_get_info( storage_object_t  * object, char *name,  extended_info_array_t
                 }
                 else {
 
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].name, "Name" );
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].title, "Name" );
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].desc, "This is the name given to the storage object. It must be unique on the system.");
+                        Info->info[DL_INFO_NAME_INDEX].name = EngFncs->engine_strdup( "Name" );
+                        Info->info[DL_INFO_NAME_INDEX].title = EngFncs->engine_strdup( _("Name") );
+                        Info->info[DL_INFO_NAME_INDEX].desc = EngFncs->engine_strdup( _("This is the name given to the storage object. It must be unique on the system.") );
                         Info->info[DL_INFO_NAME_INDEX].type               = EVMS_Type_String;
                         Info->info[DL_INFO_NAME_INDEX].unit               = EVMS_Unit_None;
-                        SET_STRING( Info->info[DL_INFO_NAME_INDEX].value.s, object->name );
+                        Info->info[DL_INFO_NAME_INDEX].value.s = EngFncs->engine_strdup( object->name );
                         Info->info[DL_INFO_NAME_INDEX].collection_type    = EVMS_Collection_None;
                         memset( &Info->info[DL_INFO_NAME_INDEX].group, 0, sizeof(group_info_t));
 
                         Info->count += 1;
 
-                        SET_STRING( Info->info[DL_INFO_SIZE_INDEX].name, "Size" );
-                        SET_STRING( Info->info[DL_INFO_SIZE_INDEX].title, "Size" );
-                        SET_STRING( Info->info[DL_INFO_SIZE_INDEX].desc, "This is the size of the entire drivelink, i.e., the sum of all the drivelink child storage objects.");
+                        Info->info[DL_INFO_SIZE_INDEX].name = EngFncs->engine_strdup( "Size" );
+                        Info->info[DL_INFO_SIZE_INDEX].title = EngFncs->engine_strdup( _("Size") );
+                        Info->info[DL_INFO_SIZE_INDEX].desc = EngFncs->engine_strdup( _("This is the size of the entire drivelink, i.e., the sum of all the drivelink child storage objects.") );
                         Info->info[DL_INFO_SIZE_INDEX].type               = EVMS_Type_Unsigned_Int64;
                         Info->info[DL_INFO_SIZE_INDEX].unit               = EVMS_Unit_Sectors;
                         Info->info[DL_INFO_SIZE_INDEX].value.ui64         = object->size;
@@ -1088,9 +1088,9 @@ int dl_get_info( storage_object_t  * object, char *name,  extended_info_array_t
 
                         Info->count += 1;
 
-                        SET_STRING( Info->info[DL_INFO_LINKS_INDEX].name, "Links" );
-                        SET_STRING( Info->info[DL_INFO_LINKS_INDEX].title, "Children" );
-                        SET_STRING( Info->info[DL_INFO_LINKS_INDEX].desc, "This is the number of child storage objects being linked by the drivelink feature.");
+                        Info->info[DL_INFO_LINKS_INDEX].name = EngFncs->engine_strdup( "Links" );
+                        Info->info[DL_INFO_LINKS_INDEX].title = EngFncs->engine_strdup( _("Children") );
+                        Info->info[DL_INFO_LINKS_INDEX].desc = EngFncs->engine_strdup( _("This is the number of child storage objects being linked by the drivelink feature.") );
                         Info->info[DL_INFO_LINKS_INDEX].type               = EVMS_Type_Unsigned_Int64;
                         Info->info[DL_INFO_LINKS_INDEX].unit               = EVMS_Unit_None;
                         Info->info[DL_INFO_LINKS_INDEX].value.ui64         = pdata->drive_link_count;
@@ -1099,9 +1099,9 @@ int dl_get_info( storage_object_t  * object, char *name,  extended_info_array_t
 
                         Info->count += 1;
 
-                        SET_STRING( Info->info[DL_INFO_PSN_INDEX].name, "PSN" );
-                        SET_STRING( Info->info[DL_INFO_PSN_INDEX].title, "Parent SN" );
-                        SET_STRING( Info->info[DL_INFO_PSN_INDEX].desc, "The serial number of the parent drivelink object.");
+                        Info->info[DL_INFO_PSN_INDEX].name = EngFncs->engine_strdup( "PSN" );
+                        Info->info[DL_INFO_PSN_INDEX].title = EngFncs->engine_strdup( _("Parent Serial Number") );
+                        Info->info[DL_INFO_PSN_INDEX].desc = EngFncs->engine_strdup( _("The serial number of the parent drivelink object.") );
                         Info->info[DL_INFO_PSN_INDEX].type               = EVMS_Type_Unsigned_Int64;
                         Info->info[DL_INFO_PSN_INDEX].unit               = EVMS_Unit_None;
                         Info->info[DL_INFO_PSN_INDEX].format             = EVMS_Format_Hex;
@@ -1122,7 +1122,7 @@ int dl_get_info( storage_object_t  * object, char *name,  extended_info_array_t
                 rc = ENOMEM;
                 LOG_ERROR("unable to malloc memory for extended info array\n");
         }
-    
+
 
         LOG_EXIT_INT(rc);
         return rc;
@@ -1167,57 +1167,59 @@ int dl_get_plugin_info( char * descriptor_name, extended_info_array_t * * info )
                         dl_plugin_record->required_plugin_api_version.plugin.minor,
                         dl_plugin_record->required_plugin_api_version.plugin.patchlevel );
 
-                SET_STRING( Info->info[DL_PLUGIN_INFO_SNAME_INDEX].name, "Short Name" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_SNAME_INDEX].title, "Short Name" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_SNAME_INDEX].desc, "A short name given to this plugin.");
+                Info->info[DL_PLUGIN_INFO_SNAME_INDEX].name = EngFncs->engine_strdup( "Short Name" );
+                Info->info[DL_PLUGIN_INFO_SNAME_INDEX].title = EngFncs->engine_strdup( _("Short Name") );
+                Info->info[DL_PLUGIN_INFO_SNAME_INDEX].desc = EngFncs->engine_strdup( _("A short name given to this plug-in") );
                 Info->info[DL_PLUGIN_INFO_SNAME_INDEX].type               = EVMS_Type_String;
                 Info->info[DL_PLUGIN_INFO_SNAME_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[DL_PLUGIN_INFO_SNAME_INDEX].value.s, dl_plugin_record->short_name );
+                Info->info[DL_PLUGIN_INFO_SNAME_INDEX].value.s = EngFncs->engine_strdup( dl_plugin_record->short_name );
                 Info->info[DL_PLUGIN_INFO_SNAME_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[DL_PLUGIN_INFO_SNAME_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[DL_PLUGIN_INFO_LNAME_INDEX].name, "Long Name" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_LNAME_INDEX].title, "Long Name" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_LNAME_INDEX].desc, "A long name given to this plugin.");
+                Info->info[DL_PLUGIN_INFO_LNAME_INDEX].name = EngFncs->engine_strdup( "Long Name" );
+                Info->info[DL_PLUGIN_INFO_LNAME_INDEX].title = EngFncs->engine_strdup( _("Long Name") );
+                Info->info[DL_PLUGIN_INFO_LNAME_INDEX].desc = EngFncs->engine_strdup( _("A longer, more descriptive name for this plug-in") );
                 Info->info[DL_PLUGIN_INFO_LNAME_INDEX].type               = EVMS_Type_String;
                 Info->info[DL_PLUGIN_INFO_LNAME_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[DL_PLUGIN_INFO_LNAME_INDEX].value.s, dl_plugin_record->long_name );
+                Info->info[DL_PLUGIN_INFO_LNAME_INDEX].value.s = EngFncs->engine_strdup( dl_plugin_record->long_name );
                 Info->info[DL_PLUGIN_INFO_LNAME_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[DL_PLUGIN_INFO_LNAME_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[DL_PLUGIN_INFO_TYPE_INDEX].name, "Type" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_TYPE_INDEX].title, "Plugin Type" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_TYPE_INDEX].desc, "There are various types of plugins; each responsible for some kind of storage object.");
+                Info->info[DL_PLUGIN_INFO_TYPE_INDEX].name = EngFncs->engine_strdup( "Type" );
+                Info->info[DL_PLUGIN_INFO_TYPE_INDEX].title = EngFncs->engine_strdup( _("Plug-in Type") );
+                Info->info[DL_PLUGIN_INFO_TYPE_INDEX].desc = EngFncs->engine_strdup( _("There are various types of plug-ins, each responsible for some kind of storage object or logical volume.") );
                 Info->info[DL_PLUGIN_INFO_TYPE_INDEX].type               = EVMS_Type_String;
                 Info->info[DL_PLUGIN_INFO_TYPE_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[DL_PLUGIN_INFO_TYPE_INDEX].value.s, "Aggregate Class Feature" );
+                Info->info[DL_PLUGIN_INFO_TYPE_INDEX].value.s = EngFncs->engine_strdup( _("EVMS Feature") );
                 Info->info[DL_PLUGIN_INFO_TYPE_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[DL_PLUGIN_INFO_TYPE_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[DL_PLUGIN_INFO_VERSION_INDEX].name, "Version" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_VERSION_INDEX].title, "Plugin Version" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_VERSION_INDEX].desc, "This is the version number of the plugin.");
+                Info->info[DL_PLUGIN_INFO_VERSION_INDEX].name = EngFncs->engine_strdup( "Version" );
+                Info->info[DL_PLUGIN_INFO_VERSION_INDEX].title = EngFncs->engine_strdup( _("Plug-in Version") );
+                Info->info[DL_PLUGIN_INFO_VERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version number of the plug-in.") );
                 Info->info[DL_PLUGIN_INFO_VERSION_INDEX].type               = EVMS_Type_String;
                 Info->info[DL_PLUGIN_INFO_VERSION_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[DL_PLUGIN_INFO_VERSION_INDEX].value.s, version_string );
+                Info->info[DL_PLUGIN_INFO_VERSION_INDEX].value.s = EngFncs->engine_strdup( version_string );
                 Info->info[DL_PLUGIN_INFO_VERSION_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[DL_PLUGIN_INFO_VERSION_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].name, "Required Engine Services Version" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].title, "Required Engine Services Version" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].desc, "This is the version of the Engine services that this plug-in requires. It will not run on older versions of the Engine services.");
+                Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].name = EngFncs->engine_strdup( "Required Engine Services Version" );
+                Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].title = EngFncs->engine_strdup( _("Required Engine Services Version") );
+                Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version of the Engine services that this plug-in requires.  "
+												   "It will not run on older versions of the Engine services.") );
                 Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].type               = EVMS_Type_String;
                 Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].value.s, required_engine_api_version_string );
+                Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].value.s = EngFncs->engine_strdup( required_engine_api_version_string );
                 Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[DL_PLUGIN_INFO_REQENGSVCVERSION_INDEX].group, 0, sizeof(group_info_t));
 
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].name, "Required Engine Plug-in API Version" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].title, "Required Engine Plug-in API Version" );
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].desc, "This is the version of the Engine plug-in API that this plug-in requires. It will not run on older versions of the Engine plug-in API.");
+                Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].name = EngFncs->engine_strdup( "Required Engine Plug-in API Version" );
+                Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].title = EngFncs->engine_strdup( _("Required Engine Plug-in API Version") );
+                Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].desc = EngFncs->engine_strdup( _("This is the version of the Engine plug-in API that this plug-in requires. "
+												    "It will not run on older versions of the Engine plug-in API.") );
                 Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].type               = EVMS_Type_String;
                 Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].unit               = EVMS_Unit_None;
-                SET_STRING( Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].value.s, required_plugin_api_version_string );
+                Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].value.s = EngFncs->engine_strdup( required_plugin_api_version_string );
                 Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].collection_type    = EVMS_Collection_None;
                 memset( &Info->info[DL_PLUGIN_INFO_REQPLUGAPIVERSION_INDEX].group, 0, sizeof(group_info_t));
 
