@@ -1437,9 +1437,7 @@ static fsim_functions_t fsim_ops = {
 };
 
 plugin_record_t ext2_plugin_record = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_FILESYSTEM_INTERFACE_MODULE,
-			  FS_TYPE_EXT2),
+	.id = EVMS_EXT2_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -1465,9 +1463,9 @@ plugin_record_t ext2_plugin_record = {
 		}
 	},
 #endif
-	.short_name = "Ext2/3",
-	.long_name = "Ext2/3 File System Interface Module",
-	.oem_name = "IBM",
+	.short_name = EVMS_EXT2_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_EXT2_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.fsim = &fsim_ops
 	},
