@@ -43,9 +43,6 @@ extern plugin_record_t ext2_plugin_record;
 extern plugin_record_t *my_plugin_record;
 extern engine_functions_t *EngFncs;
 
-/*  file system type ... used by the SetPluginID macro */
-#define FS_TYPE_EXT2     7
-
 /************************************
  ************************************
  **                                **
