@@ -385,7 +385,7 @@ static gpt_header *  get_gpt_header( storage_object_t *object, lsn_t lsn )
 static boolean isa_object_with_valid_gpt_header( LOGICALDISK  *ld )
 {
         gpt_header  *gh  = NULL;
-        char * choices[] = {"Yes", "No", NULL};
+        char * choices[] = {_("Yes"), _("No"), NULL};
         int answer = 0;     // Initialize to Revert
 
 
@@ -604,7 +604,8 @@ static int get_segments(  storage_object_t *object )
 
         // if primary gpt header is missing then mark it dirty so engine will commit it.
         if (md1_dirty == TRUE) {
-                MESSAGE("\nPrimary GPT Header is missing or corrupt. Marking %s dirty to correct the problem\n",
+                MESSAGE(_("Primary GPT Header is missing or corrupt.  "
+			  "Marking %s dirty to correct the problem.\n"),
                         metadata1->name );
                 metadata1->flags |= SOFLAG_DIRTY;
         }
@@ -631,7 +632,8 @@ static int get_segments(  storage_object_t *object )
 
         // if secondary gpt header is missing then mark it dirty so engine will commit it.
         if (md2_dirty == TRUE) {
-                MESSAGE("\nAlternate GPT Header is missing or corrupt. Marking %s dirty to correct the problem\n",
+                MESSAGE(_("Alternate GPT Header is missing or corrupt.  "
+			  "Marking %s dirty to correct the problem.\n"),
                         metadata2->name );
                 metadata2->flags |= SOFLAG_DIRTY;
         }
@@ -716,7 +718,7 @@ static void prune_gpt_segments_from_list( list_anchor_t list )
 
                 if ( seg->plugin == gpt_plugin_record_ptr ) {
                         free_gpt_disk_segment(seg);
-                        prune = TRUE;               
+                        prune = TRUE;
                 }
 
                 if (prune==TRUE) EngFncs->delete_element(iter);
@@ -756,22 +758,23 @@ static int gpt_get_devmap_info( DISKSEG *seg )
 
                                         dev = (dm_device_t *) targets->data.linear;
 
-                                        if ( ( seg->start != dev->start )||
-                                             ( seg->size  != targets->length )) {
-                                                LOG_DEBUG("this segment is being marked needs_activate\n");
+                                        if ( (seg->start == dev->start) &&
+                                             (seg->size  == targets->length)) {
+                                                /* Mappings match. */
+                                                LOG_DEBUG("segment %s matches kernel mapping.\n", seg->name);
+                                                seg->flags &= ~SOFLAG_NEEDS_ACTIVATE;
+                                        } else {
+                                                LOG_DEBUG("segment %s is being marked needs_activate\n", seg->name);
                                                 seg->flags |= SOFLAG_NEEDS_ACTIVATE;
                                         }
-                                        else {
-                                                seg->flags &= ~SOFLAG_NEEDS_ACTIVATE;
-                                        }
 
-                                }
+                                } else {
+                                        LOG_DEBUG("segment %s is being marked needs_activate\n", seg->name);
+                                        seg->flags |= SOFLAG_NEEDS_ACTIVATE;
+				}
 
                                 if (targets) EngFncs->dm_deallocate_targets(targets);
                         }
-                        else {
-                                seg->flags |= SOFLAG_NEEDS_ACTIVATE;
-                        }
 
                 }
 
