@@ -697,7 +697,7 @@ static int Assign_SegmentManager_ToDisk( LOGICALDISK *ld, boolean create_system_
         end_useable = pt_lba2 - 1;
 
         // generate a unique disk id
-        uuid_generate_random( (char *) &disk_id );
+        uuid_generate_random( (unsigned char *) (void *) &disk_id );
 
 
 
@@ -796,7 +796,7 @@ static int Assign_SegmentManager_ToDisk( LOGICALDISK *ld, boolean create_system_
 
                         memcpy(&pdata->guid_type, &EFI_SYSTEM_PARTITION, sizeof(guid_t) );
 
-                        uuid_generate_random( (char *) &pdata->guid_id );
+                        uuid_generate_random( (unsigned char *) &pdata->guid_id );
 
                         if ( isa_disk_object(ld) == FALSE ) {
                                 sprintf(esp->name, "%s.%d", devname, 1);
@@ -951,7 +951,7 @@ static int GPT_Assign( storage_object_t * input_object,
                        option_array_t * options)
 {
         int rc=EINVAL;
-        boolean create_system_partition;
+        boolean create_system_partition=FALSE;
 
         LOG_ENTRY();
 
@@ -1247,7 +1247,7 @@ static int CreateDiskSegment( storage_object_t      * freespace,            /* a
                                 memcpy(&pdata->guid_type, &GPT_SWAP_PARTITION, sizeof(guid_t) );
                         }
 
-                        uuid_generate_random( (char *) &pdata->guid_id );
+                        uuid_generate_random( (unsigned char *) &pdata->guid_id );
 
                         get_device_name(ld, devname);
 
