@@ -1855,14 +1855,14 @@ sm_cnct(void)
 			sm_ch->ops->destroy(sm_ch);
 			sm_ch = NULL;
 		} else if(peer_recv(&msg, sm_ch, 1) != IPC_OK){
-        		LOG_SERIOUS("Error: Daemon rejected the connection.  There must be some other client already connected.");
+        		LOG_SERIOUS("Error: Daemon rejected the connection.  There must be some other client already connected.\n");
 			sm_ch->ops->destroy(sm_ch);
 			sm_ch = NULL;
 		} else {
 			peer_recv_done(msg);
 			/* recieve and initialize the low level membership */
 			if(sm_recv_llm(sm_ch) == FALSE) {
-				LOG_SERIOUS("Error: Daemon did not send the llm information.  Probably is misbehaving.");
+				LOG_SERIOUS("Error: Daemon did not send the llm information.  Probably is misbehaving.\n");
 				sm_ch->ops->destroy(sm_ch);
 				sm_ch = NULL;
 			}
@@ -1912,7 +1912,7 @@ ece_send_msg(ece_msg_t *ecemsg)
 	char  *node = NULL;
 	gboolean multicast=FALSE;
 	ece_nodeid_t allnode  = ECE_ALL_NODES;
-	u_int32_t corr, crc, ackval;
+	u_int32_t orig_corr, crc, ackval;
 	int ret;
 
 
@@ -1951,8 +1951,8 @@ ece_send_msg(ece_msg_t *ecemsg)
    	pthread_mutex_lock(&gl_ece_mutex);
 	crc = get_curr_crc();
 	ackval = ++gl_ece_ackval;
-	if((corr = ecemsg->corrolator)==0) {
-		corr = gl_ece_cor++;
+	if((orig_corr = ecemsg->corrolator)==0) {
+		ecemsg->corrolator = gl_ece_cor++;
 	}
    	pthread_mutex_unlock(&gl_ece_mutex);
 
@@ -1964,12 +1964,11 @@ ece_send_msg(ece_msg_t *ecemsg)
 	ret = frag_send_msg_wait(ecemsg,
 			multicast,
 			node,
-			corr,
+			ecemsg->corrolator,
 			crc,
 			ackval);
 
 	if(!ret) {
-		ecemsg->corrolator = corr;
 		if(!multicast &&
 		(gl_ece_mode == SLAVE || strcmp(node, llm_getmynodeid())!=0)){
 			/* wait till an acknowledgement from the receiver is
@@ -1977,6 +1976,8 @@ ece_send_msg(ece_msg_t *ecemsg)
 			 */
 			ret = condition_wait(node, ackval);
 		}
+	} else {
+                ecemsg->corrolator = orig_corr;
 	}
 
 	LOG_EXIT_INT(ret);
