@@ -1852,9 +1852,7 @@ static fsim_functions_t fsim_ops = {
 };
 
 plugin_record_t jfs_plugin_record = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_FILESYSTEM_INTERFACE_MODULE,
-			  FS_TYPE_JFS),
+	.id = EVMS_JFS_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -1872,9 +1870,9 @@ plugin_record_t jfs_plugin_record = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "JFS",
-	.long_name = "JFS File System Interface Module",
-	.oem_name = "IBM",
+	.short_name = EVMS_JFS_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_JFS_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.fsim = &fsim_ops
 	},
