@@ -34,9 +34,6 @@ extern plugin_record_t jfs_plugin_record;
 extern plugin_record_t *my_plugin_record;
 extern engine_functions_t *EngFncs;
 
-// file system type ... used by the SetPluginID macro
-#define FS_TYPE_JFS     6
-
 /**********************************
  **********************************
  **                              **
