@@ -268,11 +268,11 @@ int lvm_find_group_for_pv(storage_object_t * segment,
 	/* Use the UUID from the VG metadata to determine if this group
 	 * has already been discovered and constructed.
 	 */
-	lvm_find_group_for_uuid(vg->vg_uuid, group);
+	lvm_find_group_for_uuid((char *)vg->vg_uuid, group);
 
 	if (!*group) {
 		/* Create a new group entry and add to the global list. */
-		*group = lvm_allocate_volume_group(vg, pv->vg_name,
+		*group = lvm_allocate_volume_group(vg, (char *)pv->vg_name,
 						   segment->disk_group);
 		if (!*group) {
 			rc = ENOMEM;
@@ -422,7 +422,8 @@ int lvm_add_new_pv_to_group(lvm_physical_volume_t * pv_entry,
 	/* Have to enter the PV's UUID in the group's list before adding
 	 * the PV to the group.
 	 */
-	lvm_set_uuid_list_entry(group, pv_entry->number, pv_entry->pv->pv_uuid);
+	lvm_set_uuid_list_entry(group, pv_entry->number,
+				(char *)pv_entry->pv->pv_uuid);
 
 	/* Put the PV on the group's lists. */
 	rc = lvm_add_pv_to_group_list(pv_entry, group);
@@ -473,7 +474,7 @@ static void lvm_consolidate_pvs(lvm_volume_group_t * group)
 			group->pv_list[j]->number = j;
 			group->pv_list[j]->pv->pv_number = j;
 			lvm_set_uuid_list_entry(group, j,
-						group->pv_list[i]->pv->pv_uuid);
+						(char *)group->pv_list[i]->pv->pv_uuid);
 			lvm_clear_uuid_list_entry(group, i);
 			group->pv_list[i] = NULL;
 		}
@@ -675,7 +676,7 @@ vg_disk_t * lvm_initialize_new_vg(u_int32_t pe_size)
 
 	/* Get a new UUID for this group. */
 	memset(vg->vg_uuid, 0, NAME_LEN);
-	rc = lvm_create_uuid(vg->vg_uuid);
+	rc = lvm_create_uuid((char *)vg->vg_uuid);
 	if (rc) {
 		EngFncs->engine_free(vg);
 		vg = NULL;
@@ -1264,7 +1265,7 @@ int lvm_shrink_pv_in_container(storage_container_t *container,
 	/* Calculate the number of extents to remove after the object shrunk. */
 	new_size = consumed_object->size;
 	delta_size = old_size - new_size;
-	removed_extents = (delta_size / group->vg->pe_size) + 
+	removed_extents = (delta_size / group->vg->pe_size) +
 			  ((delta_size % group->vg->pe_size) ? 1 : 0);
 
 	/* Save the old PE map and allocate a new PE map. */
