@@ -83,7 +83,7 @@ int lvm_read_pv(storage_object_t * segment,
 	int rc;
 
 	LOG_ENTRY();
-	LOG_EXTRA("Reading PV metadata from object %s\n", segment->name);
+	LOG_DEBUG("Reading PV metadata from object %s\n", segment->name);
 
 	*pv = NULL;
 
@@ -113,9 +113,17 @@ int lvm_read_pv(storage_object_t * segment,
 	 */
 	if (!(pv_buffer->id[0] == 'H' &&
 	      pv_buffer->id[1] == 'M' &&
-	      (pv_buffer->version == 1 || pv_buffer->version == 2) &&
-	      pv_buffer->pv_size == segment->size)) {
-		LOG_EXTRA("Object %s is not an LVM PV\n", segment->name);
+	      (pv_buffer->version == 1 || pv_buffer->version == 2))) {
+		LOG_DEBUG("Object %s is not an LVM PV - incorrect PV "
+			  "signature or version.\n", segment->name);
+		rc = EINVAL;
+		goto out;
+	}
+
+	if ((pv_buffer->pv_size & ~1UL) != (segment->size & ~1ULL)) {
+		LOG_DEBUG("Object %s has size %u - looking for %"PRIu64"\n",
+			  segment->name, pv_buffer->pv_size, segment->size);
+		LOG_DEBUG("Object %s is not an LVM PV.\n", segment->name);
 		rc = EINVAL;
 		goto out;
 	}
@@ -143,7 +151,7 @@ out:
  *
  * Write the PV metadata sector to the specified PV.
  **/
-int lvm_write_pv(lvm_physical_volume_t * pv_entry)
+int lvm_write_pv(lvm_physical_volume_t * pv_entry, boolean backup)
 {
 	pv_disk_t * pv_buffer;
 	int rc;
@@ -165,8 +173,16 @@ int lvm_write_pv(lvm_physical_volume_t * pv_entry)
 	lvm_endian_convert_pv(pv_buffer);
 
 	/* Write the metadata. */
-	rc = WRITE(pv_entry->segment, bytes_to_sectors(LVM_PV_DISK_BASE), 
-		   bytes_to_sectors(LVM_PV_DISK_SIZE), pv_buffer);
+	if (backup) {
+		rc = EngFncs->save_metadata(pv_entry->group->container->name,
+					    pv_entry->segment->name,
+					    bytes_to_sectors(LVM_PV_DISK_BASE),
+					    bytes_to_sectors(LVM_PV_DISK_SIZE),
+					    pv_buffer);
+	} else {
+		rc = WRITE(pv_entry->segment, bytes_to_sectors(LVM_PV_DISK_BASE),
+			   bytes_to_sectors(LVM_PV_DISK_SIZE), pv_buffer);
+	}
 	if (rc) {
 		LOG_SERIOUS("Error writing PV metadata to object %s\n",
 			    pv_entry->segment->name);
@@ -245,7 +261,7 @@ int lvm_read_vg(storage_object_t * segment,
 	int rc;
 
 	LOG_ENTRY();
-	LOG_EXTRA("Reading VG metadata from object %s\n", segment->name);
+	LOG_DEBUG("Reading VG metadata from object %s\n", segment->name);
 
 	*vg = NULL;
 
@@ -294,7 +310,7 @@ out:
  *
  * Write the VG metadata to the specified PV.
  **/
-int lvm_write_vg(lvm_physical_volume_t * pv_entry)
+int lvm_write_vg(lvm_physical_volume_t * pv_entry, boolean backup)
 {
 	vg_disk_t * vg_buffer;
 	lvm_volume_group_t * group = pv_entry->group;
@@ -321,8 +337,14 @@ int lvm_write_vg(lvm_physical_volume_t * pv_entry)
 	lvm_endian_convert_vg(vg_buffer);
 
 	/* Write the metadata. */
-	rc = WRITE(segment, bytes_to_sectors(pv->vg_on_disk.base),
-		   vg_sectors, vg_buffer);
+	if (backup) {
+		rc = EngFncs->save_metadata(group->container->name, segment->name,
+					    bytes_to_sectors(pv->vg_on_disk.base),
+					    vg_sectors, vg_buffer);
+	} else {
+		rc = WRITE(segment, bytes_to_sectors(pv->vg_on_disk.base),
+			   vg_sectors, vg_buffer);
+	}
 	if (rc) {
 		LOG_SERIOUS("Error writing VG metadata to object %s\n",
 			    segment->name);
@@ -404,7 +426,7 @@ int lvm_read_uuid_list(storage_object_t	* segment,
 		group->flags |= LVM_VG_FLAG_UUID_LIST_PRESENT;
 	}
 	else {
-		LOG_EXTRA("Already read PV UUIDs for container %s\n",
+		LOG_DEBUG("Already read PV UUIDs for container %s\n",
 			  group->container->name);
 	}
 
@@ -422,7 +444,7 @@ out:
  * table internally. So be sure to leave out the first entry in the
  * table when writing it to the PV.
  **/
-int lvm_write_uuid_list(lvm_physical_volume_t * pv_entry)
+int lvm_write_uuid_list(lvm_physical_volume_t * pv_entry, boolean backup)
 {
 	lvm_volume_group_t * group = pv_entry->group;
 	storage_object_t * segment = pv_entry->segment;
@@ -453,8 +475,14 @@ int lvm_write_uuid_list(lvm_physical_volume_t * pv_entry)
 	}
 
 	/* Write the array to the PV. */
-	rc = WRITE(segment, bytes_to_sectors(pv->pv_uuidlist_on_disk.base),
-		   uuid_sectors, uuid_buffer);
+	if (backup) {
+		rc = EngFncs->save_metadata(group->container->name, segment->name,
+					    bytes_to_sectors(pv->pv_uuidlist_on_disk.base),
+					    uuid_sectors, uuid_buffer);
+	} else {
+		rc = WRITE(segment, bytes_to_sectors(pv->pv_uuidlist_on_disk.base),
+			   uuid_sectors, uuid_buffer);
+	}
 	if (rc) {
 		LOG_SERIOUS("Error writing UUID list to object %s\n",
 			    segment->name);
@@ -564,7 +592,7 @@ int lvm_read_lv_array(lvm_volume_group_t * group)
 				    group->container->name);
 		}
 	} else {
-		LOG_EXTRA("Already read LV metadata for container %s\n",
+		LOG_DEBUG("Already read LV metadata for container %s\n",
 			  group->container->name);
 	}
 
@@ -577,7 +605,7 @@ int lvm_read_lv_array(lvm_volume_group_t * group)
  *
  * Write the LV metadata to the specified PV.
  **/
-int lvm_write_lv_array(lvm_physical_volume_t * pv_entry)
+int lvm_write_lv_array(lvm_physical_volume_t * pv_entry, boolean backup)
 {
 	lvm_volume_group_t * group = pv_entry->group;
 	storage_object_t * segment = pv_entry->segment;
@@ -590,10 +618,18 @@ int lvm_write_lv_array(lvm_physical_volume_t * pv_entry)
 	 * this function as an optimization.
 	 */
 
-	rc = WRITE(segment, pv->lv_on_disk.base >> EVMS_VSECTOR_SIZE_SHIFT,
-		   bytes_to_sectors(min(EVMS_LVM_MAX_LV_METADATA_SIZE,
-					pv->lv_on_disk.size)),
-		   group->lv_array_disk);
+	if (backup) {
+		rc = EngFncs->save_metadata(group->container->name, segment->name,
+					    pv->lv_on_disk.base >> EVMS_VSECTOR_SIZE_SHIFT,
+					    bytes_to_sectors(min(EVMS_LVM_MAX_LV_METADATA_SIZE,
+								 pv->lv_on_disk.size)),
+					    group->lv_array_disk);
+	} else {
+		rc = WRITE(segment, pv->lv_on_disk.base >> EVMS_VSECTOR_SIZE_SHIFT,
+			   bytes_to_sectors(min(EVMS_LVM_MAX_LV_METADATA_SIZE,
+						pv->lv_on_disk.size)),
+			   group->lv_array_disk);
+	}
 	if (rc) {
 		LOG_SERIOUS("Error writing LV array to object %s\n",
 			    segment->name);
@@ -669,7 +705,7 @@ out:
  *
  * Write the PE map to the specified PV.
  **/
-int lvm_write_pe_map(lvm_physical_volume_t * pv_entry)
+int lvm_write_pe_map(lvm_physical_volume_t * pv_entry, boolean backup)
 {
 	storage_object_t * segment = pv_entry->segment;
 	pv_disk_t * pv = pv_entry->pv;
@@ -696,8 +732,15 @@ int lvm_write_pe_map(lvm_physical_volume_t * pv_entry)
 	/* Convert the map to disk order and write. */
 	lvm_endian_convert_pe_map(pe_map, pv->pe_total);
 
-	rc = WRITE(segment, bytes_to_sectors(pv->pe_on_disk.base),
-		   pe_map_sectors, pe_map);
+	if (backup) {
+		rc = EngFncs->save_metadata(pv_entry->group->container->name,
+					    segment->name,
+					    bytes_to_sectors(pv->pe_on_disk.base),
+					    pe_map_sectors, pe_map);
+	} else {
+		rc = WRITE(segment, bytes_to_sectors(pv->pe_on_disk.base),
+			   pe_map_sectors, pe_map);
+	}
 	if (rc) {
 		LOG_SERIOUS("Error writing PE map to object %s\n",
 			    segment->name);
