@@ -83,7 +83,7 @@ static int move_extent_init_copy_job(lvm_logical_extent_t * le,
 		goto out;
 	}
 	snprintf(copy_job->title, title_size,
-		 "LVM: Copying LE %s:%d from %s:%d to %s:%d",
+		 _("LVM: Copying LE %s:%d from %s:%d to %s:%d"),
 		 le->volume->region->name, le->number,
 		 src_pe->pv->segment->name, src_pe->number,
 		 dst_pe->pv->segment->name, dst_pe->number);
@@ -218,11 +218,11 @@ static int move_extent_update_metadata(lvm_logical_extent_t * le)
 
 	/* Write the metadata to disk. */
 	/* FIXME: How to handle I/O errors? */
-	lvm_write_pv(dst_pe->pv);
-	lvm_write_pe_map(dst_pe->pv);
+	lvm_write_pv(dst_pe->pv, FALSE);
+	lvm_write_pe_map(dst_pe->pv, FALSE);
 	if (src_pe) {
-		lvm_write_pv(src_pe->pv);
-		lvm_write_pe_map(src_pe->pv);
+		lvm_write_pv(src_pe->pv, FALSE);
+		lvm_write_pe_map(src_pe->pv, FALSE);
 	}
 
 	LOG_EXIT_INT(0);
@@ -303,7 +303,7 @@ out:
 static int lvm_volume_is_busy(lvm_logical_volume_t * volume,
 			      int prompt_user)
 {
-	char * choices[] = {"Skip", "Retry", NULL};
+	char * choices[] = {_("Skip"), _("Retry"), NULL};
 	logical_volume_t * evms_vol;
 	int offline, answer;
 	int rc = FALSE;
@@ -324,16 +324,16 @@ static int lvm_volume_is_busy(lvm_logical_volume_t * volume,
 		answer = 0;
 		if (prompt_user) {
 			QUESTION(&answer, choices,
-				"Region \"%s\" has extents scheduled to be "
-				"moved. However, this region is part of volume "
-				"\"%s\", which is mounted at %s. Please "
-				"unmount the volume and choose \"%s\" to "
-				"continue with the move, or choose \"%s\" to "
-				"skip the move at this time (the move will be "
-				"attempted again the next time changes are "
-				"saved).",
+				_("Region \"%s\" has extents scheduled to be moved.  "
+				  "However, this region is part of volume \"%s\", "
+				  "which is mounted at %s.  "
+				  "Please unmount the volume and choose \"Retry\" to "
+				  "continue with the move, or choose \"Skip\" to "
+				  "skip the move at this time "
+				  "(the move will be attempted again "
+				  "the next time changes are saved)."),
 				volume->region->name, evms_vol->name,
-				evms_vol->mount_point, choices[1], choices[0]);
+				evms_vol->mount_point);
 		}
 
 		if (answer == 0) {
@@ -421,9 +421,9 @@ int lvm_move_extent_init_task(task_context_t * context)
 	 * volume that are not already being moved.
 	 */
 	index = LVM_OPTION_MOVE_EXTENT_LE_INDEX;
-	SET_STRING(od->option[index].name, LVM_OPTION_MOVE_EXTENT_LE_STR);
-	SET_STRING(od->option[index].title, "Logical Extent");
-	SET_STRING(od->option[index].tip, "Logical extent to move");
+	od->option[index].name = EngFncs->engine_strdup(LVM_OPTION_MOVE_EXTENT_LE_STR);
+	od->option[index].title = EngFncs->engine_strdup(_("Logical Extent"));
+	od->option[index].tip = EngFncs->engine_strdup(_("Logical extent to move"));
 	od->option[index].type = EVMS_Type_Unsigned_Int32;
 	od->option[index].flags = EVMS_OPTION_FLAGS_NO_INITIAL_VALUE;
 	od->option[index].constraint_type = EVMS_Collection_List;
@@ -443,9 +443,9 @@ int lvm_move_extent_init_task(task_context_t * context)
 	 */
 	count = 0;
 	index = LVM_OPTION_MOVE_EXTENT_PV_INDEX;
-	SET_STRING(od->option[index].name, LVM_OPTION_MOVE_EXTENT_PV_STR);
-	SET_STRING(od->option[index].title, "Physical Volume");
-	SET_STRING(od->option[index].tip, "Physical volume to move this logical extent to.");
+	od->option[index].name = EngFncs->engine_strdup(LVM_OPTION_MOVE_EXTENT_PV_STR);
+	od->option[index].title = EngFncs->engine_strdup(_("Physical Volume"));
+	od->option[index].tip = EngFncs->engine_strdup(_("Physical volume to move this logical extent to."));
 	od->option[index].type = EVMS_Type_String;
 	od->option[index].max_len = EVMS_NAME_SIZE;
 	od->option[index].flags = EVMS_OPTION_FLAGS_NO_INITIAL_VALUE;
@@ -455,8 +455,8 @@ int lvm_move_extent_init_task(task_context_t * context)
 	for (i = 0; i < MAX_PV; i++) {
 		pv_entry = group->pv_list[i];
 		if (pv_entry && lvm_pv_has_available_extents(pv_entry)) {
-			SET_STRING(od->option[index].constraint.list->value[count].s,
-				   pv_entry->segment->name);
+			od->option[index].constraint.list->value[count].s =
+				EngFncs->engine_strdup(pv_entry->segment->name);
 			count++;
 		}
 	}
@@ -468,9 +468,9 @@ int lvm_move_extent_init_task(task_context_t * context)
 	 * until the user chooses which PV to move this extent to.
 	 */
 	index = LVM_OPTION_MOVE_EXTENT_PE_INDEX;
-	SET_STRING(od->option[index].name, LVM_OPTION_MOVE_EXTENT_PE_STR);
-	SET_STRING(od->option[index].title, "Physical Extent");
-	SET_STRING(od->option[index].tip, "Physical extent to move this logical extent to.");
+	od->option[index].name = EngFncs->engine_strdup(LVM_OPTION_MOVE_EXTENT_PE_STR);
+	od->option[index].title = EngFncs->engine_strdup(_("Physical Extent"));
+	od->option[index].tip = EngFncs->engine_strdup(_("Physical extent to move this logical extent to."));
 	od->option[index].type = EVMS_Type_Unsigned_Int32;
 	od->option[index].flags = EVMS_OPTION_FLAGS_NO_INITIAL_VALUE |
 				  EVMS_OPTION_FLAGS_INACTIVE;
@@ -499,7 +499,7 @@ int lvm_move_extent_set_option(task_context_t * context,
 	int rc = EINVAL;
 
 	LOG_ENTRY();
-	LOG_EXTRA("Setting option %d\n", index);
+	LOG_DEBUG("Setting option %d\n", index);
 
 	switch (index) {
 
@@ -590,7 +590,7 @@ static void lvm_move_extent_parse_options(option_array_t * options,
 			}
 		}
 
-		LOG_EXTRA("Parsing option %d\n", options->option[i].number);
+		LOG_DEBUG("Parsing option %d\n", options->option[i].number);
 
 		/* Use the number-based index to record the option. */
 		switch (options->option[i].number) {
@@ -958,9 +958,9 @@ static int lvm_parse_maintain_stripes(char * string)
 
 	LOG_ENTRY();
 
-	if (strcasecmp(string, "strict") == 0) {
+	if (strcasecmp(string, _("strict")) == 0) {
 		rc = MAINTAIN_STRIPES_STRICT;
-	} else if (strcasecmp(string, "loose") == 0) {
+	} else if (strcasecmp(string, _("loose")) == 0) {
 		rc = MAINTAIN_STRIPES_LOOSE;
 	}
 
@@ -1016,12 +1016,13 @@ int lvm_move_pv_init_task(task_context_t * context)
 	 * source PV. Just allocate the empty list right now.
 	 */
 	index = LVM_OPTION_MOVE_PV_TARGET_LIST_IDX;
-	SET_STRING(od->option[index].name, LVM_OPTION_MOVE_PV_TARGET_LIST_STR);
-	SET_STRING(od->option[index].title, "Target PVs");
-	SET_STRING(od->option[index].tip, "List of PVs that should be used as "
-					  "targets for moving the desired source "
-					  "PV. Defaults to all remaining PVs in "
-					  "the container.");
+	od->option[index].name = EngFncs->engine_strdup(LVM_OPTION_MOVE_PV_TARGET_LIST_STR);
+	od->option[index].title = EngFncs->engine_strdup(_("Target PVs"));
+	od->option[index].tip =
+		EngFncs->engine_strdup(_("List of PVs that should be used as "
+					 "targets for moving the desired source "
+					 "PV. Defaults to all remaining PVs in "
+					 "the container."));
 	od->option[index].type = EVMS_Type_String;
 	od->option[index].min_len = 1;
 	od->option[index].max_len = EVMS_NAME_SIZE;
@@ -1042,12 +1043,13 @@ int lvm_move_pv_init_task(task_context_t * context)
 	 * No, Loose, or Strict
 	 */
 	index = LVM_OPTION_MOVE_PV_MAINTAIN_STRIPES_IDX;
-	SET_STRING(od->option[index].name, LVM_OPTION_MOVE_PV_MAINTAIN_STRIPES_STR);
-	SET_STRING(od->option[index].title, "Maintain Stripes");
-	SET_STRING(od->option[index].tip, "No: Don't bother to maintain true striping.\n"
-					  "Loose: Don't move extents to PVs that are already "
-					  "used by a striped region.\n"
-					  "Strict: Maintain true striping.");
+	od->option[index].name = EngFncs->engine_strdup(LVM_OPTION_MOVE_PV_MAINTAIN_STRIPES_STR);
+	od->option[index].title = EngFncs->engine_strdup(_("Maintain Stripes"));
+	od->option[index].tip =
+		EngFncs->engine_strdup(_("No: Don't bother to maintain true striping.\n"
+					 "Loose: Don't move extents to PVs that are already "
+					 "used by a striped region.\n"
+					 "Strict: Maintain true striping."));
 	od->option[index].type = EVMS_Type_String;
 	od->option[index].min_len = 1;
 	od->option[index].max_len = EVMS_NAME_SIZE;
@@ -1055,12 +1057,12 @@ int lvm_move_pv_init_task(task_context_t * context)
 				  EVMS_OPTION_FLAGS_AUTOMATIC;
 	od->option[index].constraint_type = EVMS_Collection_List;
 	od->option[index].constraint.list = EngFncs->engine_alloc(sizeof(value_list_t) +
-								  sizeof(value_t) * 2);
-	SET_STRING(od->option[index].constraint.list->value[0].s, "no");
-	SET_STRING(od->option[index].constraint.list->value[1].s, "loose");
-	SET_STRING(od->option[index].constraint.list->value[2].s, "strict");
+								  sizeof(value_t) * 3);
+	od->option[index].constraint.list->value[0].s = EngFncs->engine_strdup(_("no"));
+	od->option[index].constraint.list->value[1].s = EngFncs->engine_strdup(_("loose"));
+	od->option[index].constraint.list->value[2].s = EngFncs->engine_strdup(_("strict"));
 	od->option[index].constraint.list->count = 3;
-	SET_STRING(od->option[index].value.s, "no");
+	od->option[index].value.s = EngFncs->engine_strdup("no");
 
 	index++;
 	od->count = index;
@@ -1106,10 +1108,10 @@ int lvm_move_pv_set_objects(task_context_t * context,
 	for (i = 0; i <= MAX_PV; i++) {
 		if (group->pv_list[i] &&
 		    group->pv_list[i] != source_pv) {
-			SET_STRING(od->option[LVM_OPTION_MOVE_PV_TARGET_LIST_IDX].constraint.list->value[j].s,
-				   group->pv_list[i]->segment->name);
-			SET_STRING(od->option[LVM_OPTION_MOVE_PV_TARGET_LIST_IDX].value.list->value[j].s,
-				   group->pv_list[i]->segment->name);
+			od->option[LVM_OPTION_MOVE_PV_TARGET_LIST_IDX].constraint.list->value[j].s =
+				EngFncs->engine_strdup(group->pv_list[i]->segment->name);
+			od->option[LVM_OPTION_MOVE_PV_TARGET_LIST_IDX].value.list->value[j].s =
+				EngFncs->engine_strdup(group->pv_list[i]->segment->name);
 			od->option[LVM_OPTION_MOVE_PV_TARGET_LIST_IDX].constraint.list->count++;
 			od->option[LVM_OPTION_MOVE_PV_TARGET_LIST_IDX].value.list->count++;
 			j++;
@@ -1117,7 +1119,7 @@ int lvm_move_pv_set_objects(task_context_t * context,
 	}
 
 	/* Reset the Maintain-Stripes option to the default. */
-	SET_STRING(od->option[LVM_OPTION_MOVE_PV_MAINTAIN_STRIPES_IDX].value.s, "no");
+	od->option[LVM_OPTION_MOVE_PV_MAINTAIN_STRIPES_IDX].value.s = EngFncs->engine_strdup(_("no"));
 
 	*effect |= EVMS_Effect_Reload_Options;
 
@@ -1149,7 +1151,7 @@ int lvm_move_pv_set_option(task_context_t * context,
 
 	LOG_ENTRY();
 
-	LOG_EXTRA("Setting option %d\n", index);
+	LOG_DEBUG("Setting option %d\n", index);
 
 	/* Get the PV from the selected-objects list. */
 	source_pv = lvm_get_selected_segment(context->selected_objects);
@@ -1192,9 +1194,9 @@ int lvm_move_pv_set_option(task_context_t * context,
 
 	case LVM_OPTION_MOVE_PV_TARGET_LIST_IDX:
 		for (i = 0; i < pv_list->count; i++) {
-			SET_STRING(od->option[index].value.list->value[i].s, pv_list->value[i].s);
+			od->option[index].value.list->value[i].s = EngFncs->engine_strdup(pv_list->value[i].s);
 		}
-		for (; i <= MAX_PV; i++) {
+		for (; i < MAX_PV; i++) {
 			EngFncs->engine_free(od->option[index].value.list->value[i].s);
 			od->option[index].value.list->value[i].s = NULL;
 		}
@@ -1202,7 +1204,7 @@ int lvm_move_pv_set_option(task_context_t * context,
 		break;
 
 	case LVM_OPTION_MOVE_PV_MAINTAIN_STRIPES_IDX:
-		SET_STRING(od->option[index].value.s, maintain_stripes_string);
+		od->option[index].value.s = EngFncs->engine_strdup(maintain_stripes_string);
 		break;
 
 	default:
@@ -1245,7 +1247,7 @@ static int lvm_move_pv_parse_options(option_array_t * options,
 			}
 		}
 
-		LOG_EXTRA("Parsing option %d\n", options->option[i].number);
+		LOG_DEBUG("Parsing option %d\n", options->option[i].number);
 
 		/* Use the number-based index to record the option. */
 		switch (options->option[i].number) {
@@ -1278,8 +1280,8 @@ static int lvm_move_pv_display_warning(lvm_physical_volume_t * source_pv)
 	lvm_logical_volume_t * volume;
 	list_element_t itr;
 	char * volume_string;
-	char * choices[] = {"Continue",
-			    "Don't Continue",
+	char * choices[] = {_("Continue"),
+			    _("Don't Continue"),
 			    NULL};
 	int rc, count, answer = 0;
 
