@@ -3,16 +3,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Module: LVM Region Manager
@@ -33,7 +33,7 @@
 #include <plugin.h>
 #include "lvmregmgr.h"
 
-/** 
+/**
  * lvm_get_pe_start
  *
  * This function returns the starting sector of the first data PE on the
@@ -132,7 +132,7 @@ out:
 
 /**
  * lvm_deallocate_pe_map
- * 
+ *
  * Release the memory used by this PV's PE map.
  **/
 static void lvm_deallocate_pe_map(lvm_physical_volume_t * pv_entry)
@@ -283,7 +283,7 @@ static int lvm_set_system_id(pv_disk_t * pv)
 		rc = EINVAL;
 	} else {
 		memset(pv->system_id, 0, NAME_LEN);
-		snprintf(pv->system_id, NAME_LEN, "%s%lu",
+		snprintf((char *)pv->system_id, NAME_LEN, "%s%lu",
 			 uts.nodename, time(NULL));
 	}
 
@@ -421,7 +421,7 @@ static int lvm_initialize_new_pv(pv_disk_t * pv,
 
 	/* Get a UUID for the PV. */
 	memset(pv->pv_uuid, 0, NAME_LEN);
-	rc = lvm_create_uuid(pv->pv_uuid);
+	rc = lvm_create_uuid((char *)pv->pv_uuid);
 	if (rc) {
 		goto out;
 	}
@@ -593,7 +593,7 @@ int lvm_update_pv_for_group(lvm_physical_volume_t * pv_entry,
 
 	/* Copy the group name. */
 	memset(pv->vg_name, 0, NAME_LEN);
-	lvm_translate_container_name_to_vg_name(group, pv->vg_name);
+	lvm_translate_container_name_to_vg_name(group, (char *)pv->vg_name);
 
 	/* Reset all the VGDA information. */
 	lvm_calculate_vgda_info(pv);
