@@ -132,7 +132,7 @@ lvm_logical_volume_t * lvm_allocate_logical_volume(lv_disk_t * lv,
 	/* Translate the LV name to the region name. Should have checked for
 	 * uniqueness when initializing the LV.
 	 */
-	rc = lvm_translate_lv_name_to_region_name(lv->lv_name,
+	rc = lvm_translate_lv_name_to_region_name((char *)lv->lv_name,
 						  dg_name, region_name);
 	if (rc) {
 		goto out2;
@@ -277,7 +277,7 @@ int lvm_create_freespace_volume(lvm_volume_group_t * group)
 	}
 
 	/* Need to make the freespace's name look like a legal LVM lv name. */
-	lvm_make_lv_name("Freespace", group, free_lv->lv_name);
+	lvm_make_lv_name("Freespace", group, (char *)free_lv->lv_name);
 
 	free_lv->lv_allocated_le = group->vg->pe_total - group->vg->pe_allocated - group->move_extents;
 	free_lv->lv_size	= free_lv->lv_allocated_le * group->vg->pe_size;
@@ -820,7 +820,9 @@ int lvm_check_lv_name(char * name,
 	/* Search through all LVs in this group. */
 	for (i = 1; i <= MAX_LV; i++) {
 		if (group->volume_list[i] &&
-		    ! strncmp(lv_name, group->volume_list[i]->lv->lv_name, NAME_LEN)) {
+		    ! strncmp(lv_name,
+			      (char *)group->volume_list[i]->lv->lv_name,
+			      NAME_LEN)) {
 			MESSAGE(_("LV name %s already exists in container %s\n"),
 				name, group->container->name);
 			rc = EEXIST;
@@ -1033,8 +1035,8 @@ int lvm_initialize_new_lv(lvm_lv_create_options_t * lv_opts,
 	lvm_clear_lv(*lv);
 
 	/* Copy the LV and VG names. */
-	lvm_make_lv_name(lv_opts->lv_name, group, (*lv)->lv_name);
-	lvm_translate_container_name_to_vg_name(group, (*lv)->vg_name);
+	lvm_make_lv_name(lv_opts->lv_name, group, (char *)(*lv)->lv_name);
+	lvm_translate_container_name_to_vg_name(group, (char *)(*lv)->vg_name);
 
 	/* Fill in remaining fields. */
 	(*lv)->lv_access		= LV_READ | LV_WRITE;
@@ -2086,7 +2088,7 @@ void lvm_set_new_volume_name(lvm_logical_volume_t *volume, char *name)
 
 	/* Copy the new LV-name into the metadata. */
 	memset(volume->lv->lv_name, 0, NAME_LEN);
-	strncpy(volume->lv->lv_name, lv_name, NAME_LEN-1);
+	strncpy((char *)volume->lv->lv_name, lv_name, NAME_LEN-1);
 
 	if (LVM_LV_RENAMED(region)) {
 		/* If we've already renamed this volume, we can simply
