@@ -1785,7 +1785,7 @@ static int lvm_create_container(list_anchor_t objects,
 	vg_disk_t * vg;
 	lvm_volume_group_t * new_group;
 	storage_container_t * disk_group = NULL;
-	unsigned char vg_name[NAME_LEN] = {0};
+	char vg_name[NAME_LEN] = {0};
 	list_element_t itr;
 	u_int32_t pe_size;
 	int rc;
@@ -2413,7 +2413,8 @@ static int lvm_set_container_info(storage_container_t * container,
 	for (i = 0; i <= MAX_PV; i++) {
 		if ((pv_entry = group->pv_list[i])) {
 			memset(pv_entry->pv->vg_name, 0, NAME_LEN);
-			strncpy(pv_entry->pv->vg_name, vg_name, NAME_LEN-1);
+			strncpy((char *)pv_entry->pv->vg_name,
+				vg_name, NAME_LEN-1);
 		}
 	}
 
@@ -2423,7 +2424,8 @@ static int lvm_set_container_info(storage_container_t * container,
 	for (i = 0; i <= MAX_LV; i++) {
 		if ((volume = group->volume_list[i])) {
 			memset(volume->lv->vg_name, 0, NAME_LEN);
-			strncpy(volume->lv->vg_name, vg_name, NAME_LEN-1);
+			strncpy((char *)volume->lv->vg_name,
+				vg_name, NAME_LEN-1);
 
 			region_base_name = volume->region->name +
 					   strlen(old_container_name) + 1;
