@@ -3,21 +3,21 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Module: LVM Region Manager
  * File: evms2/engine/plugins/lvm/lvmregmgr.h
- */ 
+ */
 
 /* Datatypes and Defs used in lvmregmgr.c. */
 #define SECTOR_SIZE_BITS		9
@@ -61,7 +61,7 @@
 #define	LVM_MAX_PE_SIZE		(16L * 1024L * 1024L / SECTOR_SIZE * 1024L)	// 16 GB in sectors
 #define	LVM_DEFAULT_PE_SIZE	(16L * 1024L * 1024L / SECTOR_SIZE)	// 16 MB in sectors
 #define	LVM_DEFAULT_STRIPE_SIZE	(16L * 1024L / SECTOR_SIZE)		// 16 kB  in sectors
-#define	LVM_MIN_STRIPE_SIZE	(PAGE_SIZE / SECTOR_SIZE)		// PAGESIZE in sectors 
+#define	LVM_MIN_STRIPE_SIZE	(PAGE_SIZE / SECTOR_SIZE)		// PAGESIZE in sectors
 #define	LVM_MAX_STRIPE_SIZE	(512L * 1024 / SECTOR_SIZE)		// 512 kB in sectors
 #define	LVM_MAX_STRIPES		128					// max # of stripes
 #define	LVM_MAX_SIZE            (1024L * 1024L * 1024L * 1024L / SECTOR_SIZE)	// 1 TB in sectors
@@ -294,7 +294,7 @@ typedef struct lvm_physical_volume {
 	lvm_physical_extent_t	* pe_map;
 	u_int32_t		move_extents;
 	long			number;
-	long			flags;       
+	long			flags;
 } lvm_physical_volume_t;
 
 #define LVM_PV_FLAG_INVALID_UUID	(1 << 0)
@@ -368,7 +368,7 @@ typedef struct lvm_volume_group {
 	vg_disk_t		* vg;
 	storage_container_t	* container;
 	lvm_physical_volume_t	* pv_list[MAX_PV+1];
-	unsigned char		* uuid_list[MAX_PV+1];
+	char			* uuid_list[MAX_PV+1];
 	lvm_logical_volume_t	* volume_list[MAX_LV+1];
 	lv_disk_t		* lv_array;
 	lv_disk_t		* lv_array_disk;
