@@ -1024,10 +1024,10 @@ int read_pv_metadata(storage_object_t *object)
 	void *label_buffer = NULL, *mda_buffer = NULL;
 	list_anchor_t data_locations = NULL, metadata_locations = NULL;
 //	metadata_location_t *data_location;
-	label_header_t *pv_label;
+	label_header_t *pv_label = NULL;
 	pv_header_t *pv_header;
 	mda_header_t *mda_header = NULL;
-	key_value_t *vgda_tree;
+	key_value_t *vgda_tree = NULL;
 	u_int32_t pv_index;
 	u_int64_t pe_start, pe_count;
 	unsigned long pv_flags = 0;
@@ -1074,7 +1074,7 @@ int read_pv_metadata(storage_object_t *object)
 	}
 
 	/* Find this PV's information in the VGDA tree. */
-	rc = find_pv_info_in_vgda(vgda_tree, pv_header->pv_uuid,
+	rc = find_pv_info_in_vgda(vgda_tree, (char *)pv_header->pv_uuid,
 				  &pv_index, &pe_start, &pe_count, &pv_flags);
 	if (rc) {
 		EngFncs->destroy_list(metadata_locations);
@@ -1100,7 +1100,7 @@ int read_pv_metadata(storage_object_t *object)
 
 	/* Allocate private data for this PV object. */
 	rc = allocate_pv_data(object, metadata_locations, vgda_tree,
-			      pv_header->pv_uuid, pv_label->sector,
+			      (char *)pv_header->pv_uuid, pv_label->sector,
 			      pv_index, pe_start, pe_count, pv_flags);
 	if (rc) {
 		EngFncs->destroy_list(metadata_locations);
