@@ -1132,17 +1132,18 @@ int create_region_validate_options(storage_container_t *container,
 			  *stripes);
 	}
 
-	/* Size must be a multiple of the extent-size
-	 * and the number of stripes.
+	/* Size must be a multiple of the extent-size and the number of
+	 * of stripes, but not more than the total available freespace.
 	 */
 	increment = *stripes * c_data->pe_size;
-	if (*size < increment) {
-		*size = increment;
+	if (*size % increment) {
+		/* This also catches if size is less than increment. */
+		*size += increment - (*size % increment);
 		LOG_DEBUG("Rounding size up to %"PRIu64".\n", *size);
-	} else if (*size > free_extents * c_data->pe_size) {
+	}
+
+	if (*size > free_extents * c_data->pe_size) {
 		*size = free_extents * c_data->pe_size;
-		LOG_DEBUG("Rounding size down to %"PRIu64".\n", *size);
-	} else if (*size % increment) {
 		*size -= *size % increment;
 		LOG_DEBUG("Rounding size down to %"PRIu64".\n", *size);
 	}
@@ -1638,13 +1639,14 @@ int expand_region_validate_options(storage_object_t *region,
 	 * and the number of stripes.
 	 */
 	increment = *stripes * c_data->pe_size;
-	if (*size < increment) {
-		*size = increment;
+	if (*size % increment) {
+		/* This also catches if size is less than increment. */
+		*size += increment - (*size % increment);
 		LOG_DEBUG("Rounding size up to %"PRIu64".\n", *size);
-	} else if (*size > free_extents * c_data->pe_size) {
+	}
+
+	if (*size > free_extents * c_data->pe_size) {
 		*size = free_extents * c_data->pe_size;
-		LOG_DEBUG("Rounding size down to %"PRIu64".\n", *size);
-	} else if (*size % increment) {
 		*size -= *size % increment;
 		LOG_DEBUG("Rounding size down to %"PRIu64".\n", *size);
 	}
@@ -2417,7 +2419,7 @@ int split_mapping_validate_options(storage_object_t *region,
 	r_map = find_mapping_by_index(region, r_map_index);
 	if (!r_map) {
 		LOG_ERROR("Mapping %u does not exist. Region %s only contains "
-			  "%u mappings.\n", r_map_index, region->name, 
+			  "%u mappings.\n", r_map_index, region->name,
 			  EngFncs->list_count(r_data->mappings));
 		rc = EINVAL;
 		goto out;
