@@ -112,16 +112,16 @@ static struct plugin_functions_s mac_plugin_functions = {
 
 static plugin_record_t mac_plugin_record = {
 
-        id:                                 SetPluginID(EVMS_OEM_IBM, EVMS_SEGMENT_MANAGER, 8 ),
+        id:                                 EVMS_MAC_PLUGIN_ID,
 
         version:                            {MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL},
 
         required_engine_api_version:        {15,0,0},
         required_plugin_api_version:        {plugin: {13,1,0}},
 
-        short_name:                         "MAC",
-        long_name:                          "MAC Segment Manager",
-        oem_name:                           "IBM",
+        short_name:                         EVMS_MAC_PLUGIN_SHORT_NAME,
+        long_name:                          EVMS_MAC_PLUGIN_LONG_NAME,
+        oem_name:                           EVMS_IBM_OEM_NAME,
 
         functions:                          {plugin: &mac_plugin_functions},
 
