@@ -52,7 +52,7 @@ int mac_can_delete( DISKSEG * seg )
         REQUIRE( seg != NULL);
         REQUIRE( seg->object_type == SEGMENT );
         REQUIRE( seg->data_type   == DATA_TYPE );
-        REQUIRE( disk_move_pending(seg) == FALSE);      
+        REQUIRE( disk_move_pending(seg) == FALSE);
 
         rc = 0;
 
@@ -76,7 +76,7 @@ int mac_can_delete( DISKSEG * seg )
  */
 int mac_discover( list_anchor_t input_objects, list_anchor_t output_objects, boolean final_call)
 {
-        int  count = 0;
+        uint  count = 0;
         list_element_t iter;
         storage_object_t *object;
 
@@ -101,7 +101,7 @@ int mac_discover( list_anchor_t input_objects, list_anchor_t output_objects, boo
  *  Function:  mac_unassign
  *
  *  We can unassign from any logical disk storage object that
- *  has a mac disk label on it as long as the data segments are 
+ *  has a mac disk label on it as long as the data segments are
  *  top-most storage objects.
  *
  */
@@ -140,7 +140,7 @@ int mac_can_unassign( LOGICALDISK *ld )
  *
  */
 int mac_unassign( LOGICALDISK *ld )
-{       
+{
         LOG_ENTRY();
 
         REQUIRE( isa_mac_logical_disk(ld) == TRUE );
@@ -151,7 +151,7 @@ int mac_unassign( LOGICALDISK *ld )
         // toss our logical disk private data area
         delete_mac_disk_private_data( ld );
 
-        // blast mac disk label 
+        // blast mac disk label
         KILL_SECTORS(ld, 0, 2);
 
         LOG_EXIT_INT(0);
@@ -202,7 +202,7 @@ int mac_destroy( DISKSEG * seg, list_anchor_t child_objects )
                         metadata->flags   |= SOFLAG_DIRTY;
                 }
                 else {
-                        rc = ENODEV; 
+                        rc = ENODEV;
                 }
 
         }
@@ -236,8 +236,8 @@ int mac_discard(list_anchor_t objects)
 				remove_mac_segment_from_list( ld->parent_objects, seg );
 				if (EngFncs->list_empty(ld->parent_objects) == TRUE)
 			        // toss our logical disk private data area
-			        delete_mac_disk_private_data( ld );	
-				
+			        delete_mac_disk_private_data( ld );
+
 			}
 
 		}
@@ -298,7 +298,7 @@ int mac_commit_changes( DISKSEG *seg, uint commit_phase )
 
         REQUIRE( isa_mac_segment(seg) == TRUE );
 
-        ld = get_logical_disk(seg);     
+        ld = get_logical_disk(seg);
         REQUIRE( ld != NULL );
 
         disk_pdata = get_mac_disk_private_data(ld);
@@ -312,7 +312,7 @@ int mac_commit_changes( DISKSEG *seg, uint commit_phase )
                         rc = ENOSYS;
                         if (disk_pdata->copy_job) free(disk_pdata->copy_job );
                         disk_pdata->copy_job = NULL;
-                        disk_pdata->flags   &= ~DISK_HAS_MOVE_PENDING; 
+                        disk_pdata->flags   &= ~DISK_HAS_MOVE_PENDING;
                         seg->flags          &= ~SOFLAG_DIRTY;
                 }
                 else {
@@ -334,7 +334,7 @@ int mac_commit_changes( DISKSEG *seg, uint commit_phase )
 
 
         LOG_EXIT_INT(0);
-        return 0;   
+        return 0;
 }
 
 
@@ -463,7 +463,7 @@ void delete_all_mac_segment_private_data(void)
                         }
 
                 }
-       
+
                 EngFncs->destroy_list( list );
         }
 
