@@ -38,6 +38,8 @@ static boolean linear_can_change_region_configuration( storage_object_t *region
 	boolean rc = TRUE;
 	md_volume_t * volume = (md_volume_t *)region->private_data;
 
+	LOG_ENTRY();
+
 	if (volume->region_mgr_flags & MD_LINEAR_CONFIG_CHANGE_PENDING) {
 		rc = FALSE;
 	}
@@ -521,7 +523,7 @@ static int linear_create_region(md_volume_t * vol, list_anchor_t output_list, bo
 			md_append_region_to_object(region, member->obj);
 		} else {
 			length = sprintf(message_buffer, _("  The disk indexed %d is missing.\n"), i);
-			md_queue_corrupt_message(vol->personality, message_buffer, length);
+			md_queue_corrupt_message(vol, message_buffer, length);
 			vol->flags |= MD_CORRUPT;
 		}
 	}
@@ -716,8 +718,8 @@ static int linear_create_new_region(md_volume_t * vol, list_anchor_t output_list
  *
  *	Create a new MD volume.
  */
-static int linear_create(list_anchor_t objects, 
-			 option_array_t	*options, 
+static int linear_create(list_anchor_t objects,
+			 option_array_t	*options,
 			 list_anchor_t	new_region_list )
 {
 	int rc = 0;
@@ -2061,7 +2063,7 @@ int linear_backup_metadata(storage_object_t *region)
 	volume->commit_flag |= MD_COMMIT_BACKUP_METADATA;
 	volume->commit_flag |= MD_COMMIT_DONT_CHECK_ACTIVE;
 	volume->flags |= MD_DIRTY;
-	rc = md_write_sbs_to_disk(volume); 
+	rc = md_write_sbs_to_disk(volume);
 	volume->commit_flag &= ~MD_COMMIT_BACKUP_METADATA;
 	volume->commit_flag &= ~MD_COMMIT_DONT_CHECK_ACTIVE;
 
@@ -2138,7 +2140,7 @@ static plugin_functions_t linear_functions = {
  */
 
 plugin_record_t linear_plugin_record = {
-    id:                    SetPluginID(EVMS_OEM_IBM, EVMS_REGION_MANAGER, 4),
+    id:                    EVMS_MD_LINEAR_PLUGIN_ID,
 
     version:              {major:      MAJOR_VERSION,
                            minor:      MINOR_VERSION,
@@ -2151,9 +2153,9 @@ plugin_record_t linear_plugin_record = {
 					   minor:      0,
 					   patchlevel: 0} },
 
-    short_name:            "MDLinearRegMgr",
-    long_name:             "MD Linear Raid Region Manager",
-    oem_name:              "IBM",
+    short_name:            EVMS_MD_LINEAR_PLUGIN_SHORT_NAME,
+    long_name:             EVMS_MD_LINEAR_PLUGIN_LONG_NAME,
+    oem_name:              EVMS_IBM_OEM_NAME,
 
     functions:             {plugin: &linear_functions},
 
