@@ -22,14 +22,19 @@
 #ifndef _LINEAR_MGR_H_
 #define _LINEAR_MGR_H_
 
-// Plug-in functions
-#define MD_LINEAR_FUNCTION_FIX			EVMS_Task_Plugin_Function
-#define MD_LINEAR_RESTORE_SUPERBLOCK		(EVMS_Task_Plugin_Function + 1)
+//Create Option
+#define LINEAR_CREATE_OPT_COUNT         1
 
-#define MD_LINEAR_FUNCTION_COUNT		2
+#define LINEAR_CREATE_OPT_SB1_INDEX	0
+#define LINEAR_CREATE_OPT_SB1_NAME	"ver1_superblock"
+
+// Plug-in functions : none
+#define MD_LINEAR_FUNCTION_COUNT		0
 
 // Linear region manager flags
 #define MD_LINEAR_CONFIG_CHANGE_PENDING		(1<<0)
 
+
+
 #endif
 
