@@ -248,29 +248,40 @@ boolean md_check_for_expand_shrink_in_progress(md_volume_t *vol, md_member_t **m
 {
 	md_member_t *my_member;
 	list_element_t iter;
-	md_saved_info_t *saved_info;
+	md_saved_info_t *info;
+	boolean rc = FALSE;
+	int i;
 
 	LOG_ENTRY();
 
 	LIST_FOR_EACH(vol->members, iter, my_member) {
-		saved_info = my_member->saved_info;
-		if (saved_info) {
-			if (saved_info->flags & (MD_SAVED_INFO_EXPAND_IN_PROGRESS | MD_SAVED_INFO_SHRINK_IN_PROGRESS)) {
-				LOG_DEFAULT("Saved area on %s indicates that the %s"
-					" process of [%s] is (was) in progress."
-					"  The sector mark is %"PRIu64".\n",
-					my_member->obj->name,
-					(saved_info->flags & MD_SAVED_INFO_EXPAND_IN_PROGRESS) ? "EXPANSION" : "SHRINKING",
-					vol->name,
-					saved_info->sector_mark);
-				*member = my_member;
-				LOG_EXIT_BOOL(TRUE);
-				return TRUE;
+		info = my_member->saved_info;
+		if (info) {
+			if (info->flags & (MD_SAVED_INFO_EXPAND_IN_PROGRESS | MD_SAVED_INFO_SHRINK_IN_PROGRESS)) {
+				LOG_WARNING("Saved area on %s indicates that the %s"
+					    " process of [%s] was interrupt.\n",
+					    my_member->obj->name,
+					    (info->flags & MD_SAVED_INFO_EXPAND_IN_PROGRESS) ? "expand" : "shrink",
+					    vol->name);
+				LOG_WARNING(" Number of %s objects was %u."
+					    "  The sector mark was %"PRIu64".\n",
+					    (info->flags & MD_SAVED_INFO_EXPAND_IN_PROGRESS) ? "added" : "removed",
+					    info->expand_shrink_cnt,
+					    info->sector_mark);
+				for (i=0; i<info->expand_shrink_cnt; i++) {
+					LOG_WARNING("Object #%d had RAID index: %d\n", i+1, info->expand_shrink_devs[i]);
+				}
+				if (rc == FALSE) {
+					*member = my_member;
+					rc = TRUE;
+				} else {
+					LOG_WARNING("Already found MD saved info on %s\n", (*member)->obj->name);
+				}
 			}
 		}
 	}
-	LOG_EXIT_BOOL(FALSE);
-	return FALSE;
+	LOG_EXIT_BOOL(rc);
+	return rc;
 }
 
 
