@@ -75,7 +75,8 @@ typedef int (setup_func_t)(md_volume_t *volume, struct md_setup_func_s *setup);
 
 
 // Functions exported from md_dlist.c
-int md_queue_corrupt_message(int personality, const char *message, int length);
+int md_queue_corrupt_message(md_volume_t *vol, const char *message, int length);
+int md_count_corrupt_messages(md_volume_t *vol);
 void md_display_corrupt_messages(int personality);
 void md_destroy_list_corrupt_messages(void);
 
