@@ -104,6 +104,9 @@ boolean md_can_create_sb_1(void)
 	if (kernel_major >= 2 && kernel_minor >= 6 && kernel_patch >= 10) {
 		sb1 = TRUE;
 	}
+	if (sb1 == FALSE) {
+		EngFncs->get_config_bool("md.can_create_sb_1", &sb1);
+	}
 	LOG_EXIT_BOOL(sb1);
 	return sb1;
 }
