@@ -30,7 +30,6 @@
 #include <errno.h>
 #include <time.h>
 #include <sys/ioctl.h>
-#include <asm/bitops.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <plugin.h>
@@ -74,7 +73,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 
 	LOG_ENTRY();
 
-	//Found more active disks than actual raid_disks ?	
+	//Found more active disks than actual raid_disks ?
 	if (vol->active_disks > raid_disks) {
 		length = sprintf(message_buffer,
 				 _("%s region %s is corrupt."
@@ -136,7 +135,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 			vol->flags |= MD_CORRUPT;
 			goto queue_corrupt_message;
 		}
-		
+
 		if (chunksize_in_bytes > MD_MAX_CHUNK_SIZE_BYTES) {
 			length = sprintf(message_buffer,
 					 _("%s region %s is corrupt.  The chunk size (%d bytes) is too big."
@@ -147,7 +146,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 			goto queue_corrupt_message;
 		}
 		
-		if ( (1 << (ffs(chunksize_in_bytes)-1)) != chunksize_in_bytes) {
+		if (((chunksize_in_bytes - 1) & chunksize_in_bytes) != 0) {
 			length = sprintf(message_buffer,
 					 _("%s region %s is corrupt."
 					   "  The chunk size (%d bytes) is not a power of 2."),
@@ -155,7 +154,7 @@ static void md_analyze_sb(md_volume_t *vol, int level, int raid_disks, u_int32_t
 			vol->flags |= MD_CORRUPT;
 			goto queue_corrupt_message;
 		}
-		
+
 		if (chunksize_in_bytes < 4096) {
 			length = sprintf(message_buffer,
 					 _("%s region %s is corrupt."
@@ -334,8 +333,6 @@ static void sb0_get_sb_info(void *super, md_super_info_t *info)
 		info->state_flags = MD_SUPER_INFO_ERRORS;
 	} else if ((sb->state & (1<<MD_SB_CLEAN))) {
 		info->state_flags = MD_SUPER_INFO_CLEAN;
-	} else {
-		info->state_flags = MD_SUPER_INFO_DIRTY;
 	}
 	info->sb_csum = sb->sb_csum;
 	info->layout = sb->layout;
@@ -363,6 +360,14 @@ static void sb0_set_sb_info(void *super, md_super_info_t *info)
 	sb->working_disks = info->working_disks;
 	sb->failed_disks = info->failed_disks;
 	sb->spare_disks = info->spare_disks;
+	if (info->state_flags & MD_SUPER_INFO_CLEAN) {
+		sb->state |= (1<<MD_SB_CLEAN);
+	} else {
+		sb->state &= ~(1<<MD_SB_CLEAN);
+	}
+	if (info->state_flags & MD_SUPER_INFO_ERRORS) {
+		sb->state |= (1<<MD_SB_ERRORS);
+	}
 	LOG_WARNING("Superblock disk counts have been changed,"
 		    " nr_disks(%03d) raid_disks(%03d) active_disks(%03d)"
 		    " working_disks(%03d) failed_disks(%03d) spare_disks(%03d).\n",
@@ -475,7 +480,7 @@ static int sb0_find_empty_slot(void *super, u_int32_t *available_slot)
 	if (!rc) {
 		*available_slot = i;
 	}
-	
+
 	LOG_EXIT_INT(rc);
 	return rc;
 }
@@ -490,7 +495,7 @@ static int sb0_calc_sb_csum(mdp_super_t *super)
 	unsigned long long newcsum = 0;
 	unsigned long csum;
 	int i;
-	unsigned int *superc = (int*) super;
+	unsigned int *superc = (unsigned int*) super;
 
 	LOG_ENTRY();
 
@@ -589,14 +594,14 @@ static int sb0_add_new_disk(md_member_t *member)
 		rc = EINVAL;
 		goto out;
 	}
-	
+
 	master_sb = (mdp_super_t *)member->vol->sb;
 	if (!master_sb) {
 		LOG_MD_BUG();
 		rc = EINVAL;
 		goto out;
 	}
-	
+
 	if (!(member->flags & (MD_MEMBER_DISK_ACTIVE | MD_MEMBER_DISK_SPARE))) {
 		LOG_MD_BUG();
 		rc = EINVAL;
@@ -732,7 +737,7 @@ static int sb0_remove_disk(md_member_t *member, boolean resize)
 	} else {
 		disk->state = (1<<MD_DISK_REMOVED);
 	}
-	
+
 	if (member->flags & MD_MEMBER_STALE) {
 		master_sb->nr_disks++;
 		memset(disk, 0, sizeof(*disk));
@@ -893,7 +898,7 @@ static void sb0_load_this_device_info(md_member_t *member)
 		member->data_size = MD_NEW_SIZE_SECTORS(member->obj->size);
 		break;
 	}
-	
+
 	member->recovery_offset = 0;
 	member->cnt_corrected_read = 0;
 	memset(member->device_uuid, 0, sizeof(member->device_uuid));
@@ -1055,7 +1060,7 @@ static int sb0_mark_disk_faulty(md_member_t *member, boolean mark_removed)
 		master_sb->spare_disks--;
 		master_sb->working_disks--;
 		member->flags &= ~MD_MEMBER_DISK_SPARE;
-		member->flags |= MD_MEMBER_DISK_FAULTY;	
+		member->flags |= MD_MEMBER_DISK_FAULTY;
 	} else {
 		LOG_MD_BUG();
 		rc = EINVAL;
@@ -1063,9 +1068,9 @@ static int sb0_mark_disk_faulty(md_member_t *member, boolean mark_removed)
 
 	if (!rc) {
 		disk = &master_sb->disks[member->dev_number];
-		disk->state = MD_DISK_FAULTY;
+		disk->state = 1<<MD_DISK_FAULTY;
 		if (mark_removed == TRUE) {
-			disk->state |= MD_DISK_REMOVED;
+			disk->state |= (1<<MD_DISK_REMOVED);
 		}
 		if (master_sb->this_disk.number == disk->number) {
 			master_sb->this_disk.state = disk->state;
@@ -1076,6 +1081,32 @@ out:
 	return rc;
 }
 
+static int sb0_mark_disk_missing(md_volume_t *vol, int dev_number)
+{
+	mdp_super_t *master_sb;
+	mdp_disk_t *disk;
+	int rc = 0;
+
+	LOG_ENTRY();
+	
+	if (!vol || !vol->sb) {
+		LOG_MD_BUG();
+		rc = EINVAL;
+		goto out;
+	}
+	
+	master_sb = (mdp_super_t *)vol->sb;
+	disk = &master_sb->disks[dev_number];
+	disk->state = (1<<MD_DISK_FAULTY) | (1<<MD_DISK_REMOVED);
+	if (master_sb->this_disk.number == dev_number) {
+		master_sb->this_disk.state = disk->state;
+	}
+
+out:
+	LOG_EXIT_INT(rc);
+	return rc;
+}
+
 static void sb0_increment_events(void *super)
 {
 	mdp_super_t *sb = (mdp_super_t *)super;
@@ -1096,7 +1127,7 @@ static int sb0_write_sb(md_member_t *member)
 	u_int32_t index = member->dev_number;
 
 	LOG_ENTRY();
-	
+
 
 	obj = member->obj;
 
@@ -1105,7 +1136,7 @@ static int sb0_write_sb(md_member_t *member)
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
 	}
-	
+
 	if (vol->commit_flag & MD_COMMIT_BACKUP_METADATA) {
 		sb = EngFncs->engine_alloc(MD_SB_BYTES);
 	} else {
@@ -1224,9 +1255,9 @@ static int sb0_read_saved_info(md_member_t *member)
 	if (!member->saved_info) {
 		LOG_MD_BUG();
 		LOG_EXIT_INT(EINVAL);
-		return EINVAL;	
+		return EINVAL;
 	}
-	
+
 	location = member->super_offset;
 	location += MD_SB0_SAVED_INFO_SECTOR_OFFSET;
 	LOG_DEBUG("Reading MD saved info block at %"PRIu64" on %s\n",
@@ -1256,13 +1287,13 @@ static int sb0_write_saved_info(md_member_t *member)
 	if (!member->saved_info) {
 		LOG_ERROR("No Data to write\n");
 		LOG_EXIT_INT(EINVAL);
-		return EINVAL;	
+		return EINVAL;
 	}
 
 	member->saved_info->signature = MD_SAVED_INFO_SIGNATURE;
 
 	member->saved_info->csum = md_calc_saved_info_csum(member->saved_info);
-	
+
 	location = member->super_offset;
 	location += MD_SB0_SAVED_INFO_SECTOR_OFFSET;
 
@@ -1343,6 +1374,7 @@ static struct super_func sb0_handler = {
 	init_sb : sb0_init_sb,
 	load_this_device_info : sb0_load_this_device_info,
 	mark_disk_faulty : sb0_mark_disk_faulty,
+	mark_disk_missing : sb0_mark_disk_missing,
 	max_disks : sb0_max_disks,
 	read_saved_info : sb0_read_saved_info,
 	remove_disk : sb0_remove_disk,
@@ -1545,7 +1577,10 @@ static void sb1_print_sb(void *super)
 	LOG_DEBUG("dev_number:      %d,\n", sb->dev_number);
 	LOG_DEBUG("cnt_corrected_read: %d,\n", sb->cnt_corrected_read);
 	LOG_DEBUG("events:          %"PRIu64".\n", sb->events);
-	LOG_DEBUG("resync_offset:   %"PRIu64".\n", sb->resync_offset);
+	if (sb->resync_offset == -1)
+		LOG_DEBUG("resync_offset:   -1.\n");
+	else
+		LOG_DEBUG("resync_offset:   %"PRIu64".\n", sb->resync_offset);
 	LOG_DEBUG("max_dev:         %d,\n", sb->max_dev);
 	for (i=0; i<sb->max_dev; i++) {
 		LOG_DEBUG("dev_roles[%03d]:  %X,\n", i, sb->dev_roles[i]);
@@ -1694,7 +1729,7 @@ static int sb1_add_new_disk(md_member_t *member)
 		rc = EINVAL;
 		goto out;
 	}
-	
+
 	sb = (mdp_sb_1_t *)member->vol->sb;
 	if (!sb) {
 		LOG_MD_BUG();
@@ -1744,7 +1779,7 @@ static int sb1_add_new_disk(md_member_t *member)
 		member->raid_disk = -1;
 	}
 	member->flags |= MD_MEMBER_NEW;
-	
+
 	LOG_DEBUG("%s: raid_disks(%d), max_dev(%d).\n",
 		  sb->set_name, sb->raid_disks, sb->max_dev);
 out:
@@ -1909,7 +1944,7 @@ static int sb1_find_empty_slot(void *super, u_int32_t *available_slot)
 	} else {
 		*available_slot = i;
 	}
-	
+
 	LOG_EXIT_INT(rc);
 	return rc;
 }
@@ -1988,7 +2023,7 @@ static void sb1_set_this_device_state(md_member_t *member)
 	}
 
 	sb = (mdp_sb_1_t *)member->vol->sb;
-	
+
 	if (member->flags & MD_MEMBER_DISK_FAULTY) {
 		sb->dev_roles[member->dev_number] = 0xFFFE;
 	} else if (member->flags & MD_MEMBER_DISK_SPARE) {
@@ -2100,7 +2135,7 @@ static int sb1_mark_disk_faulty(md_member_t *member, boolean mark_removed)
 		member->flags |= MD_MEMBER_DISK_FAULTY;
 	} else if (member->flags & MD_MEMBER_DISK_SPARE) {
 		member->flags &= ~MD_MEMBER_DISK_SPARE;
-		member->flags |= MD_MEMBER_DISK_FAULTY;	
+		member->flags |= MD_MEMBER_DISK_FAULTY;
 	} else {
 		LOG_MD_BUG();
 		rc = EINVAL;
@@ -2114,6 +2149,25 @@ out:
 	return rc;
 }
 
+static int sb1_mark_disk_missing(md_volume_t *vol, int dev_number)
+{
+	mdp_sb_1_t *master_sb;
+	int rc = 0;
+
+	LOG_ENTRY();
+	
+	if (!vol || !vol->sb) {
+		LOG_MD_BUG();
+		rc = EINVAL;
+		goto out;
+	}
+	master_sb = (mdp_sb_1_t *)vol->sb;
+	master_sb->dev_roles[dev_number] = 0xFFFE;
+out:
+	LOG_EXIT_INT(rc);
+	return rc;
+}
+
 static void sb1_set_utime(void *super)
 {
 	mdp_sb_1_t *sb = (mdp_sb_1_t *)super;
@@ -2241,7 +2295,7 @@ static md_array_info_t * sb1_get_disk_array_info(void *super)
 				array->active_disks++;
 				array->working_disks++;
 			}
-		}		
+		}
 	}
 
 	LOG_EXIT_PTR(array);
@@ -2317,7 +2371,7 @@ static void sb1_set_sb_info(void *super, md_super_info_t *info)
 	sb->max_dev = info->nr_disks;
 	sb->raid_disks = info->raid_disks;
 	LOG_WARNING("Superblock disk counts have been changed,"
-		    " max_dev(%03d) raid_disks(%03d)",
+		    " max_dev(%03d) raid_disks(%03d)\n",
 		    sb->max_dev, sb->raid_disks);
 	LOG_EXIT_VOID();
 }
@@ -2406,7 +2460,7 @@ static int sb1_write_sb(md_member_t *member)
 		rc = EINVAL;
 		goto out;
 	}
-	
+
 	vol = member->vol;
 
 	/* Copy from master superblock */
@@ -2415,7 +2469,7 @@ static int sb1_write_sb(md_member_t *member)
 		goto out;
 	}
 	sb1_set_this_device_info(member);
-	
+
 	sb1_print_sb(member->sb);
 
 	/*
@@ -2485,13 +2539,13 @@ static int sb1_write_saved_info(md_member_t *member)
 	if (!member->saved_info) {
 		LOG_MD_BUG();
 		LOG_EXIT_INT(EINVAL);
-		return EINVAL;	
+		return EINVAL;
 	}
 
 	member->saved_info->signature = MD_SAVED_INFO_SIGNATURE;
 
 	member->saved_info->csum = md_calc_saved_info_csum(member->saved_info);
-	
+
 	location = member->super_offset;
 	location += MD_SB1_SAVED_INFO_SECTOR_OFFSET;
 
@@ -2522,9 +2576,9 @@ static int sb1_read_saved_info(md_member_t *member)
 	if (!member->saved_info) {
 		LOG_MD_BUG();
 		LOG_EXIT_INT(EINVAL);
-		return EINVAL;	
+		return EINVAL;
 	}
-	
+
 	location = member->super_offset;
 	location += MD_SB1_SAVED_INFO_SECTOR_OFFSET;
 	LOG_DEBUG("Reading MD saved info block at %"PRIu64" on %s\n",
@@ -2542,7 +2596,7 @@ static int sb1_read_saved_info(md_member_t *member)
 static int sb1_zero_superblock(md_member_t *member, boolean now)
 {
 	char sb[MD_SB_1_BYTES];
-	
+
 	LOG_ENTRY();
 	LOG_DEBUG("Removing MD superblock from %s at %"PRIu64".\n",
 		  member->obj->name, member->super_offset);
@@ -2606,6 +2660,7 @@ static struct super_func sb1_handler = {
 	init_sb : sb1_init_sb,
 	load_this_device_info : sb1_load_this_device_info,
 	mark_disk_faulty : sb1_mark_disk_faulty,
+	mark_disk_missing : sb1_mark_disk_missing,
 	max_disks : sb1_max_disks,
 	read_saved_info : sb1_read_saved_info,
 	remove_disk : sb1_remove_disk,
@@ -2709,7 +2764,7 @@ int md_volume_add_new_member(md_volume_t *vol, md_member_t *member)
 	if (rc) {
 		goto out_remove;
 	}
-	
+
 	/* Free all existing superblocks, then re-create from the master */
 	LIST_FOR_EACH(vol->members, iter, my_member) {
 		if (my_member->sb) {
@@ -2729,7 +2784,7 @@ out_remove:
 		member->vol = NULL;
 		EngFncs->delete_element(e);
 	}
-	
+
 	md_volume_get_super_info(vol, &info);
 	vol->nr_disks = info.nr_disks;
 	vol->raid_disks = info.raid_disks;
@@ -2737,6 +2792,74 @@ out_remove:
 	vol->spare_disks = info.spare_disks;
 	vol->working_disks = info.working_disks;
 	vol->failed_disks = info.failed_disks;
+
+	LOG_DEBUG("MD region %s: nr_disks(%d) raid_disks(%d) active_disks(%d)"
+		  " spare_disks(%d) working_disks(%d) failed_disks(%d).\n",
+		  vol->name, vol->nr_disks, vol->raid_disks, vol->active_disks,
+		  vol->spare_disks, vol->working_disks, vol->failed_disks);
+
+out:
+	LOG_EXIT_INT(rc);
+	return rc;
+}
+
+/*
+ * md_volume_add_new_missing
+ * - This function appends a missing disk entry at the current position (nr_disks)
+ * - To create a degraded array with a missing entry at any position, the caller
+ * must coordinate.  For example, to create a [disk1, missing, disk2] raid5 array,
+ * the raid5 plugin should do:
+ *    md_volume_add_new_member(vol, disk1)
+ *    md_volume_add_new_missing(vol)
+ *    md_volume_add_new_member(vol, disk2)
+ */
+int md_volume_add_new_missing(md_volume_t *vol)
+{
+	int rc = 0;
+	int rc2;
+	md_member_t *my_member;
+	list_element_t iter;
+	md_super_info_t info;
+
+	LOG_ENTRY();
+
+	if (!vol || !vol->sb_func) {
+		LOG_MD_BUG();
+		rc = EINVAL;
+		goto out;
+	}
+
+	/* Get current superblock */
+	md_volume_get_super_info(vol, &info);
+	info.nr_disks++;
+	info.raid_disks++;
+	info.failed_disks++;
+	info.state_flags = MD_SUPER_INFO_CLEAN;
+	vol->sb_func->set_sb_info(vol->sb, &info);
+	vol->sb_func->mark_disk_missing(vol, info.nr_disks-1);
+	
+	/* Free all existing superblocks, then re-create from the master */
+	LIST_FOR_EACH(vol->members, iter, my_member) {
+		if (my_member->sb) {
+			EngFncs->engine_free(my_member->sb);
+			my_member->sb = NULL;
+		}
+		rc2 = vol->sb_func->duplicate_sb(&my_member->sb, vol->sb);
+		if (!rc2) {
+			vol->sb_func->set_this_device_info(my_member);
+		} else if (!rc) {
+			rc = rc2; //Save and return the first error (if any)
+		}
+	}
+
+	md_volume_get_super_info(vol, &info);
+	vol->nr_disks = info.nr_disks;
+	vol->raid_disks = info.raid_disks;
+	vol->active_disks = info.active_disks;
+	vol->spare_disks = info.spare_disks;
+	vol->working_disks = info.working_disks;
+	vol->failed_disks = info.failed_disks;
+	vol->flags |= MD_DEGRADED;
 	
 	LOG_DEBUG("MD region %s: nr_disks(%d) raid_disks(%d) active_disks(%d)"
 		  " spare_disks(%d) working_disks(%d) failed_disks(%d).\n",
@@ -2762,7 +2885,7 @@ int md_write_sbs_to_disk(md_volume_t * vol)
 	list_element_t iter;
 	md_member_t *member;
 
-	LOG_ENTRY();	
+	LOG_ENTRY();
 	if (!vol || !vol->region) {
 		LOG_EXIT_INT(EFAULT);
 		return EFAULT;
@@ -2787,7 +2910,7 @@ int md_write_sbs_to_disk(md_volume_t * vol)
 
 	//md_print_sb(message_buffer, MD_MESSAGE_BUF_SIZE, vol);
 	//LOG_DEBUG("%s\n", message_buffer);
-	
+
 	level = vol->sb_func->get_level(vol->sb);
 
 	LIST_FOR_EACH(vol->members, iter, member) {
@@ -2867,7 +2990,7 @@ int md_read_saved_info(md_member_t *member)
 {
 	int rc = 0;
 	md_saved_info_t *info;
-	
+
 	LOG_ENTRY();
 	info = EngFncs->engine_alloc(MD_SAVED_INFO_BYTES);
 	if (!info) {
@@ -2910,7 +3033,7 @@ int md_member_set_sb(md_member_t *member, void *sb)
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
 	}
-	
+
 	if (!member->vol || !member->vol->sb_func) {
 		LOG_MD_BUG();
 		LOG_EXIT_INT(EINVAL);
@@ -2934,7 +3057,7 @@ int md_member_set_sb(md_member_t *member, void *sb)
 int md_member_get_disk_major(md_member_t *member)
 {
 	int dev_major;
-	
+
 	LOG_ENTRY();
 	if (!member->vol) {
 		LOG_EXIT_INT(-1);
@@ -2960,7 +3083,7 @@ int md_member_get_disk_major(md_member_t *member)
 int md_member_get_disk_minor(md_member_t *member)
 {
 	int dev_minor;
-	
+
 	LOG_ENTRY();
 	if (!member->vol) {
 		LOG_EXIT_INT(-1);
@@ -3058,7 +3181,7 @@ static int md_read_metadata(storage_object_t *obj, u_int64_t loc, void *buf, u_i
 	int fd;
 
 	LOG_ENTRY();
-	
+
 	if (obj->data_type != DATA_TYPE) {
 		LOG_DETAILS("Object not data type, skipping %s.\n", obj->name);
 		LOG_EXIT_INT(rc);
@@ -3120,7 +3243,7 @@ int md_read_sb0(storage_object_t *obj, void **super)
 		*super = sb;
 	} else {
 		LOG_DEBUG("(%s) does not have MD superblock.\n", obj->name);
-		EngFncs->engine_free(sb);	
+		EngFncs->engine_free(sb);
 	}
 	LOG_EXIT_INT(rc);
 	return rc;
@@ -3171,7 +3294,7 @@ int md_read_sb1(storage_object_t *obj, void **super, md_sb_ver_t *sb_ver)
 		*super = sb;
 	} else {
 		LOG_DEBUG("(%s) does not have MD superblock.\n", obj->name);
-		EngFncs->engine_free(sb);	
+		EngFncs->engine_free(sb);
 	}
 	LOG_EXIT_INT(rc);
 	return rc;
