@@ -568,6 +568,8 @@ static void display_volume_info( md_volume_t * vol )
 
 	my_plugin = mp_plugin;
 
+	LOG_ENTRY();
+
 	LIST_FOR_EACH(vol->members, iter, member) {
 		if (member->obj) {
 			count++;
@@ -596,6 +598,8 @@ static void display_volume_info( md_volume_t * vol )
 		LOG_DEBUG("                  disk[%02d]: maj= %d  min= %d  number= %d  raid_number= %d\n",
 			  member->dev_number, d.major, d.minor, d.number, d.raid_disk);
 	}
+
+	LOG_EXIT_VOID();
 }
 
 
@@ -2403,7 +2407,7 @@ static plugin_functions_t multipath_functions = {
 };
 
 plugin_record_t   multipath_plugin_record = {
-	id:                    		SetPluginID(EVMS_OEM_IBM, EVMS_REGION_MANAGER, 9),
+	id:                    		EVMS_MD_MULTIPATH_PLUGIN_ID,
 
 	version:              		{ major:      MAJOR_VERSION,
 					  minor:      MINOR_VERSION,
@@ -2417,9 +2421,9 @@ plugin_record_t   multipath_plugin_record = {
 					  minor:      0,
 					  patchlevel: 0}},
 
-	short_name:            		"MD Multipath",
-	long_name:             		"MD Multipath Region Manager",
-	oem_name:              		"IBM",
+	short_name:            		EVMS_MD_MULTIPATH_PLUGIN_SHORT_NAME,
+	long_name:             		EVMS_MD_MULTIPATH_PLUGIN_LONG_NAME,
+	oem_name:              		EVMS_IBM_OEM_NAME,
 
 	functions:             		{plugin: &multipath_functions},
 
