@@ -22,14 +22,12 @@
 #ifndef _MD_MULTIPATH_MGR_H_
 #define _MD_MULTIPATH_MGR_H_
 
-#define MULTIPATH_ACTIVE (1<<MD_DISK_ACTIVE | 1<<MD_DISK_SYNC | 1<<MD_DISK_NEW)
-					 
 #define EVMS_Task_Rewrite_Superblock  (EVMS_Task_Plugin_Function+1)
 
 #define MP_CREATE_OPTION_COUNT	0
 #define MP_REWRITE_SB_OPTION_COUNT 0
 
-#define VOL_MAX_NR_DISKS(v) (v->nr_disks > v->super_block->nr_disks) ? v->nr_disks : v->super_block->nr_disks;
+#define VOL_MAX_NR_DISKS(v, info) (v->nr_disks > info->nr_disks) ? v->nr_disks : info->nr_disks;
 
 #endif
 
