@@ -936,7 +936,7 @@ static int raid0_create( list_anchor_t    objects,
 	list_element_t iter1, iter2;
 	md_sb_ver_t sb_ver = {MD_SB_VER_0, 90, 0};
 	md_member_t *member;
-	u_int32_t chunksize;
+	u_int32_t chunksize = MD_DEFAULT_CHUNK_SIZE;
 	int rc = 0;
 
 	my_plugin = raid1_plugin;
