@@ -191,7 +191,6 @@ static int raid1_can_children_expand (
 	}
 	
 	*max_size = expand_size;
-	//*max_size = MD_NEW_SIZE_SECTORS(*max_size);
 
 out:
 	if (temp_list) {
@@ -290,28 +289,28 @@ static int raid1_init_expand_option_descriptors( task_context_t * context )
 				rc = raid1_can_children_expand(region, -1, &max_expand_size);
 				if (!rc) {
 
-					context->option_descriptors->count = RAID1_EXPAND_OPTION_COUNT;
+					context->option_descriptors->count = RAID1_EXPAND_OPT_COUNT;
 
 					// Expanded RAID1 region size delta
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.list = NULL;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range = EngFncs->engine_alloc( sizeof(value_range_t) );
-					if (context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range==NULL) {
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.list = NULL;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range = EngFncs->engine_alloc( sizeof(value_range_t) );
+					if (context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range==NULL) {
 						LOG_EXIT_INT(ENOMEM);
 						return ENOMEM;
 					}
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint_type = EVMS_Collection_Range;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].flags = 0;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].help = NULL;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].name = EngFncs->engine_strdup( RAID1_EXPAND_OPTION_SIZE_NAME );
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].tip =
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint_type = EVMS_Collection_Range;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].flags = 0;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].help = NULL;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].name = EngFncs->engine_strdup( RAID1_EXPAND_OPT_SIZE_NAME );
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].tip =
 						EngFncs->engine_strdup( _("Use this option to specify how much space to add to the region.") );
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].title = EngFncs->engine_strdup( _("Additional Size") );
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].type = EVMS_Type_Unsigned_Int64;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].unit = EVMS_Unit_Sectors;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_EXPAND_SIZE;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range->max.ui64 = max_expand_size;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range->increment.ui64 = 1;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].value.ui64 = max_expand_size;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].title = EngFncs->engine_strdup( _("Additional Size") );
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].type = EVMS_Type_Unsigned_Int64;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].unit = EVMS_Unit_Sectors;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_EXPAND_SIZE;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range->max.ui64 = max_expand_size;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range->increment.ui64 = 1;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].value.ui64 = max_expand_size;
 
 				}
 			}
@@ -347,28 +346,28 @@ static int raid1_init_shrink_option_descriptors( task_context_t * context )
 				rc = raid1_can_children_shrink(region, -1, &max_shrink_size);
 				if (!rc) {
 
-					context->option_descriptors->count = RAID1_SHRINK_OPTION_COUNT;
+					context->option_descriptors->count = RAID1_SHRINK_OPT_COUNT;
 
 					// Expanded RAID1 region size delta
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.list = NULL;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range = EngFncs->engine_alloc( sizeof(value_range_t) );
-					if (context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range==NULL) {
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.list = NULL;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range = EngFncs->engine_alloc( sizeof(value_range_t) );
+					if (context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range==NULL) {
 						LOG_EXIT_INT(ENOMEM);
 						return ENOMEM;
 					}
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint_type = EVMS_Collection_Range;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].flags = 0;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].help = NULL;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].name = EngFncs->engine_strdup( RAID1_SHRINK_OPTION_SIZE_NAME );
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].tip =
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint_type = EVMS_Collection_Range;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].flags = 0;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].help = NULL;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].name = EngFncs->engine_strdup( RAID1_SHRINK_OPT_SIZE_NAME );
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].tip =
 						EngFncs->engine_strdup( _("Use this option to specify how much space to reduce from the region.") );
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].title = EngFncs->engine_strdup( _("Shrink by Size") );
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].type = EVMS_Type_Unsigned_Int64;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].unit = EVMS_Unit_Sectors;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_SHRINK_SIZE;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range->max.ui64 = max_shrink_size;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range->increment.ui64 = 1;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].value.ui64 = max_shrink_size;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].title = EngFncs->engine_strdup( _("Shrink by Size") );
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].type = EVMS_Type_Unsigned_Int64;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].unit = EVMS_Unit_Sectors;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_SHRINK_SIZE;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range->max.ui64 = max_shrink_size;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range->increment.ui64 = 1;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].value.ui64 = max_shrink_size;
 
 				}
 			}
@@ -414,9 +413,9 @@ static int raid1_set_expand_option( task_context_t * context,
 						expand_sectors = RAID1_MINIMUM_EXPAND_SIZE;
 						*effect |= EVMS_Effect_Inexact;
 					}
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_EXPAND_SIZE;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].constraint.range->max.ui64 = max_expand_size;
-					context->option_descriptors->option[RAID1_EXPAND_OPTION_SIZE_INDEX].value.ui64 = expand_sectors;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_EXPAND_SIZE;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].constraint.range->max.ui64 = max_expand_size;
+					context->option_descriptors->option[RAID1_EXPAND_OPT_SIZE_INDEX].value.ui64 = expand_sectors;
 				}
 			}
 		}
@@ -461,9 +460,9 @@ static int raid1_set_shrink_option( task_context_t * context,
 						shrink_sectors = RAID1_MINIMUM_SHRINK_SIZE;
 						*effect |= EVMS_Effect_Inexact;
 					}
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_SHRINK_SIZE;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].constraint.range->max.ui64 = max_shrink_size;
-					context->option_descriptors->option[RAID1_SHRINK_OPTION_SIZE_INDEX].value.ui64 = shrink_sectors;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range->min.ui64 = RAID1_MINIMUM_SHRINK_SIZE;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].constraint.range->max.ui64 = max_shrink_size;
+					context->option_descriptors->option[RAID1_SHRINK_OPT_SIZE_INDEX].value.ui64 = shrink_sectors;
 				}
 			}
 		}
@@ -483,14 +482,14 @@ static void raid1_get_expand_options( option_array_t * options, sector_count_t
 
         if (options->option[i].is_number_based) {
 
-            if (options->option[i].number == RAID1_EXPAND_OPTION_SIZE_INDEX) {
+            if (options->option[i].number == RAID1_EXPAND_OPT_SIZE_INDEX) {
                 *size = options->option[i].value.ui64;
             }
 
         }
         else {
 
-            if (strcmp(options->option[i].name, RAID1_EXPAND_OPTION_SIZE_NAME) == 0) {
+            if (strcmp(options->option[i].name, RAID1_EXPAND_OPT_SIZE_NAME) == 0) {
                 *size = options->option[i].value.ui64;
             }
 
@@ -511,14 +510,14 @@ static void raid1_get_shrink_options( option_array_t * options, sector_count_t
 
         if (options->option[i].is_number_based) {
 
-            if (options->option[i].number == RAID1_SHRINK_OPTION_SIZE_INDEX) {
+            if (options->option[i].number == RAID1_SHRINK_OPT_SIZE_INDEX) {
                 *size = options->option[i].value.ui64;
             }
 
         }
         else {
 
-            if (strcmp(options->option[i].name, RAID1_SHRINK_OPTION_SIZE_NAME) == 0) {
+            if (strcmp(options->option[i].name, RAID1_SHRINK_OPT_SIZE_NAME) == 0) {
                 *size = options->option[i].value.ui64;
             }
 
@@ -1008,7 +1007,10 @@ static int raid1_discover( list_anchor_t input_list,
 static int raid1_get_create_options(
 	option_array_t * options,
 	char ** spare_disk,
-	md_sb_ver_t *sb_ver)
+	md_sb_ver_t *sb_ver,
+	boolean * degrade,
+	int * missing_index)
+	
 {
 	int i;
 	int rc = 0;
@@ -1022,11 +1024,18 @@ static int raid1_get_create_options(
 
 			switch (options->option[i].number) {
 			
-			case RAID1_CREATE_OPTION_SB1_INDEX:
+			case RAID1_CREATE_OPT_SB1_INDEX:
 				ver1_superblock = options->option[i].value.b;
 				break;
+			case RAID1_CREATE_OPT_DEGRADE_INDEX:
+				*degrade = options->option[i].value.b;
+				break;
+
+			case RAID1_CREATE_OPT_MISSING_INDEX:
+				*missing_index = options->option[i].value.ui32;
+				break;
 			
-			case RAID1_OPTION_SPARE_DISK_INDEX:
+			case RAID1_OPT_SPARE_DISK_INDEX:
 				// Not worth validation, will catch when we try to find the original
 				*spare_disk = options->option[i].value.s;
 				break;
@@ -1037,9 +1046,13 @@ static int raid1_get_create_options(
 
 		} else {
 
-			if (strcmp(options->option[i].name, RAID1_OPTION_SPARE_DISK_NAME) == 0) {
+			if (strcmp(options->option[i].name, RAID1_OPT_SPARE_DISK_NAME) == 0) {
 				*spare_disk = options->option[i].value.s;
-			} else if ((strcmp(options->option[i].name, RAID1_CREATE_OPTION_SB1_NAME) == 0) ) {
+			} else if (strcmp(options->option[i].name, RAID1_CREATE_OPT_DEGRADE_NAME) == 0) {
+				*degrade = options->option[i].value.b;
+			}  else if (strcmp(options->option[i].name, RAID1_CREATE_OPT_MISSING_NAME) == 0) {
+				*missing_index = options->option[i].value.ui32;
+			} else if ((strcmp(options->option[i].name, RAID1_CREATE_OPT_SB1_NAME) == 0) ) {
 				ver1_superblock = options->option[i].value.b;
 			}
 		}
@@ -1114,6 +1127,9 @@ static int raid1_create(
 	list_element_t iter1, iter2;
 	md_sb_ver_t sb_ver = {MD_SB_VER_0, 90, 0};
 	md_member_t *member;
+	boolean degrade = FALSE;
+	int missing_index = 0;
+	boolean missing_added = FALSE;	
 	int rc = 0;
 
 	my_plugin = raid1_plugin;
@@ -1142,7 +1158,7 @@ static int raid1_create(
 		goto error_free;
 	}
 
-	raid1_get_create_options(options, &spare_disk, &sb_ver);
+	raid1_get_create_options(options, &spare_disk, &sb_ver, &degrade, &missing_index);
 
 	LIST_FOR_EACH(objects, iter1, object) {
 		size = min(size, md_object_usable_size(object, &sb_ver, 0));
@@ -1162,6 +1178,10 @@ static int raid1_create(
 
 	// Add raid members
 	LIST_FOR_EACH_SAFE(objects, iter1, iter2, object) {
+		if (degrade && !missing_added && (missing_index == volume->nr_disks)) {
+			rc = md_volume_add_new_missing(volume);
+			missing_added = TRUE;
+		}		
 		member = md_allocate_member(object);
 		if (member) {
 			// This will add the member and update the MD superblock.
@@ -1181,26 +1201,35 @@ static int raid1_create(
 		EngFncs->delete_element(iter1);
 	}
 
-	// Add spare member
-	if (spare) {
-		member = md_allocate_member(spare);
-		if (member) {
-			// This will add the member and update the MD superblock.
-			member->flags |= (MD_MEMBER_NEW | MD_MEMBER_DISK_SPARE);
-			member->data_size = size;
-			rc = md_volume_add_new_member(volume, member);
+	if (degrade) {
+		if (!missing_added) {
+			rc = md_volume_add_new_missing(volume);
+			missing_added = TRUE;
+			if (rc) {
+				goto error_free;
+			}		
+		}
+	} else {
+		// Add spare member
+		if (spare) {
+			member = md_allocate_member(spare);
+			if (member) {
+				// This will add the member and update the MD superblock.
+				member->flags |= (MD_MEMBER_NEW | MD_MEMBER_DISK_SPARE);
+				member->data_size = size;
+				rc = md_volume_add_new_member(volume, member);
+				if (rc) {
+					md_free_member(member);
+					goto error_free;
+				}
+			} else {
+				rc = ENOMEM;
+			}
 			if (rc) {
-				md_free_member(member);
 				goto error_free;
 			}
-		} else {
-			rc = ENOMEM;
-		}
-		if (rc) {
-			goto error_free;
 		}
 	}
-
 	rc = raid1_create_new_region(volume, new_region_list);
 	if (rc) {
 		goto error_free;
@@ -1303,7 +1332,7 @@ static int raid1_expand_shrink_children(int cmd, storage_object_t *region, u_int
 
 	option_array.count = 1;
 	option_array.option[0].is_number_based = FALSE;
-	option_array.option[0].name = RAID1_EXPAND_OPTION_SIZE_NAME;
+	option_array.option[0].name = RAID1_EXPAND_OPT_SIZE_NAME;
 	option_array.option[0].value.ui64 = sectors;
 
 	LOG_DEBUG(" %s region %s. current size = %"PRIu64" sectors\n",
@@ -1683,13 +1712,13 @@ static int raid1_get_option_count( task_context_t * task )
 
 	switch (task->action) {
 	case EVMS_Task_Create:
-		count = RAID1_CREATE_OPTION_COUNT;
+		count = RAID1_CREATE_OPT_COUNT;
 		break;
 	case EVMS_Task_Expand:
-		count = RAID1_EXPAND_OPTION_COUNT;
+		count = RAID1_EXPAND_OPT_COUNT;
 		break;
 	case EVMS_Task_Shrink:
-		count = RAID1_SHRINK_OPTION_COUNT;
+		count = RAID1_SHRINK_OPT_COUNT;
 		break;
 	
 	case MD_RAID1_FUNCTION_ADD_SPARE:
@@ -1895,21 +1924,22 @@ static int raid1_get_active_disks(md_volume_t *vol, list_anchor_t active_disks)
 }
 
 
-typedef struct prune_small_object_parms_s {
-	sector_count_t min_size;
-	sector_count_t chunk_size;
-} prune_small_object_parms_t;
-
-static void prune_small_objects(list_anchor_t objects,
-				prune_small_object_parms_t * parms)
+static void prune_small_objects(list_anchor_t objects, md_volume_t *vol)
 {
 	list_element_t iter1, iter2;
+	sector_count_t size;
+	sector_count_t vol_size;
 	storage_object_t * obj;
 
 	LOG_ENTRY();
 
+	vol_size = md_volume_calc_size(vol);
+ 
 	LIST_FOR_EACH_SAFE(objects, iter1, iter2, obj) {
-		if (MD_CHUNK_ALIGN_NEW_SIZE_SECTORS(parms->chunk_size, obj->size) < parms->min_size) {
+		size = md_object_usable_size(obj, &vol->sb_ver, 0);
+		if (size < vol_size) {
+			LOG_DEBUG("Removing %s from list.  Object size: %"PRIu64", MD usable size: %"PRIu64", required size: %"PRIu64"\n", 
+			          obj->name, obj->size, size, vol_size);
 			EngFncs->delete_element(iter1);
 		}
 	}
@@ -1936,51 +1966,85 @@ static int raid1_init_task( task_context_t * context )
 	
 	case EVMS_Task_Create:
 
-		context->option_descriptors->count = RAID1_CREATE_OPTION_COUNT;
+		context->option_descriptors->count = RAID1_CREATE_OPT_COUNT;
 
 		// Version 1 Superblock Option
 		if (md_can_create_sb_1() == TRUE) {
-			context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].flags = 0;
+			context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].flags = 0;
 			context->min_selected_objects = 1;
 			context->max_selected_objects = MD_SB_1_DISKS;
 		} else {
-			context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].flags = EVMS_OPTION_FLAGS_INACTIVE;
+			context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].flags = EVMS_OPTION_FLAGS_INACTIVE;
 			context->min_selected_objects = 1;
 			context->max_selected_objects = MD_SB_DISKS;
 		}
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].constraint.list = NULL;
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].constraint_type = EVMS_Collection_None;
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].help = NULL;
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].name =
-			EngFncs->engine_strdup( RAID1_CREATE_OPTION_SB1_NAME );
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].tip =
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].constraint.list = NULL;
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].constraint_type = EVMS_Collection_None;
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].help = NULL;
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].name =
+			EngFncs->engine_strdup( RAID1_CREATE_OPT_SB1_NAME );
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].tip =
 			EngFncs->engine_strdup( _("Choose Yes if you want to create MD version 1 super block.") );
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].title = EngFncs->engine_strdup( _("Version 1 Super Block") );
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].type = EVMS_Type_Boolean;
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].unit = EVMS_Unit_None;
-		context->option_descriptors->option[RAID1_CREATE_OPTION_SB1_INDEX].value.b = FALSE;
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].title = EngFncs->engine_strdup( _("Version 1 Super Block") );
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].type = EVMS_Type_Boolean;
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].unit = EVMS_Unit_None;
+		context->option_descriptors->option[RAID1_CREATE_OPT_SB1_INDEX].value.b = FALSE;
+
+		/* Degrade option */
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].constraint.list = NULL;
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].constraint_type = EVMS_Collection_None;
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].help = NULL;
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].name =
+			EngFncs->engine_strdup( RAID1_CREATE_OPT_DEGRADE_NAME );
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].tip =
+			EngFncs->engine_strdup( _("Choose Yes if you want to create a degraded array.") );
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].title =
+			EngFncs->engine_strdup( _("Degraded array") );
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].type = EVMS_Type_Boolean;
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].unit = EVMS_Unit_None;
+		context->option_descriptors->option[RAID1_CREATE_OPT_DEGRADE_INDEX].value.b = FALSE;
+
+		/* Missing index option */
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED | EVMS_OPTION_FLAGS_INACTIVE;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].constraint.range = 
+			EngFncs->engine_alloc(sizeof(value_range_t));
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].constraint.range->min.ui32 = 0;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].constraint.range->max.ui32 = 1;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].constraint.range->increment.ui32 = 1;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].constraint_type = EVMS_Collection_Range;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].help = NULL;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].name = 
+			EngFncs->engine_strdup(RAID1_CREATE_OPT_MISSING_NAME );
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].tip = 
+			EngFncs->engine_strdup(_("Disk index for missing member."));
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].title = 
+			EngFncs->engine_strdup(_("Missing disk index"));
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].type = EVMS_Type_Unsigned_Int32;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].unit = EVMS_Unit_None;
+		context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].value.ui32 = 0;
 
 		// Spare Disk Option
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].flags = EVMS_OPTION_FLAGS_NOT_REQUIRED;
 		// get the list of disks that can be spares.
 		raid1_create_selectable_spare_list(
-			(value_list_t **)&context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].constraint.list,
+			(value_list_t **)&context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].constraint.list,
 			context->selected_objects,0);
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].constraint_type = EVMS_Collection_List;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].help = NULL;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].name =
-			EngFncs->engine_strdup(RAID1_OPTION_SPARE_DISK_NAME );
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].min_len = 1;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].max_len = EVMS_VOLUME_NAME_SIZE;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].tip =
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].constraint_type = EVMS_Collection_List;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].help = NULL;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].name =
+			EngFncs->engine_strdup(RAID1_OPT_SPARE_DISK_NAME );
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].min_len = 1;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].max_len = EVMS_VOLUME_NAME_SIZE;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].tip =
 			EngFncs->engine_strdup(_("Object to use as a spare disk in the array") );
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].title =
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].title =
 			EngFncs->engine_strdup(_("Spare Disk") );
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].type = EVMS_Type_String;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].unit = EVMS_Unit_None;
-		context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s =
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].type = EVMS_Type_String;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].unit = EVMS_Unit_None;
+		context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].value.s =
 			EngFncs->engine_alloc(EVMS_VOLUME_NAME_SIZE+1);
-		strcpy(context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s, RAID1_NO_SELECTION);
+		strcpy(context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].value.s, RAID1_NO_SELECTION);
 
 		// get a list of all valid input  disks, segments, and regions.
 		EngFncs->get_object_list(DISK | SEGMENT | REGION,
@@ -1994,9 +2058,6 @@ static int raid1_init_task( task_context_t * context )
 		md_transfer_list(tmp_list, context->acceptable_objects);
 		EngFncs->destroy_list(tmp_list);
 
-		//Option 1 is a boolean value for version 1 super block
-
-
 		break;
 
 	case EVMS_Task_Expand:
@@ -2041,7 +2102,6 @@ static int raid1_init_task( task_context_t * context )
 						      &tmp_list);
 
 			if (rc == 0) {
-				prune_small_object_parms_t parms;
 
 				/*
 				 * If this MD region is available, it will appear in the list.
@@ -2049,10 +2109,7 @@ static int raid1_init_task( task_context_t * context )
 				 */
 				EngFncs->remove_thing(tmp_list, context->object);
 
-				parms.min_size = md_volume_calc_size(vol);
-				parms.chunk_size = 0;
-
-				prune_small_objects(tmp_list, &parms);
+				prune_small_objects(tmp_list, vol);
 				
 				/* Remove all parents of this MD region from acceptable list */
 				remove_parent_regions_from_list(tmp_list, context->object);
@@ -2156,9 +2213,9 @@ static void warn_if_big_objects( task_context_t * context )
 	 * is specified and see if it is the smallest.
 	 */
 	if (smallest_size != -1) {
-		if (context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s != NULL) {
+		if (context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].value.s != NULL) {
 			spare = md_find_valid_input_object(
-				context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].value.s);
+				context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].value.s);
 
 			if (spare != NULL) {
 				if (vol) {
@@ -2244,12 +2301,16 @@ static void warn_if_big_new_objects( md_volume_t *vol, list_anchor_t objects)
  *  appropriate. Reset the value if necessary and possible. Adjust other
  *  options as appropriate.
  */
-static int raid1_set_option( task_context_t * context,
-			     u_int32_t        index,
-			     value_t        * value,
-			     task_effect_t  * effect )
+static int raid1_set_option(
+	task_context_t * context,
+	u_int32_t index,
+	value_t * value,
+	task_effect_t * effect )
 {
 	int rc = 0;
+	boolean degrade;
+	int answer;
+	char * choice_text[3] = { _("Yes"), _("No"), NULL };
 
 	my_plugin = raid1_plugin;
 	LOG_ENTRY();
@@ -2260,14 +2321,12 @@ static int raid1_set_option( task_context_t * context,
 		return EFAULT;
 	}
 
-	
-
 	switch (context->action) {
 	
 	case EVMS_Task_Create:
 		switch (index) {
 		
-		case RAID1_CREATE_OPTION_SB1_INDEX:
+		case RAID1_CREATE_OPT_SB1_INDEX:
 			context->option_descriptors->option[index].value.b = value->b;
 			if (value->b == TRUE) {
 				context->max_selected_objects = MD_SB_1_DISKS;
@@ -2275,8 +2334,42 @@ static int raid1_set_option( task_context_t * context,
 				context->max_selected_objects = MD_SB_DISKS;
 			}
 			break;
+
+		case RAID1_CREATE_OPT_DEGRADE_INDEX:
+			if (value->b != context->option_descriptors->option[index].value.b) {
+				degrade = FALSE;
+				if (value->b == TRUE) {
+					answer = 1; /* index 1 is "No" */
+					QUESTION(&answer, choice_text, _("Do you really want to create a degraded array?"));
+					if (answer == 0) {
+						/* index 0 is "Yes" */
+						degrade = TRUE;
+					}
+				}
+				context->option_descriptors->option[index].value.b = degrade;
+				if (degrade) {
+					context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].flags |= (EVMS_OPTION_FLAGS_INACTIVE);
+					strcpy(context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].value.s, "");
+					context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].flags &= ~(EVMS_OPTION_FLAGS_INACTIVE);
+					context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].constraint.range->max.ui32 = EngFncs->list_count(context->selected_objects);
+				} else {
+					context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].flags &= ~(EVMS_OPTION_FLAGS_INACTIVE);
+					context->option_descriptors->option[RAID1_CREATE_OPT_MISSING_INDEX].flags |= (EVMS_OPTION_FLAGS_INACTIVE);
+				}
+				*effect |= EVMS_Effect_Reload_Options;
+			}
+			break;
+
+		case RAID1_CREATE_OPT_MISSING_INDEX:
+			/* Verify that the index is within range? */
+			if (value->ui32 > EngFncs->list_count(context->selected_objects)) {
+				rc = EINVAL;
+			} else {
+				context->option_descriptors->option[index].value.ui32 = value->ui32;
+			}
+			break;
 		
-		case RAID1_OPTION_SPARE_DISK_INDEX:
+		case RAID1_OPT_SPARE_DISK_INDEX:
 			// Not worth validation, will catch when we try to find the original
 			strcpy(context->option_descriptors->option[index].value.s, value->s);
 			warn_if_big_objects(context);
@@ -2333,7 +2426,7 @@ static int raid1_set_objects( task_context_t * context,
 	
 	case EVMS_Task_Create:
 		raid1_create_selectable_spare_list(
-			(value_list_t **)&context->option_descriptors->option[RAID1_OPTION_SPARE_DISK_INDEX].constraint.list,
+			(value_list_t **)&context->option_descriptors->option[RAID1_OPT_SPARE_DISK_INDEX].constraint.list,
 			context->selected_objects, 0);
 		warn_if_big_objects(context);
 		*effect |= EVMS_Effect_Reload_Options;
@@ -2685,7 +2778,6 @@ static int raid1_enable_add_disk_function(
 	int rc;
 	list_anchor_t available_objects = NULL;
 	uint count;
-	prune_small_object_parms_t parms;
 
 	LOG_ENTRY();
 	
@@ -2712,10 +2804,7 @@ static int raid1_enable_add_disk_function(
 		 */
 		EngFncs->remove_thing(available_objects, volume->region);
 
-		parms.min_size = md_volume_calc_size(volume);
-		parms.chunk_size = 0;
-
-		prune_small_objects(available_objects, &parms);
+		prune_small_objects(available_objects, volume);
 		
 		/* Remove all parents of this MD region from available list */
 		remove_parent_regions_from_list(available_objects, volume->region);
@@ -3090,42 +3179,42 @@ static int raid1_get_plugin_functions(storage_object_t        * region,
 }
 
 
-static int raid1_can_be_added(md_volume_t * volume, storage_object_t * spare_candidate)
+static int raid1_can_be_added(md_volume_t * volume, storage_object_t * candidate)
 {
+	sector_count_t size;
 	LOG_ENTRY();
 
 	/* The spare must be a disk, segment, or region. */
-	if ((spare_candidate->object_type != DISK) &&
-	    (spare_candidate->object_type != SEGMENT) &&
-	    (spare_candidate->object_type != REGION)) {
-		LOG_ERROR("The type of object %s is not data.\n",
-			  spare_candidate->name);
+	if ((candidate->object_type != DISK) &&
+	    (candidate->object_type != SEGMENT) &&
+	    (candidate->object_type != REGION)) {
+		LOG_ERROR("The type of object %s is not data.\n", candidate->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
 	}
 
 	/* The spare must not be too small. */
-	if (MD_CHUNK_ALIGN_NEW_SIZE_SECTORS(0, spare_candidate->size)
-	    < md_volume_calc_size(volume)) {
+	size = md_object_usable_size(candidate, &volume->sb_ver, 0);
+	if (size < md_volume_calc_size(volume)) {
 		LOG_ERROR("Object %s is too small"
 			  " to be a spare object for array %s.\n",
-			  spare_candidate->name, volume->name);
+			  candidate->name, volume->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
 	}
 
 	/* The region cannot be a spare of itself. */
-	if (spare_candidate == volume->region) {
+	if (candidate == volume->region) {
 		LOG_ERROR("Region %s cannot be a spare object for itself.\n",
-			  spare_candidate->name);
+			  candidate->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
 	}
 
 	/* The spare must be in the same disk group as the region. */
-	if (spare_candidate->disk_group != volume->region->disk_group) {
+	if (candidate->disk_group != volume->region->disk_group) {
 		LOG_ERROR("Object %s is not in the same disk group as region %s.\n",
-			  spare_candidate->name, volume->region->name);
+			  candidate->name, volume->region->name);
 		LOG_EXIT_INT(EINVAL);
 		return EINVAL;
 	}
