@@ -24,12 +24,16 @@
 
 
 // create options:
-#define RAID1_CREATE_OPTION_COUNT	2
+#define RAID1_CREATE_OPT_COUNT	4
 
-#define RAID1_CREATE_OPTION_SB1_INDEX	0
-#define RAID1_CREATE_OPTION_SB1_NAME	"ver1_superblock"
-#define RAID1_OPTION_SPARE_DISK_INDEX  	1
-#define RAID1_OPTION_SPARE_DISK_NAME	"sparedisk"
+#define RAID1_CREATE_OPT_SB1_INDEX	0
+#define RAID1_CREATE_OPT_SB1_NAME	"ver1_superblock"
+#define RAID1_CREATE_OPT_DEGRADE_INDEX 1
+#define RAID1_CREATE_OPT_DEGRADE_NAME "degraded"
+#define RAID1_CREATE_OPT_MISSING_INDEX 2
+#define RAID1_CREATE_OPT_MISSING_NAME "missing_index"
+#define RAID1_OPT_SPARE_DISK_INDEX  	3
+#define RAID1_OPT_SPARE_DISK_NAME	"sparedisk"
 #define RAID1_NO_SELECTION		_("None")
 
 
@@ -38,20 +42,20 @@
 //
 // Expand Option Info
 //
-#define RAID1_EXPAND_OPTION_COUNT                     1
+#define RAID1_EXPAND_OPT_COUNT                     1
 
-#define RAID1_EXPAND_OPTION_SIZE_INDEX                0
-#define RAID1_EXPAND_OPTION_SIZE_NAME                 "Size"
+#define RAID1_EXPAND_OPT_SIZE_INDEX                0
+#define RAID1_EXPAND_OPT_SIZE_NAME                 "Size"
 #define RAID1_MINIMUM_EXPAND_SIZE			(2 * 1024)
 
 
 //
 // Shrink Option Info
 //
-#define RAID1_SHRINK_OPTION_COUNT                     1
+#define RAID1_SHRINK_OPT_COUNT                     1
 
-#define RAID1_SHRINK_OPTION_SIZE_INDEX                0
-#define RAID1_SHRINK_OPTION_SIZE_NAME                 "Size"
+#define RAID1_SHRINK_OPT_SIZE_INDEX                0
+#define RAID1_SHRINK_OPT_SIZE_NAME                 "Size"
 #define RAID1_MINIMUM_SHRINK_SIZE			(2 * 1024)
 #define RAID1_PERCENT_SHRINK_THRESHOLD		90
 
