@@ -100,17 +100,21 @@ typedef struct kill_sectors_s {
 
 #define RAID5_CREATE_OPT_SB1_INDEX              0
 #define RAID5_CREATE_OPT_SB1_NAME               "ver1_superblock"
-#define RAID5_CREATE_OPT_SPARE_DISK_INDEX       1
+#define RAID5_CREATE_OPT_DEGRADE_INDEX          1
+#define RAID5_CREATE_OPT_DEGRADE_NAME           "degraded"
+#define RAID5_CREATE_OPT_MISSING_INDEX          2
+#define RAID5_CREATE_OPT_MISSING_NAME           "missing_index"
+#define RAID5_CREATE_OPT_SPARE_DISK_INDEX       3
 #define RAID5_CREATE_OPT_SPARE_DISK_NAME        "sparedisk"
-#define RAID5_CREATE_OPT_CHUNK_SIZE_INDEX       2
+#define RAID5_CREATE_OPT_CHUNK_SIZE_INDEX       4
 #define RAID5_CREATE_OPT_CHUNK_SIZE_NAME        "chunksize"
-#define RAID5_CREATE_OPT_RAID_LEVEL_INDEX       3
+#define RAID5_CREATE_OPT_RAID_LEVEL_INDEX       5
 #define RAID5_CREATE_OPT_RAID_LEVEL_NAME        "level"
-#define RAID5_CREATE_OPT_PARITY_ALGORITHM_INDEX 4
+#define RAID5_CREATE_OPT_PARITY_ALGORITHM_INDEX 6
 #define RAID5_CREATE_OPT_PARITY_ALGORITHM_NAME  "algorithm"
 #define RAID5_CREATE_NO_SELECTION               _("None")
 
-#define MD_CREATE_OPTIONS_COUNT			5
+#define MD_CREATE_OPTIONS_COUNT			7
 
 
 /*
