@@ -586,9 +586,7 @@ static plugin_functions_t multipath_functions = {
 
 /* Plugin-record for the Multipath plugin.*/
 plugin_record_t multipath_plugin = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_SEGMENT_MANAGER,
-			  9),
+	.id = EVMS_MULTIPATH_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -606,9 +604,9 @@ plugin_record_t multipath_plugin = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "Multipath",
-	.long_name = "Multipath Segment Manager",
-	.oem_name = "IBM",
+	.short_name = EVMS_MULTIPATH_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_MULTIPATH_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.plugin = &multipath_functions
 	},
