@@ -31,7 +31,7 @@ typedef struct private_data_s {
 	sector_count_t     fs_size;
 	sector_count_t     max_fs_size;
 	u_int64_t          ntfs_cluster_size;
-	int64_t            ntfs_nr_clusters;
+	u_int64_t          ntfs_nr_clusters;
 	char             * ntfs_vol_name;
 	char             * ntfs_version;
 	logical_volume_t * clone_source;
