@@ -271,10 +271,12 @@ int has_ntfs_boot_sector(logical_volume_t * ev)
 		if (is_boot_sector_ntfs(boot_sector)) {
 			goto finished;
 		} else {
-			LOG_DETAILS("Primary boot sector is not valid.\n");
+			LOG_DETAILS("Primary boot sector on volume %s is not valid.\n",
+                        ev->name);
 		}
 	} else
-		LOG_WARNING("Unable to read primary boot sector.\n");
+		LOG_WARNING("Unable to read primary boot sector on volume %s.\n",
+                    ev->name);
 
 	/* Try to read NT4+ backup boot sector at the end of the volume. */
 	if (EngFncs->read_volume(ev, fd, boot_sector, NTFS_BLOCK_SIZE, (ev->vol_size << EVMS_VSECTOR_SIZE_SHIFT) - NTFS_BLOCK_SIZE) == NTFS_BLOCK_SIZE) {
@@ -282,7 +284,9 @@ int has_ntfs_boot_sector(logical_volume_t * ev)
 			goto finished;
 		}
 	} else
-		LOG_WARNING("Unable to read NT4+ backup boot sector.\n");
+		LOG_WARNING("Unable to read NT4+ backup boot sector at offset %"PRIu64" on volume %s.\n",
+                    (ev->vol_size << EVMS_VSECTOR_SIZE_SHIFT) - NTFS_BLOCK_SIZE,
+                    ev->name);
 	/* Try to read NT3.51- backup boot sector in the middle of the volume. */
 	if (EngFncs->read_volume(ev, fd, boot_sector, NTFS_BLOCK_SIZE, (ev->vol_size << (EVMS_VSECTOR_SIZE_SHIFT - 1))) == NTFS_BLOCK_SIZE) {
 		if (is_boot_sector_ntfs(boot_sector)) {
@@ -291,7 +295,9 @@ int has_ntfs_boot_sector(logical_volume_t * ev)
 			LOG_DETAILS("Could not find a valid backup boot sector.\n");
 		}
 	} else
-		LOG_WARNING("Unable to read NT3.51- backup boot sector.\n");
+		LOG_WARNING("Unable to read NT3.51- backup boot sector at offset %"PRIu64" on volume %s.\n",
+                    ev->vol_size << (EVMS_VSECTOR_SIZE_SHIFT - 1),
+                    ev->name);
 
 	rc = EINVAL;
 finished:
@@ -702,7 +708,7 @@ sector_count_t get_min_fs_size(logical_volume_t * vol) {
 			read(fds[0], buffer, MAX_USER_MESSAGE_LEN);
 
 			rc = WEXITSTATUS(status);
-			LOG_DETAILS("%s completed with exit code %d \n", argv[0], rc);
+			LOG_DETAILS("%s completed with exit code %d.\n", argv[0], rc);
 
 		} else {
 			/*
@@ -791,7 +797,7 @@ int fill_private_data(logical_volume_t * vol) {
 			read(fds[0], buffer, MAX_USER_MESSAGE_LEN);
 
 			rc = WEXITSTATUS(status);
-			LOG_DETAILS("%s completed with exit code %d \n", argv[0], rc);
+			LOG_DETAILS("%s completed with exit code %d.\n", argv[0], rc);
 
 		} else {
 			/*
@@ -1018,9 +1024,9 @@ int resize_ntfs(logical_volume_t * volume, sector_count_t * new_size) {
 
 			rc = WEXITSTATUS(status);
 			if (rc == 0) {
-				LOG_DETAILS("%s completed with exit code %d \n", argv[0], rc);
+				LOG_DETAILS("%s completed with exit code %d.\n", argv[0], rc);
 			} else {
-				LOG_WARNING("%s completed with exit code %d \n", argv[0], rc);
+				LOG_WARNING("%s completed with exit code %d.\n", argv[0], rc);
 			}
 
 		} else {
@@ -1139,9 +1145,9 @@ int run_ntfsfix(logical_volume_t * volume) {
 
 			rc = WEXITSTATUS(status);
 			if (rc == 0) {
-				LOG_DETAILS("%s completed with exit code %d \n", argv[0], rc);
+				LOG_DETAILS("%s completed with exit code %d.\n", argv[0], rc);
 			} else {
-				LOG_WARNING("%s completed with exit code %d \n", argv[0], rc);
+				LOG_WARNING("%s completed with exit code %d.\n", argv[0], rc);
 			}
 
 		} else {
@@ -1284,9 +1290,9 @@ int run_ntfsclone(logical_volume_t * source,
 			 */
 			rc = WEXITSTATUS(status);
 			if (rc == 0) {
-				MESSAGE("%s completed successfully \n", argv[0]);
+				MESSAGE("%s completed successfully.\n", argv[0]);
 			} else {
-				MESSAGE("%s completed with exit code %d \n", argv[0], rc);
+				MESSAGE("%s completed with exit code %d.\n", argv[0], rc);
 			}
 
 		} else {
