@@ -749,7 +749,7 @@ static int ogfs_get_cluster_metadata(logical_volume_t *volume, char **metadata)
 static int ogfs_probe(logical_volume_t *volume)
 {
 	int rc;
-	char *metadata;
+	char *metadata = NULL;
 
 	LOG_ENTRY();
 
@@ -1132,7 +1132,7 @@ static int ogfs_expand(logical_volume_t *volume, sector_count_t *new_size)
  */
 static void ogfs_enumerate_journal_names(logical_volume_t *volume, list_anchor_t names)
 {
-	u_int32_t count;
+	u_int32_t count = 0;
 	ogfs_jindex_t *ji;
 	struct ogfs_sb *ogfs_sb;
 
@@ -2046,7 +2046,8 @@ static int build_mkfs_exec_args(logical_volume_t *volume, option_array_t *option
 static int ogfs_create(logical_volume_t *volume, option_array_t *options)
 {
 	int rc;
-	char *tmpfile, *argv[OGFS_MKFS_MAX_ARG_COUNT+1];
+	char *tmpfile = NULL;
+	char *argv[OGFS_MKFS_MAX_ARG_COUNT+1];
 
 	LOG_ENTRY();
 	
