@@ -106,7 +106,7 @@ static void set_mkfs_options( option_array_t * options, char ** argv, char * vol
                 }
 
 		switch (options->option[i].number) {
-			
+
 			case MKFS_SETVOL_INDEX:
 				/* 'set volume name' option */
 				if ( options->option[i].value.s ) {
@@ -125,7 +125,7 @@ static void set_mkfs_options( option_array_t * options, char ** argv, char * vol
 
 			default:
 				break;
-				
+
 		}
 	}
 
@@ -243,12 +243,12 @@ static void set_fsck_options( option_array_t * options, char ** argv, logical_vo
 					argv[opt_count++] = "--check";
                                 }
 				break;
-				
+
 			default:
 				break;
 			}
 	}
-	
+
 	argv[opt_count++] = volume->dev_node;
 	/* NULL terminate the pointer array */
 	argv[opt_count] = NULL;
@@ -378,9 +378,9 @@ static int fsim_get_reiserfs_super_block( logical_volume_t *volume, struct reise
 
 	if ( rc == 0 ) {
 		/* see if primary reiserfs_super_block is Reiser */
-		if (strncmp(sb_ptr->s_v1.s_magic, REISERFS_SUPER_MAGIC_STRING,
+		if (strncmp((char *) sb_ptr->s_v1.s_magic, REISERFS_SUPER_MAGIC_STRING,
 			    strlen(REISERFS_SUPER_MAGIC_STRING)) != 0 &&
-		    strncmp(sb_ptr->s_v1.s_magic, REISER2FS_SUPER_MAGIC_STRING,
+		    strncmp((char *) sb_ptr->s_v1.s_magic, REISER2FS_SUPER_MAGIC_STRING,
 			    strlen(REISER2FS_SUPER_MAGIC_STRING)) != 0) {
 
 			/* check old SB location */
@@ -388,9 +388,9 @@ static int fsim_get_reiserfs_super_block( logical_volume_t *volume, struct reise
 
 			if ( rc == 0 ) {
 				/* see if primary reiserfs_super_block is Reiser */
-				if (strncmp(sb_ptr->s_v1.s_magic, REISERFS_SUPER_MAGIC_STRING,
+				if (strncmp((char *) sb_ptr->s_v1.s_magic, REISERFS_SUPER_MAGIC_STRING,
 					    strlen(REISERFS_SUPER_MAGIC_STRING)) != 0 &&
-				    strncmp(sb_ptr->s_v1.s_magic, REISER2FS_SUPER_MAGIC_STRING,
+				    strncmp((char *) sb_ptr->s_v1.s_magic, REISER2FS_SUPER_MAGIC_STRING,
 					    strlen(REISER2FS_SUPER_MAGIC_STRING)) != 0) {
 					rc = EINVAL;
 				}
@@ -1211,7 +1211,7 @@ static int reiser_init_task(task_context_t *context)
 	}
 
 	switch (context->action) {
-	
+
 	case EVMS_Task_mkfs:
 
 		rc = fs_init_mkfs_acceptable_objects(context);
@@ -1386,10 +1386,10 @@ static int reiser_set_option(task_context_t *context,
 	}
 
 	switch (context->action) {
-	
+
 	case EVMS_Task_mkfs:
 		switch (index) {
-		
+
 		case MKFS_VERSION_INDEX:
 			/* user typed over version field option set? */
 			// ignore and reload from the option descriptor.
@@ -1413,7 +1413,7 @@ static int reiser_set_option(task_context_t *context,
 
 	case EVMS_Task_fsck:
 		switch (index) {
-		
+
 		case FSCK_MODE_INDEX:
 			/* if mounted, only allow read-only */
 			if (EngFncs->is_mounted(context->volume->dev_node, NULL)) {
@@ -1555,7 +1555,7 @@ static int reiser_get_volume_info(logical_volume_t *volume,
 			Info->info[0].desc = EngFncs->engine_strdup( _("Magic Number") );
 			Info->info[0].type               = EVMS_Type_String;
 			Info->info[0].unit               = EVMS_Unit_None;
-			Info->info[0].value.s = EngFncs->engine_strdup(sb_ptr->s_v1.s_magic);
+			Info->info[0].value.s = EngFncs->engine_strdup((char *) sb_ptr->s_v1.s_magic);
 			Info->info[0].collection_type    = EVMS_Collection_None;
 			memset( &Info->info[0].group, 0, sizeof(group_info_t));
 
@@ -1573,7 +1573,7 @@ static int reiser_get_volume_info(logical_volume_t *volume,
 			Info->info[2].desc = EngFncs->engine_strdup( _("File system volume label") );
 			Info->info[2].type               = EVMS_Type_String;
 			Info->info[2].unit               = EVMS_Unit_None;
-			Info->info[2].value.s = EngFncs->engine_strdup(sb_ptr->s_label);
+			Info->info[2].value.s = EngFncs->engine_strdup((char *) sb_ptr->s_label);
 			Info->info[2].collection_type    = EVMS_Collection_None;
 			memset( &Info->info[2].group, 0, sizeof(group_info_t));
 
