@@ -1096,9 +1096,7 @@ static cluster_functions_t ft={
 
 plugin_record_t ece_plugin_record = {
 	
-	id:			SetPluginID(EVMS_OEM_IBM,
-					    EVMS_CLUSTER_MANAGER_INTERFACE_MODULE,
-					    2),
+	id:			EVMS_RSCT_PLUGIN_ID,
 	
 	version:		{major:      MAJOR_VERSION,
 				 minor:      MINOR_VERSION,
@@ -1112,8 +1110,8 @@ plugin_record_t ece_plugin_record = {
 						minor:      0,
 						patchlevel: 0} },
 	
-	short_name:		"RSCT",
-	long_name:		"Cluster Manager RSCT",
+	short_name:		EVMS_RSCT_PLUGIN_SHORT_NAME,
+	long_name:		EVMS_RSCT_PLUGIN_LONG_NAME,
 	oem_name:		"NCSA",
 	
 	functions:	{cluster:   &ft},
