@@ -2657,16 +2657,16 @@ static struct plugin_functions_s sft={
 
 static plugin_record_t plugin_record = {
 
-        id:                               SetPluginID(EVMS_OEM_IBM, EVMS_SEGMENT_MANAGER, 2 ),
+        id:                               EVMS_S390_PLUGIN_ID,
 
         version:                          {MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL},
 
         required_engine_api_version:      {15, 0, 0},
         required_plugin_api_version:      {plugin: {13, 1, 0}},
 
-        short_name:                       "S390SegMgr",
-        long_name:                        "S390 Segment Manager",
-        oem_name:                         "IBM",
+        short_name:                       EVMS_S390_PLUGIN_SHORT_NAME,
+        long_name:                        EVMS_S390_PLUGIN_LONG_NAME,
+        oem_name:                         EVMS_IBM_OEM_NAME,
 
         functions:                        {plugin: &sft},
 
