@@ -24,7 +24,7 @@
 #ifndef COMMIT_HEADER
 #define COMMIT_HEADER 1
 
-int  commit_390_partition_table(LOGICALDISK *ld, uint phase);
+int  commit_390_partition_table(LOGICALDISK *ld, DISKSEG *seg, uint phase, boolean backup);
 
 #endif
 
