@@ -24,9 +24,13 @@
 #define _390_DEV_MAPPER_HEADER_ 1
 
 int  s390_schedule_dm_rename( char *dm_name, storage_object_t *seg);
-              
+
+int  s390_can_activate( storage_object_t *object );
+
 int  s390_activate( storage_object_t *object );
 
+int  s390_can_deactivate( storage_object_t *object );
+
 int  s390_deactivate( storage_object_t *object );
 
 #endif
