@@ -212,7 +212,7 @@ static int snap_discover(list_anchor_t input_objects,
 	}
 
 	/* Look up the origin volume. */
-	org_child = find_origin(metadata->origin_volume);
+	org_child = find_origin((char *)metadata->origin_volume);
 	if (!org_child) {
 		goto error;
 	}
@@ -614,7 +614,7 @@ static void snap_set_volume(storage_object_t * object,
 	if (is_origin(volume) && creating) {
 		for (snap_volume = volume->next;
 		     snap_volume; snap_volume = snap_volume->next) {
-			strncpy(snap_volume->metadata->origin_volume,
+			strncpy((char *)snap_volume->metadata->origin_volume,
 				skip_dev_path(object->volume->name),
 				EVMS_VOLUME_NAME_SIZE);
 			schedule_for_commit(snap_volume);
