@@ -1455,9 +1455,7 @@ plugin_record_t template_plugin = {
 	 * ID number. OEM ID may be the IBM value, or select your own. See the
 	 * top-level PLUGIN.IDS file for more information.
 	 */
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_SEGMENT_MANAGER,
-			  10),
+	.id = EVMS_TEMPLATE_PLUGIN_ID,
 
 	/* MAJOR_VERSION, MINOR_VERSION, and PATCH_LEVEL are
 	 * defined in the plugin's Makefile.in.
@@ -1486,9 +1484,9 @@ plugin_record_t template_plugin = {
 		.minor		= 1,
 		.patchlevel	= 0
 	},
-	.short_name = "Template",
-	.long_name = "Template Segment Manager",
-	.oem_name = "IBM",
+	.short_name = EVMS_TEMPLATE_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_TEMPLATE_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.plugin = &template_functions
 	},
