@@ -1504,9 +1504,7 @@ static fsim_functions_t fsim_ops = {
 };
 
 plugin_record_t xfs_plugin_record = {
-	.id = SetPluginID(EVMS_OEM_IBM,
-			  EVMS_FILESYSTEM_INTERFACE_MODULE,
-			  FS_TYPE_XFS),
+	.id = EVMS_XFS_PLUGIN_ID,
 	.version = {
 		.major		= MAJOR_VERSION,
 		.minor		= MINOR_VERSION,
@@ -1524,9 +1522,9 @@ plugin_record_t xfs_plugin_record = {
 			.patchlevel	= 0
 		}
 	},
-	.short_name = "XFS",
-	.long_name = "XFS File System Interface Module",
-	.oem_name = "IBM",
+	.short_name = EVMS_XFS_PLUGIN_SHORT_NAME,
+	.long_name = EVMS_XFS_PLUGIN_LONG_NAME,
+	.oem_name = EVMS_IBM_OEM_NAME,
 	.functions = {
 		.fsim = &fsim_ops
 	},
