@@ -25,8 +25,6 @@ extern plugin_record_t xfs_plugin_record;
 extern plugin_record_t * my_plugin_record;
 extern engine_functions_t * EngFncs;
 
-/* File system ID ... used by the SetPluginID macro. */
-#define FS_TYPE_XFS 11
 
 /* fsck option array indices */
 #define FSCK_READONLY_INDEX		0
