@@ -1543,16 +1543,12 @@ static int Marginize(char * string, int indent_level, boolean indent_first_line)
   int col_width;
   int col = 0;
   int i;
+  int rc;
 
 
-  ioctl(1, TIOCGWINSZ, &ws);
-
-  if (ws.ws_col == 0) {
-    /* Set default column width if the ioctl fails. */
-    ws.ws_col = 80;
-  }
-
-  if (ws.ws_col < indent_level * 8) {
+  rc = ioctl(1, TIOCGWINSZ, &ws);
+  if (rc < 0 || ws.ws_col == 0) {
+    /* Fall back to default if ioctl fails. */
     return 0;
   }
 
