@@ -4,16 +4,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Module: fsutils.c
@@ -35,11 +35,11 @@
 /*
  *
  *   inline void add_fsim_name_to_filesys_op_clist (GtkCList *, gint, object_handle_t)
- *   
+ *
  *   Description:
  *      This routine updates the current row with the name of the
  *      FSIM associated with the given volume.
- * 
+ *
  *   Entry:
  *      clist  - address of the selections GtkCList widget
  *      row    - the row in the list to update
@@ -73,11 +73,11 @@ inline void add_fsim_name_to_filesys_op_clist(GtkCList * clist, gint row, object
 /*
  *
  *   inline void set_filesys_clist_properties (GtkCList *)
- *   
+ *
  *   Description:
  *      This routine sets some common properties about the
  *      file system operations clist.
- * 
+ *
  *   Entry:
  *      clist - address of the selections GtkCList widget
  *
@@ -95,11 +95,11 @@ inline void set_filesys_clist_properties(GtkCList * clist)
 /*
  *
  *   inline void add_volume_to_filesys_clist (GtkCList *, object_handle_t, gboolean)
- *   
+ *
  *   Description:
  *      This routine appends a new row to the file system operations
  *      clist with the name of a volume and its associated FSIM name.
- * 
+ *
  *   Entry:
  *      clist       - address of the selections GtkCList widget
  *      volume      - the volume's object handle
@@ -123,15 +123,15 @@ inline void add_volume_to_filesys_clist(GtkCList * clist, object_handle_t volume
 /*
  *
  *   void on_filesys_operation_clist_realize (GtkCList *, gpointer)
- *   
+ *
  *   Description:
  *      This routine populates the given GtkCList with the list
  *      of volumes that an FSIM associated with the volume says
- *      can either be fsck'd, defrag'd, or obliterated.
- * 
+ *      can either be fsck'd, or obliterated.
+ *
  *   Entry:
  *      clist     - address of the selections GtkCList widget
- *      user_data - contains the filesys_op_t FSCK, DEFRAG, or UNMKFS
+ *      user_data - contains the filesys_op_t FSCK, or UNMKFS
  *
  *   Exit:
  *      Selection list populated with volumes acceptable to the operation
@@ -159,9 +159,6 @@ void on_filesys_operation_clist_realize(GtkCList * clist, gpointer user_data)
 			case FSCK:
 				op_allowed = evms_can_fsck(volumes->handle[i]) == 0;
 				break;
-			case DEFRAG:
-				op_allowed = evms_can_defrag(volumes->handle[i]) == 0;
-				break;
 			case UNMKFS:
 				op_allowed = evms_can_unmkfs(volumes->handle[i]) == 0;
 				break;
@@ -187,11 +184,11 @@ void on_filesys_operation_clist_realize(GtkCList * clist, gpointer user_data)
 /*
  *
  *   void on_fsim_clist_realize (GtkWidget *, gpointer)
- *   
+ *
  *   Description:
  *      This routine populates the given GtkCList with the list
  *      of file system interface modules to choose from.
- * 
+ *
  *   Entry:
  *      widget    - address of the selections GtkCList widget
  *      user_data - contains task action code for action to use list
@@ -211,23 +208,22 @@ void on_fsim_clist_realize(GtkWidget * widget, gpointer user_data)
 /*
  *
  *   void on_initiate_filesys_operation_button_clicked (GtkButton *, gpointer)
- *   
- *   Description:
- *      This routine initiates either a defragmentation or checking/repairing
- *      operation on a file system located on the volume selected. It is also
- *      used by the context popup menu item that initiates a make file system
- *      on a volume.
  *
- *      In the case of defrag and fsck operations, our selection window has
- *      a list of volumes and the current selection is used to start the task.
- *      For a mkfs operation, the selection window has a list of FSIM plugins
- *      and the current selection is used to initiate the task. After the
- *      mkfs is started, we set the volume that initiated the operation as the
+ *   Description:
+ *      This routine initiates a checking/repairing operation on a file system
+ *      located on the volume selected.  It is also used by the context popup
+ *      menu item that initiates a make file system on a volume.
+ *
+ *      In the case of fsck operations, our selection window has a list of
+ *      volumes and the current selection is used to start the task.  For a
+ *      mkfs operation, the selection window has a list of FSIM plugins and
+ *      the current selection is used to initiate the task.  After the mkfs is
+ *      started, we set the volume that initiated the operation as the
  *      selected object.
- * 
+ *
  *   Entry:
  *      button    - the button that was clicked
- *      user_data - contains filesys_op_t value MKFS, DEFRAG or FSCK
+ *      user_data - contains filesys_op_t value MKFS, or FSCK
  *
  *   Exit:
  *      Nothing is returned but hopefully the options notebook
@@ -246,9 +242,7 @@ void on_initiate_filesys_operation_button_clicked(GtkButton * button, gpointer u
 	task_action_t filesys_task;
 	filesys_op_t opcode = GPOINTER_TO_UINT(user_data);
 
-	if (opcode == DEFRAG)
-		filesys_task = EVMS_Task_defrag;
-	else if (opcode == MKFS)
+	if (opcode == MKFS)
 		filesys_task = EVMS_Task_mkfs;
 	else
 		filesys_task = EVMS_Task_fsck;
@@ -296,12 +290,13 @@ void on_initiate_filesys_operation_button_clicked(GtkButton * button, gpointer u
 					       NULL, FALSE, selection_window);
 		} else {
 			if (opcode == MKFS) {
-				handle_array_t ha;
+				gchar mem[sizeof(handle_array_t) + sizeof(object_handle_t)];
+				handle_array_t * ha = (handle_array_t *) mem;
 
-				ha.count = 1;
-				ha.handle[0] = volume;
+				ha->count = 1;
+				ha->handle[0] = volume;
 
-				rc = evms_set_selected_objects(handle, &ha, NULL, NULL);
+				rc = evms_set_selected_objects(handle, ha, NULL, NULL);
 			}
 
 			if (rc != SUCCESS) {
@@ -329,9 +324,7 @@ void on_initiate_filesys_operation_button_clicked(GtkButton * button, gpointer u
 
 				button_text = get_task_action_string(handle);
 
-				if (opcode == DEFRAG)
-					window_title = _("Defragment File System - Options");
-				else if (opcode == MKFS)
+				if (opcode == MKFS)
 					window_title = _("Make File System - Options");
 				else
 					window_title = _("Check/Repair File System - Options");
@@ -380,11 +373,11 @@ void on_initiate_filesys_operation_button_clicked(GtkButton * button, gpointer u
 /*
  *
  *   void on_remove_filesys_button_clicked (GtkButton *, gpointer)
- *   
+ *
  *   Description:
  *      This routine initiates the removal of a file system located
  *      on the volume selected.
- * 
+ *
  *   Entry:
  *      button    - the button that was clicked
  *      user_data - not used
@@ -425,7 +418,7 @@ void on_remove_filesys_button_clicked(GtkButton * button, gpointer user_data)
  *   Description:
  *      This routine will display one volume in the filesys operation
  *      window's selection list.
- * 
+ *
  *   Entry:
  *      window - the filesys operation window id
  *      volume - the volume's object handle
@@ -452,7 +445,7 @@ inline void init_filesys_single_item_clist(GtkWidget * window, object_handle_t v
  *   Description:
  *      This routine will display the names of the FSIMs that have
  *      agreed they can make a file system on the volume supplied.
- * 
+ *
  *   Entry:
  *      window - the FSIM selection window id
  *      volume - the volume's object handle
@@ -501,7 +494,7 @@ inline void populate_clist_with_fsims_for_volume(GtkWidget * window, object_hand
  *      This routine will display the volume containing the file system
  *      we intend to fsck and allow the user to confirm the checking of
  *      the file system.
- * 
+ *
  *   Entry:
  *      menuitem  - the menuitem that initiated the action
  *      user_data - volume's object handle
@@ -526,39 +519,6 @@ void on_fsck_popup_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data
 	gtk_widget_show(window);
 }
 
-/*
- *
- *   void on_defrag_popup_menu_item_activate (GtkMenuItem *, gpointer)
- *
- *   Description:
- *      This routine will display the volume containing the file system
- *      we intend to defrag and allow the user to confirm the defragmenting
- *      of the file system.
- * 
- *   Entry:
- *      menuitem  - the menuitem that initiated the action
- *      user_data - volume's object handle
- *
- *   Exit:
- *      See description.
- *
- */
-void on_defrag_popup_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data)
-{
-	GtkWidget *window;
-
-	window = create_standard_selection_window(_("Defragment File System"),
-						  NULL,
-						  get_defrag_help_text(),
-						  NULL,
-						  on_initiate_filesys_operation_button_clicked,
-						  NULL, NULL, NULL, NULL, GUINT_TO_POINTER(DEFRAG));
-
-	init_filesys_single_item_clist(window, GPOINTER_TO_UINT(user_data));
-
-	gtk_widget_show(window);
-}
-
 /*
  *
  *   void on_mkfs_popup_menu_item_activate (GtkMenuItem *, gpointer)
@@ -566,7 +526,7 @@ void on_defrag_popup_menu_item_activate(GtkMenuItem * menuitem, gpointer user_da
  *   Description:
  *      This routine will display the FSIMs that agreed that they could
  *      make a file system on the volume that initiated this action.
- * 
+ *
  *   Entry:
  *      menuitem  - the menuitem that initiated the action
  *      user_data - volume's object handle
@@ -608,7 +568,7 @@ void on_mkfs_popup_menu_item_activate(GtkMenuItem * menuitem, gpointer user_data
  *      This routine will display the volume containing the file system
  *      we intend to unmkfs and allow the user to confirm the removal
  *      of the file system.
- * 
+ *
  *   Entry:
  *      menuitem  - the menuitem that initiated the action
  *      user_data - volume's object handle
@@ -640,7 +600,7 @@ void on_unmkfs_popup_menu_item_activate(GtkMenuItem * menuitem, gpointer user_da
  *   Description:
  *      This routine checks to see if the volume has an associated
  *      FSIM and returns TRUE if it does.
- * 
+ *
  *   Entry:
  *      volume - volume's object handle
  *
@@ -673,7 +633,7 @@ gboolean volume_has_fsim(object_handle_t volume)
  *   Description:
  *      This routine checks to see if any FSIM can mkfs it
  *      and if so returns TRUE.
- * 
+ *
  *   Entry:
  *      volume - volume's object handle
  *
