@@ -4,16 +4,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Module: readable.c
@@ -37,7 +37,7 @@
  *   Description:
  *      This routine takes a data type code and returns
  *      the string description of the data type.
- * 
+ *
  *   Entry:
  *      type - data type enumeration value
  *
@@ -75,10 +75,10 @@ inline gchar *make_data_type_readable_string(data_type_t type)
  *
  *   Description:
  *      This routine takes a value unit type code and returns
- *      the string description of the data type. The caller can 
+ *      the string description of the data type. The caller can
  *      request a short form if available, i.e. "KB" instead of
  *      "kilobytes".
- * 
+ *
  *   Entry:
  *      unit           - unit measurement enumeration value
  *      use_short_form - TRUE if a condensed version is preferred
@@ -159,10 +159,10 @@ inline gchar *make_unit_readable_string(value_unit_t unit, gboolean use_short_fo
  *   Description:
  *      This routine takes a size in sectors and returns the
  *      size as a string representation in either TB, GB,
- *      MB, KB, or bytes. The dynamically allocated string 
- *      should be freed by the caller with g_free() when no 
+ *      MB, KB, or bytes. The dynamically allocated string
+ *      should be freed by the caller with g_free() when no
  *      longer needed.
- * 
+ *
  *   Entry:
  *      size_in_sectors - the size in 512 byte sector units
  *      unit            - address to write new unit measurement
@@ -208,7 +208,7 @@ inline gchar *make_sectors_readable_size_string(u_int64_t size_in_sectors, value
  *   Description:
  *      This routine takes a size string value and generates
  *      a new string with the unit measurement appended to it.
- * 
+ *
  *   Entry:
  *      size_string - the size value already converted to a string
  *      unit        - the size's unit measurement
@@ -242,10 +242,10 @@ inline gchar *make_size_readable_string(gchar * size_string, value_unit_t unit)
  *   Description:
  *      This routine takes a size in sectors and returns the
  *      size as a string representation in either TB, GB,
- *      MB, KB, or bytes. The dynamically allocated string 
- *      should be freed by the caller with g_free() when no 
+ *      MB, KB, or bytes. The dynamically allocated string
+ *      should be freed by the caller with g_free() when no
  *      longer needed.
- * 
+ *
  *   Entry:
  *      size_in_sectors - the size in 512 byte sector units
  *
@@ -280,10 +280,10 @@ inline gchar *make_sectors_readable_string(u_int64_t size_in_sectors)
  *   Description:
  *      This routine takes a size in kilobytes and returns the
  *      size as a string representation in either TB, GB,
- *      MB, or KB. The dynamically allocated string 
- *      should be freed by the caller with g_free() when no 
+ *      MB, or KB. The dynamically allocated string
+ *      should be freed by the caller with g_free() when no
  *      longer needed.
- * 
+ *
  *   Entry:
  *      size_in_kbytes - the size in kbytes
  *
@@ -304,9 +304,9 @@ inline gchar *make_kbytes_readable_string(u_int64_t size_in_kbytes)
  *   Description:
  *      This routine takes an object handle and returns
  *      its given name and also the short name of its
- *      plugin. If the handle is for a plugin, the 
+ *      plugin. If the handle is for a plugin, the
  *      object_name will be the long descriptive name.
- * 
+ *
  *   Entry:
  *      handle      - handle to the object
  *      object_name - address to store pointer to dynamically allocated object name
@@ -376,9 +376,9 @@ inline void get_object_and_plugin_names(object_handle_t handle, gchar ** object_
  *
  *   Description:
  *      This routine takes an object handle and returns
- *      its given name. If the handle is for a plugin, the 
+ *      its given name. If the handle is for a plugin, the
  *      object_name will be the long descriptive name.
- * 
+ *
  *   Entry:
  *      handle - handle to the object
  *
@@ -386,7 +386,7 @@ inline void get_object_and_plugin_names(object_handle_t handle, gchar ** object_
  *      Returns a dynamically allocated string that contains
  *      the objects name. The caller should call g_free() to
  *      free the memory once it is no longer needed. NULL
- *      is returned if an error retrieving the name was 
+ *      is returned if an error retrieving the name was
  *      encountered.
  *
  */
@@ -437,7 +437,7 @@ inline gchar *get_object_name(object_handle_t handle)
  *   Description:
  *      This routine takes a object type code and returns
  *      the string description of the object type.
- * 
+ *
  *   Entry:
  *      type - data type enumeration value
  *
@@ -490,9 +490,9 @@ inline gchar *make_object_type_readable_string(object_type_t type)
  *      This routine retrieves the shortname of the
  *      plugin identified as the filesystem interface
  *      manager for the volume supplied.
- * 
+ *
  *   Entry:
- *      volume - address of the logical_volume_info_t 
+ *      volume - address of the logical_volume_info_t
  *
  *   Exit:
  *      Returns a dynamically allocated string
@@ -531,14 +531,14 @@ inline gchar *get_volume_fsim_name(logical_volume_info_t * volume)
  *   Description:
  *      This routine takes an plugin handle and returns
  *      its given short name.
- * 
+ *
  *   Entry:
  *      plugin_handle - handle to the plugin
  *
  *   Exit:
  *      Returns a dynamically allocated string that contains
  *      the plugin short name. The caller should call g_free() to
- *      free the memory once it is no longer needed. 
+ *      free the memory once it is no longer needed.
  *
  */
 inline gchar *get_plugin_name(plugin_handle_t plugin_handle)
@@ -571,7 +571,7 @@ inline gchar *get_plugin_name(plugin_handle_t plugin_handle)
  *   Description:
  *      This routine takes a plugin type code and returns
  *      the string description of the plugin type.
- * 
+ *
  *   Entry:
  *      type      - the plugin type
  *      lowercase - TRUE if all words in the description should be lowercase
@@ -666,8 +666,8 @@ gchar *object_flags_to_string(u_int32_t flags)
 
 	gstring = g_string_new("");
 
-	if (flags & SOFLAG_ACTIVE) {
-		if (flags & SOFLAG_NEEDS_ACTIVATE)
+	if (flags & SOFLAG_NEEDS_ACTIVATE) {
+		if (flags & SOFLAG_ACTIVE)
 			gstring = g_string_append(gstring, _("Re-activation"));
 	} else if (flags & SOFLAG_NEEDS_ACTIVATE) {
 		gstring = g_string_append(gstring, _("Activation"));
@@ -682,7 +682,7 @@ gchar *object_flags_to_string(u_int32_t flags)
 	if ((flags & SOFLAG_DIRTY) || (flags & SOFLAG_FEATURE_HEADER_DIRTY)) {
 		if (*(gstring->str) != '\0')
 			gstring = g_string_append_c(gstring, ',');
-		gstring = g_string_append(gstring, _("Dirty"));
+		gstring = g_string_append(gstring, _("Modified"));
 	}
 
 	if (flags & SOFLAG_NEW) {
@@ -713,7 +713,7 @@ gchar *container_flags_to_string(u_int32_t flags)
 	gstring = g_string_new("");
 
 	if (flags & SCFLAG_DIRTY) {
-		gstring = g_string_append(gstring, _("Dirty"));
+		gstring = g_string_append(gstring, _("Modified"));
 	}
 
 	if (flags & SCFLAG_NEW) {
@@ -743,8 +743,8 @@ gchar *volume_flags_to_string(u_int32_t flags)
 
 	gstring = g_string_new("");
 
-	if (flags & VOLFLAG_ACTIVE) {
-		if (flags & VOLFLAG_NEEDS_ACTIVATE)
+	if (flags & VOLFLAG_NEEDS_ACTIVATE) {
+		if (flags & VOLFLAG_ACTIVE)
 			gstring = g_string_append(gstring, _("Re-activation"));
 	} else {
 		gstring = g_string_append(gstring, _("Activation"));
@@ -756,10 +756,10 @@ gchar *volume_flags_to_string(u_int32_t flags)
 		gstring = g_string_append(gstring, _("Deactivation"));
 	}
 
-	if (flags & VOLFLAG_DIRTY) {
+	if (flags & (VOLFLAG_DIRTY | VOLFLAG_FEATURE_HEADER_DIRTY)) {
 		if (*(gstring->str) != '\0')
 			gstring = g_string_append_c(gstring, ',');
-		gstring = g_string_append(gstring, _("Dirty"));
+		gstring = g_string_append(gstring, _("Modified"));
 	}
 
 	if (flags & VOLFLAG_NEW) {
@@ -786,12 +786,6 @@ gchar *volume_flags_to_string(u_int32_t flags)
 		gstring = g_string_append(gstring, _("Unmkfs"));
 	}
 
-	if (flags & VOLFLAG_DEFRAG) {
-		if (*(gstring->str) != '\0')
-			gstring = g_string_append_c(gstring, ',');
-		gstring = g_string_append(gstring, _("Defragment"));
-	}
-
 	if (flags & VOLFLAG_PROBE_FS) {
 		if (*(gstring->str) != '\0')
 			gstring = g_string_append_c(gstring, ',');
@@ -844,13 +838,13 @@ gchar *changes_flag_to_string(u_int32_t flags)
 	if (flags & CHANGE_DIRTY) {
 		if (*(gstring->str) != '\0')
 			gstring = g_string_append_c(gstring, ',');
-		gstring = g_string_append(gstring, _("Dirty"));
+		gstring = g_string_append(gstring, _("Modified"));
 	}
 
 	if (flags & CHANGE_FEATURE_HEADER_DIRTY) {
 		if (*(gstring->str) != '\0')
 			gstring = g_string_append_c(gstring, ',');
-		gstring = g_string_append(gstring, _("Feature Header Dirty"));
+		gstring = g_string_append(gstring, _("Feature Header Modified"));
 	}
 
 	if (flags & CHANGE_EXPAND) {
@@ -883,12 +877,6 @@ gchar *changes_flag_to_string(u_int32_t flags)
 		gstring = g_string_append(gstring, _("Unmkfs"));
 	}
 
-	if (flags & CHANGE_DEFRAG) {
-		if (*(gstring->str) != '\0')
-			gstring = g_string_append_c(gstring, ',');
-		gstring = g_string_append(gstring, _("Defragment"));
-	}
-
 	if (flags & CHANGE_DELETE) {
 		if (*(gstring->str) != '\0')
 			gstring = g_string_append_c(gstring, ',');
