@@ -2168,8 +2168,8 @@ gint create_task(engine_handle_t handle, task_action_t action,
 		 task_requirements_t * requirements, task_handle_t * task)
 {
 	gint rc;
-	gint objects_min;
-	gint objects_max;
+	guint objects_min;
+	guint objects_max;
 	gint option_count;
 
 	*requirements = TASK_REQUIREMENTS_UNKNOWN;
