@@ -4,16 +4,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  * Module: value.c
@@ -23,6 +23,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <limits.h>
+#include <locale.h>
 #include <frontend.h>
 #include <gtk/gtk.h>
 
@@ -424,7 +425,7 @@ gint convert_string_to_value(gchar * string, value_type_t type, gint maxlen, val
  *
  *   Description:
  *      This routine creates a value list. If the list is
- *      a list of string types then it also allocates 
+ *      a list of string types then it also allocates
  *      string buffers of the given size + 1.
  *
  *   Entry:
@@ -440,7 +441,7 @@ value_list_t *allocate_value_list(guint count, value_type_t type, guint size)
 {
 	value_list_t *vlist;
 
-	vlist = g_malloc0(sizeof(value_list_t) + ((count - 1) * sizeof(value_t)));
+	vlist = g_malloc0(sizeof(value_list_t) + (count * sizeof(value_t)));
 
 	if (type == EVMS_Type_String) {
 		guint i;
@@ -477,7 +478,7 @@ value_list_t *allocate_value_list(guint count, value_type_t type, guint size)
  *      target_value - address of value_t to store duplicated contents
  *
  *   Exit:
- *      The source value is copied to the target and strings 
+ *      The source value is copied to the target and strings
  *      and lists are duplicated as necessary.
  *
  */
@@ -505,7 +506,7 @@ void duplicate_value(value_t source_value, value_type_t type, gboolean is_list,
 		} else {
 			target_value->list = g_memdup(source_value.list,
 						      (sizeof(value_list_t) +
-						       (list_count * (sizeof(value_t) - 1))));
+						       (list_count * sizeof(value_t))));
 		}
 	} else if (type == EVMS_Type_String) {
 		target_value->s = g_malloc(maxlen);
@@ -996,7 +997,7 @@ gchar *convert_sector_value_to_new_unit_string(value_t value, value_type_t type,
  *                 a unit measurement
  *
  *   Exit:
- *      Returns the value_unit_t type corresponding to the unit of 
+ *      Returns the value_unit_t type corresponding to the unit of
  *      measurement the string represents.
  *
  */
@@ -1129,7 +1130,7 @@ value_unit_t select_readable_unit_for_sector_value(value_t value, value_type_t t
 
 /*
  *
- *   void convert_size_value_to_sector_value (value_t, value_type_t, value_unit_t, 
+ *   void convert_size_value_to_sector_value (value_t, value_type_t, value_unit_t,
  *                                            value_t *, value_type_t)
  *
  *   Description:
@@ -1214,7 +1215,7 @@ void convert_size_value_to_sector_value(value_t size_value, value_type_t size_ty
  *      size  - the sector unit size as a real number
  *      type  - the type of the sector value, e.g. EVMS_Type_Int64
  *      unit  - the unit of the size, e.g. KB, TB, etc.
- *      value - address to write sector value to 
+ *      value - address to write sector value to
  *
  *   Exit:
  *      Returns the size real number converted to a sector unit value
@@ -1279,7 +1280,7 @@ void convert_float_to_sector_value(gfloat size, value_type_t type, value_unit_t
  *      string    - the string containing a size, i.e. "10 MB" or "1.4GB"
  *      unit      - unit of value (superseded if unit mnemonic found)
  *      type_out  - value_type_t to convert the value to on return
- *      value_out - address to write sector value to 
+ *      value_out - address to write sector value to
  *
  *   Exit:
  *      Returns the size converted to a sector unit value.
@@ -1295,18 +1296,28 @@ void convert_size_string_to_sector_value(gchar * string, value_unit_t unit, valu
 		gchar *number;
 		value_t value_in;
 		value_type_t type_in;
+		struct lconv * locale_conv = localeconv();
+		char decimal_point = '.';
+
+		if (locale_conv != NULL) {
+			if (locale_conv->decimal_point != NULL) {
+				if (*locale_conv->decimal_point != '\0') {
+					decimal_point = *locale_conv->decimal_point;
+				}
+			}
+		}
 
 		/*
-		 * Copy digits, blank space and '.' to temp string until we hit an
-		 * alpha character.
+		 * Copy digits, blank space and decimal point to temp string
+		 * until we hit an alpha character.
 		 */
 
 		number = g_malloc(strlen(string) + 1);
 		type_in = EVMS_Type_Unsigned_Int64;
 		value_in.i64 = 0;
 
-		while (*string && (isdigit(*string) || *string == '.' || isspace(*string))) {
-			if (*string == '.')
+		while (*string && (isdigit(*string) || *string == decimal_point || isspace(*string))) {
+			if (*string == decimal_point)
 				type_in = EVMS_Type_Real64;
 
 			number[length] = *string;
@@ -1392,7 +1403,7 @@ gchar *convert_value_to_string_with_unit(value_t value, value_type_t type, value
  *      type          - the id of the data type
  *      unit          - the value unit measurement
  *      format        - the format for the the display value
- *      ok_to_convert - TRUE if we are allowed to convert 
+ *      ok_to_convert - TRUE if we are allowed to convert
  *                      the value to something more readable
  *
  *   Exit:
@@ -1519,6 +1530,8 @@ gint validate_numeric_string_characters(gchar * string)
 gchar *validate_string_as_numeric_value(gchar * string, value_type_t type)
 {
 	gchar *msg = NULL;
+	gchar *number_buffer1;
+	gchar *number_buffer2;
 
 	if (type >= EVMS_Type_Int && type <= EVMS_Type_Unsigned_Int64) {
 		gint rc = SUCCESS;
@@ -1580,16 +1593,22 @@ gchar *validate_string_as_numeric_value(gchar * string, value_type_t type)
 				break;
 
 			case EVMS_Type_Int64:
+				number_buffer1 = g_strdup_printf("%"PRId64, INT64_MIN);
+				number_buffer2 = g_strdup_printf("%"PRId64, INT64_MAX);
 				msg =
 				    g_strdup_printf(_
-						    ("Valid values are %" PRId64 " to %" PRId64
-						     "."), INT64_MIN, INT64_MAX);
+						    ("Valid values are %s to %s."),
+						    number_buffer1, number_buffer2);
+				g_free(number_buffer1);
+				g_free(number_buffer2);
 				break;
 
 			case EVMS_Type_Unsigned_Int64:
+				number_buffer1 = g_strdup_printf("%"PRIu64, UINT64_MAX);
 				msg =
-				    g_strdup_printf(_("Valid values are %u to %" PRIu64 "."), 0,
-						    UINT64_MAX);
+				    g_strdup_printf(_("Valid values are %u to %s."), 0,
+						    number_buffer1);
+				g_free(number_buffer1);
 				break;
 
 			default:
