@@ -21,6 +21,8 @@
 
 #include <frontend.h>
 #include <gtk/gtk.h>
+#include <string.h>
+#include <mntent.h>
 
 #include "support.h"
 #include "add.h"
@@ -1707,6 +1709,52 @@ void on_set_mount_options_button_clicked(GtkButton * button, GtkWidget * mount_w
 	gtk_widget_show(options_window);
 }
 
+/*
+ *
+ *   void set_default_mount_point (GtkWidget *, gpointer)
+ *
+ *   Description:
+ *      This looks up the name of the volume (gpointer is that volume handle) in
+ *      /etc/fstab to see if there is a defualt mount point for the volume.  If
+ *      the volume is found in /etc/fstab, the widget is set to the mount point.
+ *
+ *   Entry:
+ *      mount_directory_entry - GtkWidget for the mount directory name
+ *      user_data             - volume handle
+ *
+ *   Exit:
+ *      Sets mount_directory_entry if volume found in /etc/fstab.
+ *
+ */
+void set_default_mount_point(GtkWidget * mount_directory_entry, gpointer user_data)
+{
+	char *volume_name;
+	FILE *mount_records;
+	struct mntent *mount_entry;
+
+	volume_name = get_object_name(GPOINTER_TO_UINT(user_data));
+
+	if (volume_name != NULL) {
+		mount_records = setmntent("/etc/fstab", "r");
+
+		if (mount_records != NULL) {
+
+			/* Scan the mount entries to see if this volume is listed. */
+			while ((mount_entry = getmntent(mount_records)) != NULL) {
+				if (strcmp(mount_entry->mnt_fsname, volume_name) == 0) {
+					gtk_entry_set_text(GTK_ENTRY(mount_directory_entry), mount_entry->mnt_dir);
+					break;
+				}
+			}
+
+			/* Close the stream. */
+			endmntent(mount_records);
+		}
+
+		g_free(volume_name);
+	}
+}
+
 /*
  *
  *   GtkWidget *create_mount_operation_window (GtkSignalFunc, gpointer)
@@ -1764,6 +1812,8 @@ GtkWidget *create_mount_operation_window(gchar * title, gchar * verb,
 	gtk_label_set_text(GTK_LABEL(next_button_label), verb);
 	gtk_label_set_text(GTK_LABEL(label), _("Mount Point"));
 
+	set_default_mount_point(mount_directory_entry, user_data);
+
 	/*
 	 * Change the prev button to be the button to set the mount options
 	 */
