@@ -4,19 +4,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
- */ 
+ */
 
 gboolean volume_has_fsim(object_handle_t volume);
 gboolean can_volume_be_formatted(object_handle_t volume);
@@ -26,5 +26,3 @@ int context_mkfs_menuitem_activated(struct menu_item *item);
 int actions_mkfs_menuitem_activated(struct menu_item *item);
 int context_unmkfs_menuitem_activated(struct menu_item *item);
 int actions_unmkfs_menuitem_activated(struct menu_item *item);
-int context_defrag_menuitem_activated(struct menu_item *item);
-int actions_defrag_menuitem_activated(struct menu_item *item);
