@@ -4,19 +4,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
- */ 
+ */
 
 #include <stdlib.h>
 #include <string.h>
@@ -56,6 +56,8 @@
 #include "save.h"
 #include "callbacks.h"
 #include "logging.h"
+#include "activation.h"
+#include "backup.h"
 
 static WINDOW *menubar;
 static WINDOW *statusbar;
@@ -63,7 +65,7 @@ static WINDOW *statusbar;
 static struct menu_item menubar_item[MENUBAR_ITEM_COUNT];
 
 /**
- *	Since we don't destroy the action menues once created, we keep
+ *	Since we don't destroy the action menus once created, we keep
  *	track of their popup_menu structures created here so we can
  *	show or hide them as necessary.
  */
@@ -71,6 +73,7 @@ static struct popup_menu *actions_menu = NULL;
 static struct popup_menu *settings_menu = NULL;
 static struct popup_menu *create_menu = NULL;
 static struct popup_menu *delete_menu = NULL;
+static struct popup_menu *activation_menu = NULL;
 static struct popup_menu *expand_menu = NULL;
 static struct popup_menu *shrink_menu = NULL;
 static struct popup_menu *add_menu = NULL;
@@ -86,7 +89,7 @@ static struct popup_menu *fsys_menu = NULL;
  *	get_accel_color - return the attribute/color for the accelerator character in a menu
  *	@win: the window that contains the menu
  *
- *	This routine returns the proper color attribute for a menu depending on if the 
+ *	This routine returns the proper color attribute for a menu depending on if the
  *	current color pair is for a selected menu item or the normal menu background.
  */
 chtype get_accel_color(WINDOW *win)
@@ -142,7 +145,7 @@ void print_menu_item(WINDOW *win, int starty, int startx, struct menu_item *item
  *	get_accelerator_char - retrieves the accelerator character from menu label
  *	@label: the label containing the accelerator character
  *
- *	This routine scans the the string for the '_' character and then uses the
+ *	This routine scans the string for the '_' character and then uses the
  *	following character as the accelerator character. '\0' is returned if the
  *	label does not contain an accelerator character.
  */
@@ -243,7 +246,7 @@ void delete_menu_item(struct menu_item *item, struct popup_menu *menu)
  *	@item: the menu item
  *	@activate_cb: the function to invoke when a menu item is activated
  *
- *	This routine is used to set the menu item activation callback. This allows a 
+ *	This routine is used to set the menu item activation callback. This allows a
  *	activation callback to be changed as needed (such as to replace the default).
  */
 inline void set_menu_item_activate_cb(struct menu_item *item, menuitem_activate_cb activate_cb)
@@ -378,7 +381,7 @@ int translate_key(GList *items, int key, GList **focus_item)
 	element = items;
 	while (element != NULL) {
 		item = element->data;
-		if (MI_IS_SENSITIVE(item->flags) && 
+		if (MI_IS_SENSITIVE(item->flags) &&
 				(tolower(item->accel) == tolower(key))) {
 			key = KEY_ENTER;
 			*focus_item = element;
@@ -418,7 +421,7 @@ int show_about_box(struct menu_item *item)
 
 	menu = create_horizontal_menu(win, getmaxx(win) - 4, getmaxy(win) - 2, 1, 1);
 	pack_menu_item_at_end(menu, _("[OK]"), get_accelerator_char(_("[_OK]")),
-					(menuitem_activate_cb)ok_button_activated, 
+					(menuitem_activate_cb)ok_button_activated,
 					NULL);	
 	draw_horizontal_menu(menu);
 	show_popup_window(panel);
@@ -491,7 +494,7 @@ int process_menubar_events(int key)
  *	@void
  *
  *	This routine creates the main window menubar that is used to
- *	access the general dropdown action menues.
+ *	access the general dropdown action menus.
  */
 void draw_menubar(void)
 {
@@ -669,7 +672,7 @@ int get_max_label_width(GList *element)
  *	@startx: the starting column to place the window
  *
  *	This routine creates a panel window sized to the width of the
- *	longest label in the linked list of menu items. The panel of the 
+ *	longest label in the linked list of menu items. The panel of the
  *	created menu is then set in the popup_menu struct.
  */
 inline void create_menu_panel(struct popup_menu *menu, int starty, int startx)
@@ -726,13 +729,13 @@ void highlight_current_menuitem(struct popup_menu *menu, int width)
 }
 
 /**
- *	hide_parent_menues - hides the menu and all its parent menues
+ *	hide_parent_menus - hides the menu and all its parent menus
  *	@menu: the initial menu to hide
  *
  *	This routine hides the given menu and if its a submenu, hides
  *	any parent menu as well.
  */
-inline void hide_parent_menues(struct popup_menu *menu)
+inline void hide_parent_menus(struct popup_menu *menu)
 {
 	struct popup_menu *curr_menu;
 
@@ -795,7 +798,7 @@ int process_menu_events(struct popup_menu *menu)
 					highlight_current_menuitem(menu, width);
 				} else {
 					print_statusbar_text("");
-					hide_parent_menues(menu);
+					hide_parent_menus(menu);
 				}
 				if (curr_item->activate_cb != NULL) {
 					rc = curr_item->activate_cb(curr_item);
@@ -824,7 +827,7 @@ int process_menu_events(struct popup_menu *menu)
  *	calculate_menu_item_offsets_from_start - calculate the offsets for items in a horiz menu from start
  *	@menu: the horizontal menu
  *
- *	This routine calculates the starting offsets for each menu item label in a 
+ *	This routine calculates the starting offsets for each menu item label in a
  *	horizontal menu. We expect that the first item in the list was just added and
  *	the we set it's offset to 0 and ensure that the next item over and on are at
  *	least menu->spacing from each other. Otherwise, we make the necessary adjustments.
@@ -872,7 +875,7 @@ inline void calculate_menu_item_offsets_from_start(struct horizontal_menu *menu)
  *	calculate_menu_item_offsets_from_end - calculate the offsets for items in a horiz menu from end
  *	@menu: the horizontal menu
  *
- *	This routine calculates the starting offsets for each menu item label in a 
+ *	This routine calculates the starting offsets for each menu item label in a
  *	horizontal menu. It places the last element in the list of menu items at an offset
  *	where it is to rightmost of the menu.
  *
@@ -907,7 +910,7 @@ inline void calculate_menu_item_offsets_from_end(struct horizontal_menu *menu)
 			} else {
 				/*
 				 * There is sufficient spacing between current
-				 * and previous menu item so stop processing 
+				 * and previous menu item so stop processing
 				 */
 				element = NULL;
 			}
@@ -997,10 +1000,10 @@ inline void set_horizontal_menu_focus(struct horizontal_menu *menu, struct menu_
  *
  *	This routine creates a menu with the menu items on the same. The menu items
  *	are navigated with the left or right arrow key, cycled with the TAB key or
- *	activated with an ENTER or accelerator key. Items are either packed at the 
+ *	activated with an ENTER or accelerator key. Items are either packed at the
  *	end or the start of the menu row.
  */
-struct horizontal_menu *create_horizontal_menu(WINDOW *parent_win, int width, int starty, 
+struct horizontal_menu *create_horizontal_menu(WINDOW *parent_win, int width, int starty,
 						int startx, int spacing)
 {
 	struct horizontal_menu *menu;
@@ -1196,9 +1199,9 @@ int process_horizontal_menu_events(struct horizontal_menu *menu, int *key)
  */
 inline void append_create_menu_items(void)
 {
-	append_menu_item(create_menu, _("EVMS Volume..."), 
+	append_menu_item(create_menu, _("EVMS Volume..."),
 				_("Create an EVMS native volume"),
-				get_accelerator_char(_("_EVMS Volume...")), FALSE, 
+				get_accelerator_char(_("_EVMS Volume...")), FALSE,
 				(menuitem_activate_cb)actions_create_evms_vol_menuitem_activated, NULL);
 
 	append_menu_item(create_menu, _("Compatibility Volume..."),
@@ -1206,7 +1209,7 @@ inline void append_create_menu_items(void)
 				get_accelerator_char(_("Compatibility _Volume...")), FALSE,
 				(menuitem_activate_cb)actions_create_vol_menuitem_activated, NULL);
 
-	append_menu_item(create_menu, _("Feature Object..."), 
+	append_menu_item(create_menu, _("Feature Object..."),
 				_("Create a native EVMS Feature Object"),
 				get_accelerator_char(_("_Feature Object...")), FALSE,
 				(menuitem_activate_cb)create_feature_menuitem_activated, NULL);
@@ -1248,7 +1251,7 @@ void draw_create_menu(void)
  *
  *	This routine is a callback routine invoked when the "Create" menu item
  *	in the "Actions" menu is selected. It draws the "Create" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int create_menuitem_activated(struct menu_item *item)
 {
@@ -1273,7 +1276,7 @@ inline void append_delete_menu_items(void)
 				GUINT_TO_POINTER(VOLUME));
 
 	append_menu_item(delete_menu, _("Storage Object..."), _("Delete a Storage Object"),
-				get_accelerator_char(_("_Storage Object...")), FALSE, 
+				get_accelerator_char(_("_Storage Object...")), FALSE,
 				(menuitem_activate_cb)actions_delete_menuitem_activated,
 				GUINT_TO_POINTER(EVMS_OBJECT));
 
@@ -1307,7 +1310,7 @@ void draw_delete_menu(void)
  *
  *	This routine is a callback routine invoked when the "Delete" menu item
  *	in the "Actions" menu is selected. It draws the "Delete" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int delete_menuitem_activated(struct menu_item *item)
 {
@@ -1318,6 +1321,60 @@ int delete_menuitem_activated(struct menu_item *item)
 	return rc;
 }
 
+/**
+ *	append_activation_menu_items - appends the "Activation" menu items
+ *	@void
+ *
+ *	This routine appends the menu items for the "Activation" menu.
+ */
+inline void append_activation_menu_items(void)
+{
+	append_menu_item(activation_menu, _("Activate..."), _("Activate a Logical Volume or Storage Object"),
+				get_accelerator_char(_("_Activate...")), FALSE,
+				(menuitem_activate_cb)actions_activate_menuitem_activated,
+				NULL);
+
+	append_menu_item(activation_menu, _("Deactivate..."), _("Deactivate a Logical Volume or Storage Object"),
+				get_accelerator_char(_("_Deactivate...")), FALSE,
+				(menuitem_activate_cb)actions_deactivate_menuitem_activated,
+				NULL);
+}
+
+/**
+ *	draw_activation_menu - draws the "Activation" submenu
+ *	@void
+ *
+ *	This routine displays the "Activation" pulldown submenu. It gets
+ *	placed next to the main "Actions" pulldown menu.
+ */
+void draw_activation_menu(void)
+{
+	if (activation_menu == NULL) {
+		activation_menu = create_popup_menu();
+		append_activation_menu_items();
+		create_menu_panel(activation_menu, 0, 0);
+		cascade_menu(activation_menu, actions_menu, ACTIVATION_MENUITEM);
+	}
+	show_panel_window(activation_menu->panel, TRUE);
+}
+
+/**
+ *	activation_menuitem_activated - function invoked when "Activation" menu item activated
+ *	@item: the menu item that caused this function to get invoked
+ *
+ *	This routine is a callback routine invoked when the "Activation" menu item
+ *	in the "Actions" menu is selected. It draws the "Activation" pulldown submenu
+ *	and processes menu events.
+ */
+int activation_menuitem_activated(struct menu_item *item)
+{
+	int rc;
+
+	draw_activation_menu();
+	rc = process_menu_events(activation_menu);
+	return rc;
+}
+
 /**
  *	append_expand_menu_items - appends the "Expand" menu items
  *	@void
@@ -1363,7 +1420,7 @@ void draw_expand_menu(void)
  *
  *	This routine is a callback routine invoked when the "Expand" menu item
  *	in the "Actions" menu is selected. It draws the "Expand" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int expand_menuitem_activated(struct menu_item *item)
 {
@@ -1382,7 +1439,7 @@ int expand_menuitem_activated(struct menu_item *item)
  */
 inline void append_shrink_menu_items(void)
 {
-	append_menu_item(shrink_menu, _("Volume..."), 
+	append_menu_item(shrink_menu, _("Volume..."),
 				_("Reduce the storage size of a Logical Volume"),
 				get_accelerator_char(_("_Volume...")), FALSE,
 				(menuitem_activate_cb)actions_shrink_volume_menuitem_activated, NULL);
@@ -1422,7 +1479,7 @@ void draw_shrink_menu(void)
  *
  *	This routine is a callback routine invoked when the "Shrink" menu item
  *	in the "Actions" menu is selected. It draws the "Shrink" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int shrink_menuitem_activated(struct menu_item *item)
 {
@@ -1477,7 +1534,7 @@ void draw_add_menu(void)
  *
  *	This routine is a callback routine invoked when the "Add" menu item
  *	in the "Actions" menu is selected. It draws the "Add" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int add_menuitem_activated(struct menu_item *item)
 {
@@ -1535,7 +1592,7 @@ void draw_remove_menu(void)
  *
  *	This routine is a callback routine invoked when the "Remove" menu item
  *	in the "Actions" menu is selected. It draws the "Remove" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int remove_menuitem_activated(struct menu_item *item)
 {
@@ -1594,7 +1651,7 @@ void draw_modify_menu(void)
  *
  *	This routine is a callback routine invoked when the "Modify" menu item
  *	in the "Actions" menu is selected. It draws the "Modify" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int modify_menuitem_activated(struct menu_item *item)
 {
@@ -1643,7 +1700,7 @@ void draw_view_menu(void)
  *
  *	This routine is a callback routine invoked when the "View" menu item
  *	in the "Actions" menu is selected. It draws the "View" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int view_menuitem_activated(struct menu_item *item)
 {
@@ -1701,7 +1758,7 @@ void draw_convert_menu(void)
  *
  *	This routine is a callback routine invoked when the "Convert" menu item
  *	in the "Actions" menu is selected. It draws the "Convert" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int convert_menuitem_activated(struct menu_item *item)
 {
@@ -1769,7 +1826,7 @@ void draw_other_menu(void)
  *
  *	This routine is a callback routine invoked when the "Other" menu item
  *	in the "Actions" menu is selected. It draws the "Other" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int other_menuitem_activated(struct menu_item *item)
 {
@@ -1796,10 +1853,6 @@ inline void append_fsys_menu_items(void)
 				get_accelerator_char(_("_Check/Repair...")), FALSE,
 				(menuitem_activate_cb)actions_fsck_menuitem_activated, NULL);
 
-	append_menu_item(fsys_menu, _("Defragment..."), _("Defragment a File System"),
-				get_accelerator_char(_("_Defragment...")), FALSE,
-				(menuitem_activate_cb)actions_defrag_menuitem_activated, NULL);
-
 	append_menu_item(fsys_menu, _("Remove..."), _("Remove a File System"),
 				get_accelerator_char(_("_Remove...")), FALSE,
 				(menuitem_activate_cb)actions_unmkfs_menuitem_activated, NULL);
@@ -1837,7 +1890,7 @@ void draw_fsys_menu(void)
  *
  *	This routine is a callback routine invoked when the "File System" menu item
  *	in the "Actions" menu is selected. It draws the "File System" pulldown submenu
- *	and processes menu events. 
+ *	and processes menu events.
  */
 int fsys_menuitem_activated(struct menu_item *item)
 {
@@ -1862,6 +1915,9 @@ inline void append_actions_menu_items(void)
 	append_menu_item(actions_menu, _("Delete"), NULL, get_accelerator_char(_("_Delete")),
 				TRUE, (menuitem_activate_cb)delete_menuitem_activated, NULL);
 
+	append_menu_item(actions_menu, _("Activation"), NULL, get_accelerator_char(_("Act_ivation")),
+				TRUE, (menuitem_activate_cb)activation_menuitem_activated, NULL);
+
 	append_menu_item(actions_menu, _("Expand"), NULL, get_accelerator_char(_("_Expand")),
 				TRUE, (menuitem_activate_cb)expand_menuitem_activated, NULL);
 
@@ -1895,6 +1951,9 @@ inline void append_actions_menu_items(void)
 	append_menu_item(actions_menu, _("Save..."), NULL, get_accelerator_char(_("_Save...")),
 				FALSE, (menuitem_activate_cb)on_save_menuitem_activated, NULL);
 
+	append_menu_item(actions_menu, _("Backup..."), NULL, get_accelerator_char(_("_Backup...")),
+				FALSE, (menuitem_activate_cb)on_backup_menuitem_activated, NULL);
+
 	append_menu_item(actions_menu, _("Quit"), NULL, get_accelerator_char(_("_Quit")),
 				FALSE, (menuitem_activate_cb)on_quit_menuitem_activated, NULL);
 }
@@ -1943,15 +2002,21 @@ int actions_menuitem_activated(struct menu_item *item)
  */
 inline void append_settings_menu_items(void)
 {
+	struct menu_item *new_item;
+
 	append_menu_item(settings_menu, _("Log Level..."), NULL,
 				get_accelerator_char(_("_Log Level...")),
 				FALSE, (menuitem_activate_cb)show_log_level_dialog_menuitem_activated,
 				NULL);
 
-	append_menu_item(settings_menu, _("Node Administered..."), NULL,
+	new_item = append_menu_item(settings_menu, _("Node Administered..."), NULL,
 				get_accelerator_char(_("_Node Administered...")),
 				FALSE, (menuitem_activate_cb)show_nodes_dialog_menuitem_activated,
 				NULL);
+
+	if (get_number_of_nodes() <= 1) {
+		set_menu_item_sensitivity(new_item, 0);
+	}
 }
 
 /**
@@ -2007,19 +2072,19 @@ void append_navigation_menu_items(struct popup_menu *menu, object_handle_t handl
 	get_object_handles(handle, &parent, &producing_container, &consuming_container);
 
 	if (parent != 0) {
-		append_menu_item(menu, _("Go to parent object"), NULL, 0, FALSE, 
+		append_menu_item(menu, _("Go to parent object"), NULL, 0, FALSE,
 					(menuitem_activate_cb)jump_to_view_by_handle,
 					GUINT_TO_POINTER(parent));
 	}
 
 	if (producing_container != 0) {
-		append_menu_item(menu, _("Go to producing container"), NULL, 0, FALSE, 
+		append_menu_item(menu, _("Go to producing container"), NULL, 0, FALSE,
 					(menuitem_activate_cb)jump_to_view_by_handle,
 					GUINT_TO_POINTER(producing_container));
 	}
 
 	if (consuming_container != 0) {
-		append_menu_item(menu, _("Go to consuming container"), NULL, 0, FALSE, 
+		append_menu_item(menu, _("Go to consuming container"), NULL, 0, FALSE,
 					(menuitem_activate_cb)jump_to_view_by_handle,
 					GUINT_TO_POINTER(consuming_container));
 	}
@@ -2044,6 +2109,18 @@ void append_object_menu_items(struct popup_menu *menu, object_handle_t handle, o
 			(menuitem_activate_cb)display_object_tree_menuitem_activated,
 			handle_data);
 
+	if (evms_can_activate(handle) == 0) {
+		append_menu_item(menu, _("Activate..."), NULL, 0, FALSE,
+					(menuitem_activate_cb)context_activate_menuitem_activated,
+					handle_data);
+	}
+
+	if (evms_can_deactivate(handle) == 0) {
+		append_menu_item(menu, _("Deactivate..."), NULL, 0, FALSE,
+					(menuitem_activate_cb)context_deactivate_menuitem_activated,
+					handle_data);
+	}
+
 	if (can_create_from_freespace_object(handle) == TRUE) {
 		if (type == REGION) {
 			append_menu_item(menu, _("Create Region..."), NULL, 0, FALSE,
@@ -2062,12 +2139,6 @@ void append_object_menu_items(struct popup_menu *menu, object_handle_t handle, o
 					handle_data);
 	}
 
-	if (evms_can_set_info(handle) == 0) {
-		append_menu_item(menu, _("Modify Properties..."), NULL, 0, FALSE,
-					(menuitem_activate_cb)context_modify_object_menuitem_activated,
-					handle_data);		
-	}
-
 	if (evms_can_create_volume(handle) == 0) {
 		append_menu_item(menu, _("Create EVMS Volume..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_create_evms_vol_menuitem_activated,
@@ -2075,11 +2146,17 @@ void append_object_menu_items(struct popup_menu *menu, object_handle_t handle, o
 	}
 
 	if (evms_can_create_compatibility_volume(handle) == 0) {
-		append_menu_item(menu, _("Create Compatibility Volume..."), NULL, 0, FALSE, 
+		append_menu_item(menu, _("Create Compatibility Volume..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_create_vol_menuitem_activated,
 					handle_data);
 	}
 
+	if (evms_can_set_info(handle) == 0) {
+		append_menu_item(menu, _("Modify Properties..."), NULL, 0, FALSE,
+					(menuitem_activate_cb)context_modify_object_menuitem_activated,
+					handle_data);		
+	}
+
 	if (evms_can_delete(handle) == 0) {
 		append_menu_item(menu, _("Delete..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_delete_menuitem_activated,
@@ -2104,7 +2181,7 @@ void append_object_menu_items(struct popup_menu *menu, object_handle_t handle, o
 					handle_data);
 	}
 
-	if (evms_can_remove_from_container(handle) == 0) {
+	if (can_remove_from_container(handle) == 0) {
 		append_menu_item(menu, _("Remove from Container..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_remove_consumed_object_menuitem_activated,
 					handle_data);
@@ -2113,7 +2190,7 @@ void append_object_menu_items(struct popup_menu *menu, object_handle_t handle, o
 	if (evms_can_unassign(handle) == 0) {
 		gchar *text;
 		
-		text = g_strdup_printf(_("Remove %s from object..."),
+		text = g_strdup_printf(_("Remove %s from Object..."),
 					get_parent_plugin_type_string(handle, TRUE));
 		append_menu_item(menu, text, NULL, 0, FALSE,
 					(menuitem_activate_cb)context_remove_segment_manager_menuitem_activated,
@@ -2144,8 +2221,20 @@ void append_volume_menu_items(struct popup_menu *menu, object_handle_t handle)
 		evms_free(volume);
 	}
 
+	if (evms_can_activate(handle) == 0) {
+		append_menu_item(menu, _("Activate..."), NULL, 0, FALSE,
+					(menuitem_activate_cb)context_activate_menuitem_activated,
+					handle_data);
+	}
+
+	if (evms_can_deactivate(handle) == 0) {
+		append_menu_item(menu, _("Deactivate..."), NULL, 0, FALSE,
+					(menuitem_activate_cb)context_deactivate_menuitem_activated,
+					handle_data);
+	}
+
 	if (can_volume_accept_new_feature(handle) == TRUE) {
-		append_menu_item(menu, _("Add feature..."), NULL, 0, FALSE,
+		append_menu_item(menu, _("Add Feature..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_add_feature_menuitem_activated,
 					handle_data);
 	}
@@ -2163,7 +2252,7 @@ void append_volume_menu_items(struct popup_menu *menu, object_handle_t handle)
 	}
 
 	if (evms_can_set_volume_name(handle) == 0) {
-		append_menu_item(menu, _("Change volume name..."), NULL, 0, FALSE,
+		append_menu_item(menu, _("Change Volume Name..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_modify_vol_menuitem_activated,
 					handle_data);
 	}
@@ -2202,34 +2291,27 @@ void append_filesys_menu_items(struct popup_menu *menu, object_handle_t handle)
 	handle_data = GUINT_TO_POINTER(handle);
 
 	if (evms_can_mount(handle) == 0) {
-		append_menu_item(menu, _("Mount File System..."), NULL, 0, FALSE,
+		append_menu_item(menu, _("Mount..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_mount_filesystem_menuitem_activated,
 					handle_data);
 	}
 	
 	if (evms_can_unmount(handle) == 0) {
-		append_menu_item(menu, _("Unmount File System..."), NULL, 0, FALSE,
+		append_menu_item(menu, _("Unmount..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_unmount_filesystem_menuitem_activated,
 					handle_data);
 	}
 
 	if (volume_has_fsim(handle) == TRUE) {
 		if (evms_can_fsck(handle) == 0) {
-			append_menu_item(menu, _("Check/Repair File System..."), NULL, 0, 
-						FALSE,
-						(menuitem_activate_cb)context_fsck_menuitem_activated,
-						handle_data);
-		}
-
-		if (evms_can_defrag(handle) == 0) {
-			append_menu_item(menu, _("Defragment File System..."), NULL, 0, 
+			append_menu_item(menu, _("Check/Repair File System..."), NULL, 0,
 						FALSE,
 						(menuitem_activate_cb)context_fsck_menuitem_activated,
 						handle_data);
 		}
 
 		if (evms_can_unmkfs(handle) == 0) {
-			append_menu_item(menu, _("Remove File System..."), NULL, 0, 
+			append_menu_item(menu, _("Remove File System..."), NULL, 0,
 						FALSE,
 						(menuitem_activate_cb)context_unmkfs_menuitem_activated,
 						handle_data);
@@ -2256,29 +2338,29 @@ void append_container_menu_items(struct popup_menu *menu, object_handle_t handle
 
 	handle_data = GUINT_TO_POINTER(handle);
 
+	if (evms_can_set_info(handle) == 0) {
+		append_menu_item(menu, _("Modify Properties..."), NULL, 0, FALSE,
+					(menuitem_activate_cb)context_modify_container_menuitem_activated,
+					handle_data);		
+	}
+
 	if (evms_can_delete(handle) == 0) {
 		append_menu_item(menu, _("Delete..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_delete_menuitem_activated,
 					handle_data);
 	}
 
-	if (can_expand_container(handle)) {
+	if (evms_can_expand(handle) == 0) {
 		append_menu_item(menu, _("Expand..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_expand_container_menuitem_activated,
 					handle_data);
 	}
 
-	if (can_shrink_container(handle)) {
+	if (evms_can_shrink(handle) == 0) {
 		append_menu_item(menu, _("Shrink..."), NULL, 0, FALSE,
 					(menuitem_activate_cb)context_shrink_container_menuitem_activated,
 					handle_data);
 	}
-
-	if (evms_can_set_info(handle) == 0) {
-		append_menu_item(menu, _("Modify Properties..."), NULL, 0, FALSE,
-					(menuitem_activate_cb)context_modify_container_menuitem_activated,
-					handle_data);		
-	}
 }
 
 /**
@@ -2350,7 +2432,7 @@ void append_context_menu_items(struct popup_menu *menu, object_handle_t handle)
  *
  *	This routine creates a context popup menu for a given object handle. It
  *	populates the menu with selections only valid for this object. The context
- *	popup is a modal window. 
+ *	popup is a modal window.
  */
 void popup_context_menu(object_handle_t handle, int starty, int startx)
 {
