@@ -4,19 +4,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
- */ 
+ */
 
 #include <string.h>
 #include <frontend.h>
@@ -127,7 +127,7 @@ gboolean required_options_have_values(GSList *options)
  *	@options: the list of option descriptors
  *
  *	This routine checks to see if all required options have values. If they
- *	all do then the task button is made sensitive to 
+ *	all do then the task button is made sensitive to
  */
 void check_required_options(struct dialog_window *dialog, GSList *options)
 {
@@ -198,7 +198,7 @@ int get_info_title_column_width(extended_info_array_t *info)
  *	@collection_type: the collection type
  *	@can_convert: whether plugins allows us to convert to a more readable format
  *
- *	This routine is the common routine invoked to produce the string for either a value if 
+ *	This routine is the common routine invoked to produce the string for either a value if
  *	it is not a collection type or the first value in a list or the min and max values for
  *	a range if they are a collection type.
  */
@@ -226,7 +226,7 @@ char *create_value_string(value_t value, value_unit_t unit, value_type_t type, v
 			break;
 		case EVMS_Collection_List:
 			if (collection.list->count > 0)
-				str = make_sectors_readable_string(convert_value_to_ui64(collection.list->value[0], 
+				str = make_sectors_readable_string(convert_value_to_ui64(collection.list->value[0],
 				type));
 			else
 				str = make_sectors_readable_string(0);
@@ -283,7 +283,7 @@ char *create_option_value_string(option_descriptor_t *option)
 		 * Weirdness to handle multi value option value.
 		 * Basically we send over the value list
 		 * through the collection list parm and set it
-		 * up so it is looked (like an extended info 
+		 * up so it is looked (like an extended info
 		 * collection) and the option->value is ignored.
 		 */
 		if (EVMS_OPTION_VALUE_IS_LIST(option->flags)) {
@@ -625,7 +625,7 @@ extended_info_array_t *add_extra_volume_info(logical_volume_info_t *vinfo, exten
 	info_out->info[VOL_INFO_FS_MIN_SIZE].format = EVMS_Format_Normal;
 	info_out->info[VOL_INFO_FS_MIN_SIZE].collection_type = EVMS_Collection_None;
 	info_out->info[VOL_INFO_FS_MIN_SIZE].value.ui64 = vinfo->min_fs_size;
-	    
+	
 	info_out->info[VOL_INFO_FS_MAX_SIZE].name = "max_fs_size";
 	info_out->info[VOL_INFO_FS_MAX_SIZE].title = _("Maximum File System Size");
 	info_out->info[VOL_INFO_FS_MAX_SIZE].desc = _("This field describes the maximum size of the file system.");
@@ -705,8 +705,8 @@ extended_info_array_t *add_extra_object_info(storage_object_info_t *oinfo, exten
  */
 inline extended_info_array_t *duplicate_extended_info(extended_info_array_t *info)
 {
-	return g_memdup(info, sizeof(extended_info_array_t) + (sizeof(extended_info_t) *
-			(info->count - 1)));
+	return g_memdup(info, sizeof(extended_info_array_t) +
+			      (sizeof(extended_info_t) * info->count));
 }
 
 /**
@@ -762,7 +762,7 @@ int view_more_info(struct clist *clist, struct clist_item *item)
  *	@clist: the options clist
  *	@item: the clist_item that received focus
  *
- *	This routine is invoked when an item in the extended info clist receives focus. 
+ *	This routine is invoked when an item in the extended info clist receives focus.
  *	We display the extended info field description in the status bar for the user to see.
  */
 void on_info_item_focus(struct clist *clist, struct clist_item *item)
@@ -888,7 +888,7 @@ int display_details_menuitem_activated(struct menu_item *item)
  */
 void replace_option(task_handle_t task, struct clist_item *item, option_descriptor_t *option, GSList *options)
 {
-	int rc; 
+	int rc;
 	option_descriptor_t *option_redux;
 
 	rc = evms_get_option_descriptor_by_name(task, option->name, &option_redux);
@@ -903,7 +903,7 @@ void replace_option(task_handle_t task, struct clist_item *item, option_descript
 		g_free(item->row_text[1]);
 		evms_free(option);
 
-		item->row_text[1] = create_option_value_string(option_redux); 
+		item->row_text[1] = create_option_value_string(option_redux);
 	} else {
 		log_error("%s: evms_get_option_descriptor_by_name() returned error code %d.\n", __FUNCTION__, rc);
 	}
@@ -924,7 +924,7 @@ void replace_option(task_handle_t task, struct clist_item *item, option_descript
  *	We replace the clist item value displayed on success and if the effect indicates
  *	we need to reload options we just let the reload handle the refresh.
  */
-gboolean set_option_value(task_handle_t task, option_descriptor_t *option, GSList *options, 
+gboolean set_option_value(task_handle_t task, option_descriptor_t *option, GSList *options,
 				struct clist_item *item, char *buffer)
 {
 	int rc;
