@@ -358,7 +358,7 @@ task_requirements_t determine_task_requirements(task_handle_t task, engine_handl
  */
 int create_task(engine_handle_t handle, task_action_t action,
 		task_requirements_t *requirements, task_handle_t *task,
-		int *objects_min, int *objects_max)
+		u_int32_t *objects_min, u_int32_t *objects_max)
 {
 	int rc, option_count;
 
@@ -390,7 +390,7 @@ int create_task(engine_handle_t handle, task_action_t action,
 	} else {
 		log_error("%s: evms_create_task() returned error code %d.\n", __FUNCTION__, rc);
 	}
-	
+
 	log_debug("%s: The task requirement code is %d\n", __FUNCTION__, *requirements);
 
 	return rc;
@@ -709,7 +709,7 @@ int configure_options_button_activated(struct menu_item *item)
 				evms_free(prev_selections);
 
 			g_hash_table_insert(objs_hash_table, "prev_selections", curr_selections);
-				
+
 			set_dialog_delete_cb(opts_dialog, (dialog_delete_cb)on_delete_options_dialog);
 		} else {
 			evms_free(curr_selections);
@@ -832,7 +832,7 @@ void display_declination_window(declined_handle_array_t *declined_objects)
 void mark_selected_rows(struct clist *clist, handle_array_t *selected_objects)
 {
 	gint i;
-		
+
 	/*
 	 * Find the row corresponding to each object handle in the
 	 * selected list and mark those rows as selected in the
@@ -892,7 +892,7 @@ int reload_acceptable_objects(struct clist *clist)
 		}
 
 		clear_clist(clist);
-		
+
 		rc = evms_get_selected_object_limits(task, &min, &max);
 		if (rc == 0)
 			set_selection_mode(clist, (max != 1 ? CLIST_MODE_MULTI : CLIST_MODE_SINGLE));
@@ -997,7 +997,8 @@ int update_selected_objects(struct clist *clist, task_handle_t task, int *count)
  */
 int on_select_acceptable_object(struct clist *clist, struct clist_item *item)
 {
-	int rc, min, max;
+	int rc;
+	u_int32_t min, max;
 	task_handle_t task;
 	struct dialog_window *dialog = clist->user_data;
 
@@ -1046,7 +1047,8 @@ int on_select_acceptable_object(struct clist *clist, struct clist_item *item)
  */
 int on_unselect_acceptable_object(struct clist *clist, struct clist_item *item)
 {
-	int rc, min, max;
+	int rc;
+	u_int32_t min, max;
 	task_handle_t task;
 	struct dialog_window *dialog = clist->user_data;
 
@@ -1092,7 +1094,7 @@ struct dialog_window *create_acceptable_objects_selection_dialog(task_handle_t t
 								task_requirements_t requirements, char *help,
 								GHashTable *hash_table)
 {
-	int min = 0, max = 0;
+	u_int32_t min = 0, max = 0;
 	struct selwin *selwin;
 	char *window_title, *prompt;
 	struct dialog_window *dialog;
@@ -1190,7 +1192,8 @@ void on_delete_task_dialog(struct dialog_window *dialog)
 struct dialog_window *create_task_dialog(struct dialog_list *list, engine_handle_t handle,
 			task_action_t action, gchar *title, gchar *verb, gchar *help)
 {
-	int rc, min, max;
+	int rc;
+	u_int32_t min, max;
 	task_handle_t task;
 	GHashTable *hash_table;
 	struct dialog_window *dialog = NULL;
