@@ -4,20 +4,20 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
- */ 
- 
+ */
+
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -25,6 +25,7 @@
 #include <limits.h>
 #include <frontend.h>
 #include <glib.h>
+#include <locale.h>
 
 #include "common.h"
 #include "value.h"
@@ -113,7 +114,7 @@ gboolean value_less_than_integer(value_t value, value_type_t type, gint number)
 		result = value.i32 < number;
 		break;
 	case EVMS_Type_Unsigned_Int:
-		result = value.ui < number;            
+		result = value.ui < number;
 		break;
 	case EVMS_Type_Unsigned_Int32:
 		result = value.ui32 < number;
@@ -252,7 +253,7 @@ gint convert_string_to_value(gchar *string, value_type_t type, gint maxlen, valu
 
 	switch (type) {
 	case EVMS_Type_Boolean:
-		if (g_strcasecmp(_("True"), string) == 0 || 
+		if (g_strcasecmp(_("True"), string) == 0 ||
 			g_strcasecmp(_("Yes"), string) == 0)
 			value->b = TRUE;
 		else
@@ -276,18 +277,18 @@ gint convert_string_to_value(gchar *string, value_type_t type, gint maxlen, valu
 		rc = errno;
 		break;
 	case EVMS_Type_Int8:
-		value->i32 = strtol(string, NULL, 0);        
+		value->i32 = strtol(string, NULL, 0);
 		if (errno == 0 && (value->i32 < SCHAR_MIN || value->i32 > SCHAR_MAX))
 			rc = ERANGE;
 		else
-			rc = errno;            
-		break;        
+			rc = errno;
+		break;
 	case EVMS_Type_Unsigned_Int8:
 		value->ui32 = strtoul(string, NULL, 0);
 		if (errno == 0 && value->ui32 > UCHAR_MAX)
 			rc = ERANGE;
 		else
-			rc = errno;            
+			rc = errno;
 		break;
 	case EVMS_Type_Int16:
 		value->i32 = strtol(string, NULL, 0);
@@ -341,14 +342,14 @@ gint convert_string_to_value(gchar *string, value_type_t type, gint maxlen, valu
  *	@size: max string size
  *
  *	This routine creates a value list. If the list is a list of
- *	string types then it also allocates string buffers of the 
+ *	string types then it also allocates string buffers of the
  *	given size + 1.
  */
 value_list_t *allocate_value_list(guint count, value_type_t type, guint size)
 {
 	value_list_t *vlist;
 
-	vlist = g_malloc0(sizeof(value_list_t) + ((count - 1) * sizeof(value_t)));
+	vlist = g_malloc0(sizeof(value_list_t) + (count * sizeof(value_t)));
 
 	if (type == EVMS_Type_String) {
 		guint i;
@@ -377,7 +378,7 @@ value_list_t *allocate_value_list(guint count, value_type_t type, guint size)
  *	length and the string is duplicated. If the value
  *	type describes a value list then the list is duplicated.
  */
-void duplicate_value(value_t source_value, value_type_t type, gboolean is_list, 
+void duplicate_value(value_t source_value, value_type_t type, gboolean is_list,
 			guint list_count, gint maxlen, value_t *target_value)
 {
 	/*
@@ -397,10 +398,10 @@ void duplicate_value(value_t source_value, value_type_t type, gboolean is_list,
 			}
 			target_value->list->count = source_value.list->count;
 		} else {
-			target_value->list = g_memdup(source_value.list, 
-				(sizeof(value_list_t) + (list_count * (sizeof(value_t) - 1))));
+			target_value->list = g_memdup(source_value.list,
+				(sizeof(value_list_t) + (list_count * sizeof(value_t))));
 		}
-	} else if (type == EVMS_Type_String) { 
+	} else if (type == EVMS_Type_String) {
 		target_value->s = g_malloc(maxlen);
 		strcpy(target_value->s, source_value.s);
 	} else {
@@ -418,7 +419,7 @@ void duplicate_value(value_t source_value, value_type_t type, gboolean is_list,
  *	This routine takes the address of a value and clears
  *	the value contents. If the value is a list of values
  *	then the list is freed. If the value contains a string
- *	then the string is freed. 
+ *	then the string is freed.
  */
 void clear_value(value_t *value, value_type_t type, gboolean is_list, guint list_count)
 {
@@ -481,7 +482,7 @@ gfloat convert_value_to_float(value_t value, value_type_t type)
 		float_value = value.i32 * 1.0;
 		break;
 	case EVMS_Type_Unsigned_Int:
-		float_value = value.ui * 1.0;            
+		float_value = value.ui * 1.0;
 		break;
 	case EVMS_Type_Unsigned_Int32:
 		float_value = value.ui32 * 1.0;
@@ -518,7 +519,7 @@ void convert_float_to_value(gfloat float_value, value_type_t type, value_t *valu
 	case EVMS_Type_Char:
 	case EVMS_Type_Unsigned_Char:
 	case EVMS_Type_Int8:
-	case EVMS_Type_Unsigned_Int8:        
+	case EVMS_Type_Unsigned_Int8:
 		value->ui8 = float_value;
 		break;
 	case EVMS_Type_Int16:
@@ -527,7 +528,7 @@ void convert_float_to_value(gfloat float_value, value_type_t type, value_t *valu
 		break;
 	case EVMS_Type_Int:
 	case EVMS_Type_Unsigned_Int:
-		value->ui = float_value;            
+		value->ui = float_value;
 		break;
 	case EVMS_Type_Int32:
 	case EVMS_Type_Unsigned_Int32:
@@ -580,13 +581,13 @@ gdouble convert_value_to_double(value_t value, value_type_t type)
 		double_value = value.ui16 * 1.0;
 		break;
 	case EVMS_Type_Int:
-		double_value = value.i * 1.0;            
+		double_value = value.i * 1.0;
 		break;
 	case EVMS_Type_Int32:
 		double_value = value.i32 * 1.0;
 		break;
 	case EVMS_Type_Unsigned_Int:
-		double_value = value.ui * 1.0;            
+		double_value = value.ui * 1.0;
 		break;
 	case EVMS_Type_Unsigned_Int32:
 		double_value = value.ui32 * 1.0;
@@ -623,7 +624,7 @@ void convert_double_to_value(gdouble double_value, value_type_t type, value_t *v
 	case EVMS_Type_Char:
 	case EVMS_Type_Unsigned_Char:
 	case EVMS_Type_Int8:
-	case EVMS_Type_Unsigned_Int8:        
+	case EVMS_Type_Unsigned_Int8:
 		value->ui8 = double_value;
 		break;
 	case EVMS_Type_Int16:
@@ -632,7 +633,7 @@ void convert_double_to_value(gdouble double_value, value_type_t type, value_t *v
 		break;
 	case EVMS_Type_Int:
 	case EVMS_Type_Unsigned_Int:
-		value->ui = double_value;            
+		value->ui = double_value;
 		break;
 	case EVMS_Type_Int32:
 	case EVMS_Type_Unsigned_Int32:
@@ -685,13 +686,13 @@ u_int64_t convert_value_to_ui64(value_t value, value_type_t type)
 		ui64_value = value.ui16;
 		break;
 	case EVMS_Type_Int:
-		ui64_value = value.i;            
+		ui64_value = value.i;
 		break;
 	case EVMS_Type_Int32:
 		ui64_value = value.i32;
 		break;
 	case EVMS_Type_Unsigned_Int:
-		ui64_value = value.ui;            
+		ui64_value = value.ui;
 		break;
 	case EVMS_Type_Unsigned_Int32:
 		ui64_value = value.ui32;
@@ -702,7 +703,7 @@ u_int64_t convert_value_to_ui64(value_t value, value_type_t type)
 	case EVMS_Type_Unsigned_Int64:
 		ui64_value = value.ui64;
 		break;
-	default:      
+	default:
 		log_warning("%s: Value type of %d was not handled.\n", __FUNCTION__, type);
 	}
 	return ui64_value;
@@ -719,7 +720,7 @@ u_int64_t convert_value_to_ui64(value_t value, value_type_t type)
  *	bytes, kilobytes, megabytes, gigabytes, or terabytes.
  */
 gchar *convert_sector_value_to_string(value_t value, value_type_t type, value_unit_t *new_unit)
-{      
+{
 	u_int64_t size_in_sectors;
 
 	size_in_sectors = convert_value_to_ui64(value, type);
@@ -739,9 +740,9 @@ gchar *convert_sector_value_to_string(value_t value, value_type_t type, value_un
  *	determine the unit to use but is given the unit to convert to.
  */
 gchar *convert_sector_value_to_new_unit_string(value_t value, value_type_t type, value_unit_t new_unit)
-{   
+{
 	value_t converted_value;
-    
+
 	converted_value.r32 = convert_sector_value_to_float_with_unit(value, type, new_unit);
 	return convert_value_to_string(converted_value, EVMS_Type_Real32, EVMS_Format_Normal);
 }
@@ -769,7 +770,7 @@ value_unit_t get_unit_from_mnemonic(gchar *mnemonic)
 	else if (*mnemonic == 'B' || *mnemonic == 'b')
 		unit = EVMS_Unit_Bytes;
 	else if (*mnemonic == 'K' || *mnemonic == 'k')
-		unit = EVMS_Unit_Kilobytes;    
+		unit = EVMS_Unit_Kilobytes;
 	else if (*mnemonic == 'T' || *mnemonic == 't')
 		unit = EVMS_Unit_Terabytes;
 	else if (*mnemonic == 'P' || *mnemonic == 'p')
@@ -818,7 +819,7 @@ gfloat convert_sector_value_to_float_with_unit(value_t value, value_type_t type,
 		new_size /= PB_TO_SECTORS_MULTIPLIER;
 		break;
 	default:
-		log_debug("%s: We are not going to convert this unit of measurement: %d\n", 
+		log_debug("%s: We are not going to convert this unit of measurement: %d\n",
 			__FUNCTION__, conversion_unit);
 		break;
 	}
@@ -848,7 +849,7 @@ value_unit_t select_readable_unit_for_sector_value(value_t value, value_type_t t
 		result = value_as_ui64 / divisor;
 
 		if (result > 0.0)
-			unit = units[i];      
+			unit = units[i];
 		else
 			break;
 	}
@@ -868,8 +869,8 @@ value_unit_t select_readable_unit_for_sector_value(value_t value, value_type_t t
  *      or integer number and it gets converted to a value expressed in terms of
  *      EVMS_Unit_Sectors unit of measurement.
  */
-void convert_size_value_to_sector_value(value_t size_value, value_type_t size_type, 
-					value_unit_t size_unit, 
+void convert_size_value_to_sector_value(value_t size_value, value_type_t size_type,
+					value_unit_t size_unit,
 					value_t *sec_value, value_type_t sec_type)
 {
 	gdouble size_as_double, size_in_sectors;
@@ -900,7 +901,7 @@ void convert_size_value_to_sector_value(value_t size_value, value_type_t size_ty
 		size_in_sectors = size_as_double * PB_TO_SECTORS_MULTIPLIER;
 		break;
 	default:
-		log_debug("%s: We are not going to convert this unit of measurement: %d\n", 
+		log_debug("%s: We are not going to convert this unit of measurement: %d\n",
 			__FUNCTION__, size_unit);
 	case EVMS_Unit_Sectors:
 		size_in_sectors = size_as_double;
@@ -914,7 +915,7 @@ void convert_size_value_to_sector_value(value_t size_value, value_type_t size_ty
  *	@size: the sector unit size as a real number
  *	@type: the type of the sector value, e.g. EVMS_Type_Int64
  *	@unit: the unit of the size, e.g. KB, TB, etc.
- *	@value: address to write sector value to 
+ *	@value: address to write sector value to
  *
  *	This routine takes a float that expresses a size unit
  *	(KB,MB,TB,etc.) and converts it to a value_t of value_type_t
@@ -944,7 +945,7 @@ void convert_float_to_sector_value(gfloat size, value_type_t type, value_unit_t
 		size_in_sectors = size * PB_TO_SECTORS_MULTIPLIER;
 		break;
 	default:
-		log_debug("%s: We are not going to convert this unit of measurement: %d\n", 
+		log_debug("%s: We are not going to convert this unit of measurement: %d\n",
 			__FUNCTION__, unit);
 	case EVMS_Unit_Sectors:
 		size_in_sectors = size;
@@ -976,18 +977,28 @@ void convert_size_string_to_sector_value(gchar *string, value_unit_t unit,
 		gchar *number;
 		value_t value_in;
 		value_type_t type_in;
+		struct lconv * locale_conv = localeconv();
+		char decimal_point = '.';
+
+		if (locale_conv != NULL) {
+			if (locale_conv->decimal_point != NULL) {
+				if (*locale_conv->decimal_point != '\0') {
+					decimal_point = *locale_conv->decimal_point;
+				}
+			}
+		}
 
 		/*
-		 * Copy digits, blank space and '.' to temp string until we hit an
-		 * alpha character.
+		 * Copy digits, blank space and decimal point to temp string
+		 * until we hit an alpha character.
 		 */
 		number = g_malloc(strlen(string) + 1);
 		type_in = EVMS_Type_Unsigned_Int64;
 		value_in.i64 = 0;
 
-		while (*string && (isdigit(*string) || *string == '.' || isspace(*string))) {
-            		if (*string == '.')
-                		type_in = EVMS_Type_Real64;
+		while (*string && (isdigit(*string) || *string == decimal_point || isspace(*string))) {
+			if (*string == decimal_point)
+				type_in = EVMS_Type_Real64;
 
 			number[length] = *string;
 			length++;
@@ -1055,7 +1066,7 @@ gchar *convert_value_to_string_with_unit(value_t value, value_type_t type,
  *	If ok_to_convert is TRUE, it converts it first to a more
  *	readable form, e.g. sectors or bytes to MB or GB.
  */
-gchar *make_value_readable_string(value_t value, value_type_t type, value_unit_t unit, 
+gchar *make_value_readable_string(value_t value, value_type_t type, value_unit_t unit,
 					value_format_t format, gboolean ok_to_convert)
 {
 	gchar *string;
@@ -1108,14 +1119,14 @@ gint validate_numeric_string_characters(gchar *string)
 {
 	gint i, len, rc = 0;
 	gchar *stripped;
-    
+
 	stripped = g_strstrip(string);
     	len = strlen(stripped);
-    
+
 	for (i = 0; i < len; i++) {
 		if (isdigit(stripped[i]))
 			continue;
-		else if (i > 1 && isxdigit(stripped[i]) && 
+		else if (i > 1 && isxdigit(stripped[i]) &&
 				(stripped[1] == 'x' || stripped[1] == 'X') && stripped[0] == '0')
 			continue;
 		else if (isspace(stripped[i]))
@@ -1124,7 +1135,7 @@ gint validate_numeric_string_characters(gchar *string)
 			continue;
 		else if (i == 1 && (stripped[1] == 'x' || stripped[1] == 'X') && stripped[0] == '0')
 			continue;
-		else {    
+		else {
 			rc = EINVAL;
 			break;
 		}
@@ -1144,32 +1155,34 @@ gint validate_numeric_string_characters(gchar *string)
 gchar *validate_string_as_numeric_value(gchar *string, value_type_t type)
 {
 	gchar *msg = NULL;
-    
+	gchar *number_buffer1;
+	gchar *number_buffer2;
+
 	if (type >= EVMS_Type_Int && type <= EVMS_Type_Unsigned_Int64) {
 		gint rc = 0;
 		value_t value;
-               
+
 		/*
 		 * Do a preliminary scan of the string for non-valid characters.
 		 * We accept 0-9, A-F, a-f, X or x. + or - is valid for the first
 		 * character only. We ignore whitespace as we do the scan/check.
 		 */
 		rc = validate_numeric_string_characters(string);
-        
+
 		/*
 		 * Use convert_to_string_to_value() to do the bounds check on the numeric
 		 * for us. If we get a range error, produce a acceptable values message
 		 * for the given type.
 		 */
-        
+
 		if (rc == 0)
 			rc = convert_string_to_value(string, type, 0, &value);
-        
+
 		if (rc != 0) {
-			switch (type) {            
+			switch (type) {
 			case EVMS_Type_Int8:
 				msg = g_strdup_printf(_("Valid values are %hhd to %hhd."), SCHAR_MIN, SCHAR_MAX);
-				break; 
+				break;
 			case EVMS_Type_Unsigned_Int8:
 				msg = g_strdup_printf(_("Valid values are %hhu to %hhu."), 0, UCHAR_MAX);
 				break;
@@ -1188,15 +1201,21 @@ gchar *validate_string_as_numeric_value(gchar *string, value_type_t type)
 				msg = g_strdup_printf(_("Valid values are %u to %u."), 0, UINT_MAX);
 				break;
 			case EVMS_Type_Int64:
-				msg = g_strdup_printf(_("Valid values are %"PRId64" to %"PRId64"."), INT64_MIN, INT64_MAX);
+				number_buffer1 = g_strdup_printf("%"PRId64, INT64_MIN);
+				number_buffer2 = g_strdup_printf("%"PRId64, INT64_MAX);
+				msg = g_strdup_printf(_("Valid values are %s to %s."), number_buffer1, number_buffer2);
+				g_free(number_buffer1);
+				g_free(number_buffer2);
 				break;
 			case EVMS_Type_Unsigned_Int64:
-				msg = g_strdup_printf(_("Valid values are %u to %"PRIu64"."), 0, UINT64_MAX);           
+				number_buffer1 = g_strdup_printf("%"PRIu64, UINT64_MAX);
+				msg = g_strdup_printf(_("Valid values are %u to %s."), 0, number_buffer1);
+				g_free(number_buffer1);
 				break;
 			default:
 				log_debug("%s: Gave no message for a numeric type of %d.\n", __FUNCTION__, type);
-			}        
-		} 
+			}
+		}
 	}
 	return msg;
 }
@@ -1240,7 +1259,7 @@ gboolean values_are_equal(value_t value1, value_t value2, value_type_t type)
 		break;
 	case EVMS_Type_Int:
 	case EVMS_Type_Unsigned_Int:
-		result = value1.ui == value2.ui;            
+		result = value1.ui == value2.ui;
 		break;
 	case EVMS_Type_Int32:
 	case EVMS_Type_Unsigned_Int32:
