@@ -99,26 +99,26 @@ typedef struct tree_node_s {
 
 char msg_buf[10240];
 
-#define LOG_CRITICAL(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(CRITICAL,	  prog_name, msg_buf, ## args);}
-#define LOG_SERIOUS(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(SERIOUS,	  prog_name, msg_buf, ## args);}
-#define LOG_ERROR(msg, args...)		{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(ERROR,	  prog_name, msg_buf, ## args);}
-#define LOG_WARNING(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(WARNING,	  prog_name, msg_buf, ## args);}
-#define LOG_DEFAULT(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(DEFAULT,	  prog_name, msg_buf, ## args);}
-#define LOG_DETAILS(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(DETAILS,	  prog_name, msg_buf, ## args);}
-#define LOG_DEBUG(msg, args...)		{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(DEBUG,	  prog_name, msg_buf, ## args);}
-#define LOG_EXTRA(msg, args...)		{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(EXTRA,	  prog_name, msg_buf, ## args);}
-#define LOG_ENTRY_EXIT(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(ENTRY_EXIT, prog_name, msg_buf, ## args);}
-#define LOG_EVERYTHING(msg, args...)	{sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
-					 evms_write_log_entry(EVERYTHING, prog_name, msg_buf, ## args);}
+#define LOG_CRITICAL(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(CRITICAL,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_SERIOUS(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(SERIOUS,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_ERROR(msg, args...)		do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(ERROR,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_WARNING(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(WARNING,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_DEFAULT(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(DEFAULT,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_DETAILS(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(DETAILS,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_DEBUG(msg, args...)		do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(DEBUG,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_EXTRA(msg, args...)		do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(EXTRA,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_ENTRY_EXIT(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(ENTRY_EXIT,	prog_name, msg_buf , ## args);} while (0)
+#define LOG_EVERYTHING(msg, args...)	do { sprintf(msg_buf, "%s: %s", __FUNCTION__, msg); \
+					     evms_write_log_entry(EVERYTHING,	prog_name, msg_buf , ## args);} while (0)
 
 /* Macros to log entry and exit from subroutines. */
 #define LOG_ENTRY()			LOG_ENTRY_EXIT("Enter.\n")
@@ -128,9 +128,9 @@ char msg_buf[10240];
 #define LOG_EXIT_BOOL(x)		LOG_ENTRY_EXIT("Exit.  Return is %s\n", x ? "TRUE" : "FALSE")
 #define LOG_EXIT_VOID()			LOG_ENTRY_EXIT("Exit.\n")
 
-#define MSG(msg, args...)         {if (!quiet) { printf(msg, ## args); } LOG_DEFAULT(msg, ## args)}
-#define VERBOSE_MSG(msg, args...) {if (verbose) { printf(msg, ## args); } LOG_DEBUG(msg, ## args)}
-#define ERROR_MSG(msg, args...)   {fprintf(stderr, msg, ## args); LOG_CRITICAL(msg, ## args) }
+#define MSG(msg, args...)         do { if (!quiet) { printf(msg , ## args); } LOG_DEFAULT(msg , ## args); } while (0)
+#define VERBOSE_MSG(msg, args...) do { if (verbose) { printf(msg , ## args); } LOG_DEBUG(msg , ## args); } while (0)
+#define ERROR_MSG(msg, args...)   do { fprintf(stderr, msg , ## args); LOG_CRITICAL(msg , ## args); } while (0)
 
 
 static boolean is_numeric(char * str) {
@@ -401,7 +401,7 @@ static int parse_options(int      argc,
 					date_string = strdup(optarg);
 
 				} else {
-					ERROR_MSG("You cannot specify both a metadata file and a metadata backup date.\n");
+					ERROR_MSG(_("You cannot specify both a metadata file and a metadata backup date.\n"));
 					rc = EINVAL;
 				}
 				break;
@@ -411,7 +411,7 @@ static int parse_options(int      argc,
 					metadata_file = strdup(optarg);
 
 				} else {
-					ERROR_MSG("You cannot specify both a metadata backup date and a metadata file.\n");
+					ERROR_MSG(_("You cannot specify both a metadata backup date and a metadata file.\n"));
 					rc = EINVAL;
 				}
 				break;
@@ -423,7 +423,7 @@ static int parse_options(int      argc,
 			case 'L':
 				list = TRUE;
 				if (single) {
-					ERROR_MSG(_("You cannot specify -L (list) and -s (single) at the same time.\n"));
+					(_("You cannot specify -L (list) and -s (single) at the same time.\n"));
 
 					/* Display the help. */
 					rc = EINVAL;
@@ -582,31 +582,31 @@ static boolean validate_date(struct tm * date) {
 	boolean result = TRUE;
 
 	if ((date->tm_sec < 0) || (date->tm_sec > 60)) {
-		VERBOSE_MSG("Seconds value of %d is out of range.\n", date->tm_sec);
+		VERBOSE_MSG(_("Seconds value of %d is out of range.\n"), date->tm_sec);
 		result = FALSE;
 	}
 	if ((date->tm_min < 0) || (date->tm_min > 59)) {
-		VERBOSE_MSG("Minues value of %d is out of range.\n", date->tm_min);
+		VERBOSE_MSG(_("Minues value of %d is out of range.\n"), date->tm_min);
 		result = FALSE;
 	}
 	if ((date->tm_hour < 0) || (date->tm_hour > 23)) {
-		VERBOSE_MSG("Hour value of %d is out of range.\n", date->tm_hour);
+		VERBOSE_MSG(_("Hour value of %d is out of range.\n"), date->tm_hour);
 		result = FALSE;
 	}
 	if ((date->tm_mday < 1) || (date->tm_mday > 31)) {
-		VERBOSE_MSG("Date value of %d is out of range.\n", date->tm_mday);
+		VERBOSE_MSG(_("Date value of %d is out of range.\n"), date->tm_mday);
 		result = FALSE;
 	}
 	if ((date->tm_mon < 0) || (date->tm_mon > 11)) {
-		VERBOSE_MSG("Month value of %d is out of range.\n", date->tm_mon);
+		VERBOSE_MSG(_("Month value of %d is out of range.\n"), date->tm_mon);
 		result = FALSE;
 	}
 	if (date->tm_year < 70) {
-		VERBOSE_MSG("Year value of %d (%d) is out of range.\n", date->tm_year, date->tm_year + 1900);
+		VERBOSE_MSG(_("Year value of %d (%d) is out of range.\n"), date->tm_year, date->tm_year + 1900);
 		result = FALSE;
 	}
 
-	LOG_EXIT_BOOL(result)
+	LOG_EXIT_BOOL(result);
 	return result;
 }
 
@@ -630,8 +630,8 @@ static inline boolean got_valid_date(struct tm * date, char * remainder) {
 		 * characters in the date string that did not get parsed.
 		 */
 		if (*remainder != '\0') {
-			VERBOSE_MSG("Extra characters given for the date/time: \"%s\"\n",
-				  remainder);
+			VERBOSE_MSG(_("Extra characters given for the date/time: \"%s\"\n"),
+				    remainder);
 			return FALSE;
 		} else {
 			if ((*remainder == '\0') && validate_date(date)) {
@@ -695,8 +695,8 @@ static int get_file_by_date(const char * date_str,
 
 				if (!got_valid_date(&date, remainder)) {
 					build_date_time_format_help();
-					ERROR_MSG("Error parsing the date/time \"%s\".  "
-						  "The format for the date/time is either \"%s\" or \"%s\".\n",
+					ERROR_MSG(_("Error parsing the date/time \"%s\".  "
+						    "The format for the date/time is either \"%s\" or \"%s\".\n"),
 						  date_str,
 						  date_time_format_help,
 						  STANDARD_DATE_TIME_FORMAT_HELP);
@@ -709,7 +709,7 @@ static int get_file_by_date(const char * date_str,
 		file_name = find_newest_backup_file(default_metadata_dir, &date);
 
 		if (file_name == NULL) {
-			ERROR_MSG("No metadata backup files before %s found in directory %s.\n",
+			ERROR_MSG(_("No metadata backup files before %s found in directory %s.\n"),
 				  date_str, default_metadata_dir);
 			rc = ENOENT;
 		}
@@ -719,7 +719,7 @@ static int get_file_by_date(const char * date_str,
 		file_name = find_newest_backup_file(default_metadata_dir, NULL);
 
 		if (file_name == NULL) {
-			ERROR_MSG("No metadata backup files found in directory %s.\n",
+			ERROR_MSG(_("No metadata backup files found in directory %s.\n"),
 				  default_metadata_dir);
 			rc = ENOENT;
 		}
@@ -1698,7 +1698,7 @@ static int restore_children(int      fd,
 		     curr = curr->sibling);
 
 		if (curr == NULL) {
-			MSG("No backup information found for %s\n", things[i]);
+			MSG(_("No backup information found for %s\n"), things[i]);
 		}
 	}
 
@@ -1806,7 +1806,7 @@ static int restore_parents(int      fd,
 		     curr = curr->sibling);
 
 		if (curr == NULL) {
-			MSG("No backup information found for %s\n", things[i]);
+			MSG(_("No backup information found for %s\n"), things[i]);
 		}
 	}
 
@@ -2151,7 +2151,7 @@ int main(int argc, char * * argv)
 			return 1;
 		}
 
-		VERBOSE_MSG("Opening the EVMS Engine...\n");
+		VERBOSE_MSG(_("Opening the EVMS Engine...\n"));
 		rc = evms_open_engine(NULL, ENGINE_READWRITE,
 				      &callbacks, debug_level, log_file);
 		if (rc) {
@@ -2159,12 +2159,12 @@ int main(int argc, char * * argv)
 				  rc, evms_strerror(rc));
 			return rc;
 		}
-		VERBOSE_MSG("The EVMS Engine is open.\n");
+		VERBOSE_MSG(_("The EVMS Engine is open.\n"));
 	}
 
 	if (single) {
 		if (things != NULL) {
-			VERBOSE_MSG("Restoring metadata...\n");
+			VERBOSE_MSG(_("Restoring metadata...\n"));
 
 			if (parents) {
 				rc = restore_parents(fd, things, FALSE);
@@ -2177,12 +2177,12 @@ int main(int argc, char * * argv)
 			}
 
 		} else {
-			ERROR_MSG("You must specify at least one thing for a single restore.\n");
+			ERROR_MSG(_("You must specify at least one thing for a single restore.\n"));
 			rc = EINVAL;
 		}
 
 	} else if (recursive) {
-		VERBOSE_MSG("Restoring metadata...\n");
+		VERBOSE_MSG(_("Restoring metadata...\n"));
 
 		if (parents) {
 			rc = restore_parents(fd, things, TRUE);
