@@ -109,6 +109,7 @@ static boolean is_numeric(char * str)
 		if ((*str < '0') || (*str > '9')) {
 			return FALSE;
 		}
+		str++;
 	}
 	return TRUE;
 }
@@ -190,6 +191,7 @@ static int parse_options(int argc, char ** argv)
 					/* Display the help. */
 					rc = 1;
 				}
+				debug_level = level;
 			} else if (strcasecmp(optarg, "critical") == 0) {
 				debug_level = CRITICAL;
 			} else if (strcasecmp(optarg, "serious") == 0) {
